@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the COPYING file for more information.
 
 #include <rudiments/dynamicarray.h>
@@ -31,7 +31,8 @@ enum sqlrclientbindvartype_t {
 enum sqlrclientlistformat_t {
 	SQLRCLIENTLISTFORMAT_NULL=0,
 	SQLRCLIENTLISTFORMAT_MYSQL,
-	SQLRCLIENTLISTFORMAT_ODBC
+	SQLRCLIENTLISTFORMAT_ODBC,
+	SQLRCLIENTLISTFORMAT_JDBC
 };
 
 class sqlrconnectionprivate;
