@@ -1,4 +1,4 @@
-/* Copyright (c) 2000-2001  David Muse
+/* Copyright (c) 1999-2018 David Muse
    See the file COPYING for more information */
 
 #include <sqlrelay/sqlrclient.h>
@@ -25,6 +25,14 @@ sqlrcon sqlrcon_alloc_copyrefs(const char *server,
 	return sqlrconref;
 }
 
+int sqlrcon_isYes(const char *string) {
+	return sqlrconnection::isYes(string);
+}
+
+int sqlrcon_isNo(const char *string) {
+	return sqlrconnection::isNo(string);
+}
+
 void sqlrcon_free(sqlrcon sqlrconref) {
 	delete (sqlrconnection *)sqlrconref;
 }
@@ -44,6 +52,47 @@ void sqlrcon_setResponseTimeout(sqlrcon sqlrconref,
 	sqlrconref->setResponseTimeout(timeoutsec,timeoutusec);
 }
 
+
+void sqlrcon_getConnectTimeout(sqlrcon sqlrconref,
+			int32_t *timeoutsec, int32_t *timeoutusec) {
+	sqlrconref->getConnectTimeout(timeoutsec,timeoutusec);
+}
+
+void sqlrcon_getAuthenticationTimeout(sqlrcon sqlrconref,
+			int32_t *timeoutsec, int32_t *timeoutusec) {
+	sqlrconref->getAuthenticationTimeout(timeoutsec,timeoutusec);
+}
+
+void sqlrcon_getResponseTimeout(sqlrcon sqlrconref,
+			int32_t *timeoutsec, int32_t *timeoutusec) {
+	sqlrconref->getResponseTimeout(timeoutsec,timeoutusec);
+}
+
+void sqlrcon_setBindVariableDelimiters(sqlrcon sqlrconref,
+						const char *delimiters) {
+	sqlrconref->setBindVariableDelimiters(delimiters);
+}
+
+int sqlrcon_getBindVariableDelimiterQuestionMarkSupported(
+						sqlrcon sqlrconref) {
+	return sqlrconref->getBindVariableDelimiterQuestionMarkSupported();
+}
+
+int sqlrcon_getBindVariableDelimiterColonSupported(
+						sqlrcon sqlrconref) {
+	return sqlrconref->getBindVariableDelimiterColonSupported();
+}
+
+int sqlrcon_getBindVariableDelimiterAtSignSupported(
+						sqlrcon sqlrconref) {
+	return sqlrconref->getBindVariableDelimiterAtSignSupported();
+}
+
+int sqlrcon_getBindVariableDelimiterDollarSignSupported(
+						sqlrcon sqlrconref) {
+	return sqlrconref->getBindVariableDelimiterDollarSignSupported();
+}
+
 void sqlrcon_enableKerberos(sqlrcon sqlrconref,
 					const char *service,
 					const char *mech,
@@ -337,9 +386,11 @@ void sqlrcur_inputBindDouble(sqlrcur sqlrcurref, const char *variable,
 void sqlrcur_inputBindDate(sqlrcur sqlrcurref, const char *variable,
 				int16_t year, int16_t month, int16_t day,
 				int16_t hour, int16_t minute, int16_t second,
-				int32_t microsecond, const char *tz) {
+				int32_t microsecond, const char *tz,
+				int isnegative) {
 	sqlrcurref->inputBind(variable,year,month,day,
-				hour,minute,second,microsecond,tz);
+				hour,minute,second,microsecond,tz,
+				isnegative);
 }
 
 void sqlrcur_inputBindBlob(sqlrcur sqlrcurref, const char *variable,
@@ -464,9 +515,14 @@ double sqlrcur_getOutputBindDouble(sqlrcur sqlrcurref,
 int sqlrcur_getOutputBindDate(sqlrcur sqlrcurref, const char *variable,
 				int16_t *year, int16_t *month, int16_t *day,
 				int16_t *hour, int16_t *minute, int16_t *second,
-				int32_t *microsecond, const char **tz) {
-	return sqlrcurref->getOutputBindDate(variable,year,month,day,
-					hour,minute,second,microsecond,tz);
+				int32_t *microsecond, const char **tz,
+				int *isnegative) {
+	bool	isneg;
+	int	retval=sqlrcurref->getOutputBindDate(variable,year,month,day,
+					hour,minute,second,microsecond,tz,
+					&isneg);
+	*isnegative=isneg;
+	return retval;
 }
 
 uint32_t sqlrcur_getOutputBindLength(sqlrcur sqlrcurref, const char *variable) {
