@@ -1,4 +1,4 @@
-// Copyright (c) 2012-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 using System;
@@ -21,7 +21,7 @@ public class SQLRConnection : IDisposable
      *  will be made to connect through the socket.*/
     public SQLRConnection(String server, UInt16 port, String socket, String user, String password, Int32 retrytime, Int32 tries)
     {
-        sqlrconref = sqlrcon_alloc_copyrefs(server, port, socket, user, password, retrytime, tries, true);
+        sqlrconref = sqlrcon_alloc_copyrefs(server, port, socket, user, password, retrytime, tries, 1);
     }
     
     /** Dispose framework */
@@ -77,6 +77,44 @@ public class SQLRConnection : IDisposable
 
 
 
+    /** Sets which delimiters are used to identify bind variables
+     *  in countBindVariables() and validateBinds().  Valid
+     *  delimiters include ?,:,@, and $.  Defaults to "?:@$" */
+    public void setBindVariableDelimiters(String delimiters)
+    {
+        sqlrcon_setBindVariableDelimiters(sqlrconref, delimiters);
+    }
+
+    /** Returns true if question marks (?) are considered to be
+    *  valid bind variable delimiters. */
+    public Boolean getBindVariableDelimiterQuestionMarkSupported()
+    {
+        return sqlrcon_getBindVariableDelimiterQuestionMarkSupported(sqlrconref)!=0;
+    }
+
+    /** Returns true if colons (:) are considered to be
+     *  valid bind variable delimiters. */
+    public Boolean getBindVariableDelimiterColonSupported()
+    {
+        return sqlrcon_getBindVariableDelimiterColonSupported(sqlrconref)!=0;
+    }
+
+    /** Returns true if at-signs (@) are considered to be
+     *  valid bind variable delimiters. */
+    public Boolean getBindVariableDelimiterAtSignSupported()
+    {
+        return sqlrcon_getBindVariableDelimiterAtSignSupported(sqlrconref)!=0;
+    }
+
+    /** Returns true if dollar signs ($) are considered to be
+     *  valid bind variable delimiters. */
+    public Boolean getBindVariableDelimiterDollarSignSupported()
+    {
+        return sqlrcon_getBindVariableDelimiterDollarSignSupported(sqlrconref)!=0;
+    }
+
+
+
     /** Enables Kerberos authentication and encryption.
      *
      *  "service" indicates the Kerberos service name of the
@@ -228,14 +266,14 @@ public class SQLRConnection : IDisposable
      *  is only valid after a call to suspendSession(). */
     public String getConnectionSocket()
     {
-    	return sqlrcon_getConnectionSocket(sqlrconref);
+        return sqlrcon_getConnectionSocket(sqlrconref);
     }
     
     /** Resumes a session previously left open using sqlrcon_suspendSession().
      *  Returns true on success and false on failure. */
     public Boolean resumeSession(UInt16 port, String socket)
     {
-    	return sqlrcon_resumeSession(sqlrconref, port, socket)!=0;
+        return sqlrcon_resumeSession(sqlrconref, port, socket)!=0;
     }
     
     
@@ -255,19 +293,19 @@ public class SQLRConnection : IDisposable
     /** Returns the version of the database */
     public String dbVersion()
     {
-    	return sqlrcon_dbVersion(sqlrconref);
+        return sqlrcon_dbVersion(sqlrconref);
     }
     
     /** Returns the host name of the database */
     public String dbHostName()
     {
-    	return sqlrcon_dbHostName(sqlrconref);
+        return sqlrcon_dbHostName(sqlrconref);
     }
     
     /** Returns the ip address of the database */
     public String dbIpAddress()
     {
-    	return sqlrcon_dbIpAddress(sqlrconref);
+        return sqlrcon_dbIpAddress(sqlrconref);
     }
     
     /** Returns the version of the sqlrelay server software. */
@@ -417,10 +455,20 @@ public class SQLRConnection : IDisposable
         return sqlrconref;
     }
 
+    public static Boolean isYes(String str)
+    {
+        return (sqlrcon_isYes(str) != 0);
+    }
+
+    public static Boolean isNo(String str)
+    {
+        return (sqlrcon_isNo(str) != 0);
+    }
+
     private IntPtr sqlrconref;
 
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
-    private static extern IntPtr sqlrcon_alloc_copyrefs(String server, UInt16 port, String socket, String user, String password, Int32 retrytime, Int32 tries, Boolean copyreferences);
+    private static extern IntPtr sqlrcon_alloc_copyrefs(String server, UInt16 port, String socket, String user, String password, Int32 retrytime, Int32 tries, Int32 copyreferences);
     
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
     private static extern void sqlrcon_free(IntPtr sqlrconref);
@@ -434,6 +482,21 @@ public class SQLRConnection : IDisposable
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
     private static extern void sqlrcon_setResponseTimeout(IntPtr sqlrconref, Int32 timeoutsec, Int32 timeoutusec);
 
+    [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
+    private static extern void sqlrcon_setBindVariableDelimiters(IntPtr sqlrconref, String delimiters);
+
+    [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
+    private static extern Int32 sqlrcon_getBindVariableDelimiterQuestionMarkSupported(IntPtr sqlrconref);
+
+    [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
+    private static extern Int32 sqlrcon_getBindVariableDelimiterColonSupported(IntPtr sqlrconref);
+
+    [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
+    private static extern Int32 sqlrcon_getBindVariableDelimiterAtSignSupported(IntPtr sqlrconref);
+
+    [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
+    private static extern Int32 sqlrcon_getBindVariableDelimiterDollarSignSupported(IntPtr sqlrconref);
+
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
     private static extern void sqlrcon_enableKerberos(IntPtr sqlrconref, String service, String mech, String flags);
 
@@ -529,6 +592,12 @@ public class SQLRConnection : IDisposable
     
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
     private static extern String sqlrcon_getClientInfo(IntPtr sqlrconref);
+
+    [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
+    private static extern Int32 sqlrcon_isYes(String str);
+
+    [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
+    private static extern Int32 sqlrcon_isNo(String str);
 }
 
 }
