@@ -1,4 +1,4 @@
-﻿// Copyright (c) 2012-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 using System;
@@ -326,6 +326,27 @@ namespace SQLRClient
             if (_sqlrcur == null)
             {
                 _sqlrcur = new SQLRCursor(_sqlrelaycon.SQLRConnection);
+
+                if (_sqlrelaycon._columnnamecase == "upper")
+                {
+                    _sqlrcur.upperCaseColumnNames();
+                }
+                else if (_sqlrelaycon._columnnamecase == "lower")
+                {
+                    _sqlrcur.lowerCaseColumnNames();
+                }
+
+                _sqlrcur.setResultSetBufferSize(_sqlrelaycon._resultsetbuffersize);
+
+                if (_sqlrelaycon._dontgetcolumninfo)
+                {
+                    _sqlrcur.dontGetColumnInfo();
+                }
+
+                if (_sqlrelaycon._nullsasnulls)
+                {
+                    _sqlrcur.getNullsAsNulls();
+                }
             }
             return _sqlrcur;
         }
@@ -413,7 +434,7 @@ namespace SQLRClient
                         case DbType.DateTime2:
                         case DbType.DateTimeOffset:
                             DateTime dt = Convert.ToDateTime(param.Value);
-                            _sqlrcur.inputBind(param.ParameterName, Convert.ToInt16(dt.Year), Convert.ToInt16(dt.Month), Convert.ToInt16(dt.Day), Convert.ToInt16(dt.Hour), Convert.ToInt16(dt.Minute), Convert.ToInt16(dt.Second), Convert.ToInt16(dt.Millisecond)*1000, null);
+                            _sqlrcur.inputBind(param.ParameterName, Convert.ToInt16(dt.Year), Convert.ToInt16(dt.Month), Convert.ToInt16(dt.Day), Convert.ToInt16(dt.Hour), Convert.ToInt16(dt.Minute), Convert.ToInt16(dt.Second), Convert.ToInt16(dt.Millisecond)*1000, null, false);
                             continue;
 
                         case DbType.Binary:
@@ -576,7 +597,8 @@ namespace SQLRClient
                             Int16 second = 0;
                             Int32 microsecond = 0;
                             String tz = null;
-                            _sqlrcur.getOutputBindDate(param.ParameterName, out year, out month, out day, out hour, out minute, out second, out microsecond, out tz);
+                            Boolean isnegative = false;
+                            _sqlrcur.getOutputBindDate(param.ParameterName, out year, out month, out day, out hour, out minute, out second, out microsecond, out tz, out isnegative);
                             param.Value = new DateTime(year, month, day, hour, minute, second, microsecond/1000);
                             break;
 
