@@ -1,4 +1,4 @@
-// Copyright (c) 2004  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrclient.h>
@@ -10,6 +10,7 @@
 #include <rudiments/dictionary.h>
 #include <rudiments/file.h>
 #include <rudiments/memorypool.h>
+#include <rudiments/datetime.h>
 #include <rudiments/stdio.h>
 //#define DEBUG_MESSAGES
 #include <rudiments/debugprint.h>
@@ -20,12 +21,20 @@
 #define NEED_IS_UNSIGNED_TYPE_CHAR 1
 #define NEED_IS_BINARY_TYPE_CHAR 1
 #include <datatypes.h>
+#include <defines.h>
 
 extern "C" {
 
 #define CR_UNKNOWN_ERROR	2000
 #define MYSQL_NO_DATA		100
 #define REFRESH_GRANT		1
+#define REFRESH_LOG		2
+#define REFRESH_TABLES		4
+#define REFRESH_HOSTS		8
+#define REFRESH_STATUS		16
+#define REFRESH_THREADS		32
+#define REFRESH_SLAVE		64
+#define REFRESH_MASTER		128
 
 typedef unsigned long long	my_ulonglong;
 typedef bool			my_bool;
@@ -40,7 +49,7 @@ enum mysql_option {
 	MYSQL_OPTION_UNKNOWN_OPTION
 };
 
-// Taken directly from mysql_com.h version 5.1.22
+// Taken directly from mysql_com.h version 5.something
 // Back-compatible with all previous versions.
 enum enum_field_types {
 	MYSQL_TYPE_DECIMAL,
@@ -51,12 +60,18 @@ enum enum_field_types {
 	MYSQL_TYPE_DOUBLE,
 	MYSQL_TYPE_NULL,
 	MYSQL_TYPE_TIMESTAMP,
-	MYSQL_TYPE_LONGLONG,MYSQL_TYPE_INT24,
+	MYSQL_TYPE_LONGLONG,
+	MYSQL_TYPE_INT24,
 	MYSQL_TYPE_DATE,
 	MYSQL_TYPE_TIME,
 	MYSQL_TYPE_DATETIME,
 	MYSQL_TYPE_YEAR,
 	MYSQL_TYPE_NEWDATE,
+	MYSQL_TYPE_VARCHAR,
+	MYSQL_TYPE_BIT,
+	MYSQL_TYPE_TIMESTAMP2,
+	MYSQL_TYPE_DATETIME2,
+	MYSQL_TYPE_TIME2,
 	MYSQL_TYPE_NEWDECIMAL=246,
 	MYSQL_TYPE_ENUM=247,
 	MYSQL_TYPE_SET=248,
@@ -184,8 +199,8 @@ struct MYSQL_BIND {
   my_bool       binary_data;      /* data buffer is binary */
   my_bool       null_field;       /* NULL data cache flag */
   my_bool	internal_is_null; /* Used if is_null is 0 */
-  void (*store_param_func);/*(NET *net, struct MYSQL_BIND *param);*/
-  void (*fetch_result);/*(struct MYSQL_BIND *, unsigned char **row);*/
+  void *store_param_func;/*(NET *net, struct MYSQL_BIND *param);*/
+  void *fetch_result;/*(struct MYSQL_BIND *, unsigned char **row);*/
 };
 #endif
 
@@ -241,7 +256,7 @@ struct MYSQL_STMT {
 	MYSQL_RES	*result;
 	MYSQL_BIND	*resultbinds;
 	MYSQL		*mysql;
-	memorypool	*bindvarnames;
+	memorypool	bindvarnames;
 };
 
 struct MYSQL {
@@ -254,8 +269,25 @@ struct MYSQL {
 	char		*error;
 	int		errorno;
 	dictionary< int64_t, unsigned int >	*errormap;
+	bool		backendchecked;
+	bool		backendismysql;
 };
 
+#define NOT_NULL_FLAG		1
+#define PRI_KEY_FLAG		2
+#define UNIQUE_KEY_FLAG		4
+#define MULTIPLE_KEY_FLAG	8
+#define BLOB_FLAG		16
+#define UNSIGNED_FLAG		32
+#define ZEROFILL_FLAG		64
+#define BINARY_FLAG		128
+#define ENUM_FLAG		256
+#define AUTO_INCREMENT_FLAG	512
+#define TIMESTAMP_FLAG		1024
+#define ON_UPDATE_NOW_FLAG	8192
+#define SET_FLAG		2048
+#define NUM_FLAG		32768
+
 
 unsigned int mysql_thread_safe();
 MYSQL *mysql_init(MYSQL *mysql);
@@ -504,6 +536,8 @@ MYSQL *mysql_real_connect(MYSQL *mysql, const char *host, const char *user,
 	if (charstring::length(errormap)) {
 		loadErrorMap(mysql,errormap);
 	}
+	mysql->backendchecked=false;
+	mysql->backendismysql=false;
 	mysql->currentstmt=NULL;
 	mysql_select_db(mysql,db);
 	return mysql;
@@ -531,26 +565,53 @@ int mysql_ping(MYSQL *mysql) {
 
 const char *mysql_stat(MYSQL *mysql) {
 	debugFunction();
-	return "Uptime: 0  Threads: 0  Questions: 0  Slow queries: 0  Opens: 0  Flush tables: 0  Open tables: 0 Queries per second avg: 0.0";
+	return "Uptime: 0  Threads: 0  Questions: 0  "
+		"Slow queries: 0  Opens: 0  Flush tables: 0  "
+		"Open tables: 0 Queries per second avg: 0.0";
 }
 
 int mysql_shutdown(MYSQL *mysql) {
 	debugFunction();
-	return unknownError(mysql);
+	sqlrcursor	sqlrcur(mysql->sqlrcon);
+	return !sqlrcur.sendQuery("SHUTDOWN");
 }
 
 int mysql_refresh(MYSQL *mysql, unsigned int refresh_options) {
 	debugFunction();
-	return (refresh_options==REFRESH_GRANT)?mysql_reload(mysql):0;
+	const char	*query=NULL;
+	switch (refresh_options) {
+		case REFRESH_GRANT:
+			query="FLUSH PRIVILEGES";
+			break;
+		case REFRESH_LOG:
+			query="FLUSH LOGS";
+			break;
+		case REFRESH_TABLES:
+			query="FLUSH TABLES";
+			break;
+		case REFRESH_HOSTS:
+			query="FLUSH HOSTS";
+			break;
+		case REFRESH_STATUS:
+			query="FLUSH STATUS";
+			break;
+		case REFRESH_THREADS:
+			// FIXME: do something?
+			return 0;
+		case REFRESH_SLAVE:
+			query="RESET SLAVE";
+			break;
+		case REFRESH_MASTER:
+			query="RESET MASTER";
+			break;
+	}
+	sqlrcursor	sqlrcur(mysql->sqlrcon);
+	return !sqlrcur.sendQuery(query);
 }
 
 int mysql_reload(MYSQL *mysql) {
 	debugFunction();
-	if (!charstring::compare(mysql->sqlrcon->identify(),"mysql")) {
-		sqlrcursor	sqlrcur(mysql->sqlrcon);
-		return !sqlrcur.sendQuery("FLUSH PRIVILEGES");
-	}
-	return 0;
+	return mysql_refresh(mysql,REFRESH_GRANT);
 }
 
 unsigned long mysql_thread_id(MYSQL *mysql) {
@@ -560,12 +621,30 @@ unsigned long mysql_thread_id(MYSQL *mysql) {
 
 MYSQL_RES *mysql_list_processes(MYSQL *mysql) {
 	debugFunction();
-	return NULL;
+	mysql_stmt_close(mysql->currentstmt);
+
+	mysql->currentstmt=new MYSQL_STMT;
+	mysql->currentstmt->result=new MYSQL_RES;
+	mysql->currentstmt->result->stmtbackptr=NULL;
+	mysql->currentstmt->result->sqlrcur=new sqlrcursor(mysql->sqlrcon,true);
+	mysql->currentstmt->result->errorno=0;
+	mysql->currentstmt->result->fields=NULL;
+	mysql->currentstmt->result->lengths=NULL;
+	mysql->currentstmt->result->sqlrcur->sendQuery("SHOW PROCESSLIST");
+	processFields(mysql->currentstmt);
+	mysql->currentstmt->result->currentfield=0;
+
+	MYSQL_RES	*retval=mysql->currentstmt->result;
+	mysql->currentstmt->result=NULL;
+	return retval;
 }
 
 int mysql_kill(MYSQL *mysql, unsigned long pid) {
 	debugFunction();
-	return unknownError(mysql);
+	sqlrcursor	sqlrcur(mysql->sqlrcon);
+	stringbuffer	query;
+	query.append("KILL ")->append((uint64_t)pid);
+	return !sqlrcur.sendQuery(query.getString());
 }
 
 
@@ -751,7 +830,6 @@ MYSQL_RES *mysql_list_dbs(MYSQL *mysql, const char *wild) {
 	mysql_stmt_close(mysql->currentstmt);
 
 	mysql->currentstmt=new MYSQL_STMT;
-	mysql->currentstmt->bindvarnames=new memorypool(0,128,100);
 	mysql->currentstmt->result=new MYSQL_RES;
 	mysql->currentstmt->result->stmtbackptr=NULL;
 	mysql->currentstmt->result->sqlrcur=new sqlrcursor(mysql->sqlrcon,true);
@@ -774,7 +852,6 @@ MYSQL_RES *mysql_list_tables(MYSQL *mysql, const char *wild) {
 	mysql_stmt_close(mysql->currentstmt);
 
 	mysql->currentstmt=new MYSQL_STMT;
-	mysql->currentstmt->bindvarnames=new memorypool(0,128,100);
 	mysql->currentstmt->result=new MYSQL_RES;
 	mysql->currentstmt->result->stmtbackptr=NULL;
 	mysql->currentstmt->result->sqlrcur=new sqlrcursor(mysql->sqlrcon,true);
@@ -782,7 +859,9 @@ MYSQL_RES *mysql_list_tables(MYSQL *mysql, const char *wild) {
 	mysql->currentstmt->result->fields=NULL;
 	mysql->currentstmt->result->lengths=NULL;
 	mysql->currentstmt->result->sqlrcur->getTableList(wild,
-						SQLRCLIENTLISTFORMAT_MYSQL);
+					SQLRCLIENTLISTFORMAT_MYSQL,
+					DB_OBJECT_TABLE|DB_OBJECT_VIEW|
+					DB_OBJECT_ALIAS|DB_OBJECT_SYNONYM);
 	processFields(mysql->currentstmt);
 	mysql->currentstmt->result->currentfield=0;
 
@@ -808,7 +887,6 @@ MYSQL_RES *mysql_list_fields(MYSQL *mysql,
 	mysql_stmt_close(mysql->currentstmt);
 
 	MYSQL_STMT	*stmt=new MYSQL_STMT;
-	stmt->bindvarnames=new memorypool(0,128,100);
 	mysql->currentstmt=stmt;
 	stmt->result=new MYSQL_RES;
 	stmt->result->stmtbackptr=NULL;
@@ -839,8 +917,9 @@ MYSQL_RES *mysql_list_fields(MYSQL *mysql,
 			fields[i].name=const_cast<char *>(
 					sqlrcur->getField(i,(uint32_t)0));
 			fields[i].table=const_cast<char *>(table);
-			fields[i].def=const_cast<char *>(
-					sqlrcur->getField(i,(uint32_t)7));
+			const char	*def=sqlrcur->getField(i,(uint32_t)7);
+			fields[i].def=(charstring::isNullOrEmpty(def))?
+							NULL:(char *)def;
 
 			#if defined(COMPAT_MYSQL_4_0) || \
 				defined(COMPAT_MYSQL_4_1) || \
@@ -851,8 +930,8 @@ MYSQL_RES *mysql_list_fields(MYSQL *mysql,
 			#if defined(COMPAT_MYSQL_4_1) || \
 				defined(COMPAT_MYSQL_5_0) || \
 				defined(COMPAT_MYSQL_5_1)
-  			fields[i].catalog=(char *)"";
-  			fields[i].org_name=fields[i].name;
+  			fields[i].catalog=(char *)"def";
+  			fields[i].org_name=(char *)"";
 			fields[i].name_length=
 				charstring::length(fields[i].name);
 			fields[i].org_name_length=
@@ -875,48 +954,150 @@ MYSQL_RES *mysql_list_fields(MYSQL *mysql,
 			// figure out the column type
 			const char	*columntypestring=
 						sqlrcur->getField(i,1);
+			const char	*lengthstring=
+						sqlrcur->getField(i,2);
+			int64_t	prec=sqlrcur->getFieldAsInteger(i,3);
 			int64_t	scale=sqlrcur->getFieldAsInteger(i,4);
+			const char	*nullable=sqlrcur->getField(i,5);
+			const char	*key=sqlrcur->getField(i,6);
+			const char	*extra=sqlrcur->getField(i,8);
 			enum enum_field_types	columntype=
 					map_col_type(columntypestring,scale);
 			fields[i].type=columntype;
 
 			// determine the length...
-			// for decimals, attempt to use the precision (column 3)
-			// and add 2 (one for negative, one for decimal)
-			// for non-decimals, or if column 3 is empty, fall back
-			// to the "length" (column 2) otherwise fall back to 50
-			bool		gotlen=false;
 			unsigned int	len=0;
-			if ((columntype==MYSQL_TYPE_DECIMAL ||
-				columntype==MYSQL_TYPE_NEWDECIMAL) &&
-				sqlrcur->getFieldLength(i,(uint32_t)3)) {
-				len=sqlrcur->getFieldAsInteger(i,(uint32_t)3)+2;
-				gotlen=true;
-			}
-			if (!gotlen && sqlrcur->getFieldLength(i,(uint32_t)2)) {
-				len=sqlrcur->getFieldAsInteger(i,(uint32_t)2);
-				gotlen=true;
-			}
-			if (!gotlen) {
-				len=50;
+			if (!charstring::isNullOrEmpty(lengthstring)) {
+				len=charstring::toInteger(lengthstring);
+			} else {
+				switch (columntype) {
+					case MYSQL_TYPE_DECIMAL:
+						len=prec+2;
+						break;
+					case MYSQL_TYPE_TINY:
+						len=4;
+						break;
+					case MYSQL_TYPE_SHORT:
+						len=6;
+						break;
+					case MYSQL_TYPE_LONG:
+						len=11;
+						break;
+					case MYSQL_TYPE_FLOAT:
+						len=12;
+						break;
+					case MYSQL_TYPE_DOUBLE:
+						len=22;
+						break;
+					case MYSQL_TYPE_TIMESTAMP:
+						len=19;
+						break;
+					case MYSQL_TYPE_LONGLONG:
+						len=20;
+						break;
+					case MYSQL_TYPE_INT24:
+						len=9;
+						break;
+					case MYSQL_TYPE_DATE:
+						len=10;
+						break;
+					case MYSQL_TYPE_TIME:
+						len=10;
+						break;
+					case MYSQL_TYPE_DATETIME:
+						len=19;
+						break;
+					case MYSQL_TYPE_YEAR:
+						len=4;
+						break;
+					case MYSQL_TYPE_NEWDATE:
+						len=10;
+						break;
+					case MYSQL_TYPE_BIT:
+						len=1;
+						break;
+					case MYSQL_TYPE_TIMESTAMP2:
+						len=19;
+						break;
+					case MYSQL_TYPE_DATETIME2:
+						len=19;
+						break;
+					case MYSQL_TYPE_TIME2:
+						len=10;
+						break;
+					case MYSQL_TYPE_NEWDECIMAL:
+						len=sqlrcur->getFieldAsInteger(
+							i,(uint32_t)3)+2;
+						break;
+					case MYSQL_TYPE_ENUM:
+					case MYSQL_TYPE_SET:
+					case MYSQL_TYPE_GEOMETRY:
+						// FIXME: not really sure
+						// about these
+						len=8;
+						break;
+					default:
+						// fall back to 50
+						len=50;
+						break;
+				}
 			}
 			fields[i].length=len;
 
-			// no good way to set this
-			fields[i].max_length=fields[i].length;
+			// it looks like this is always 0
+			fields[i].max_length=0;
 
 			// figure out the flags
 			unsigned int	flags=0;
-			if (isTrue(sqlrcur->getField(i,5))) {
-				#define NOT_NULL_FLAG	1
+			if (!isTrue(nullable)) {
 				flags|=NOT_NULL_FLAG;
 			}
-			if (isTrue(sqlrcur->getField(i,6))) {
-				#define PRI_KEY_FLAG	2
+			if (!charstring::compareIgnoringCase(key,"pri")) {
 				flags|=PRI_KEY_FLAG;
 			}
-			// FIXME: the Extra field might have other flags in it
-
+			if (!charstring::compareIgnoringCase(key,"uni")) {
+				flags|=UNIQUE_KEY_FLAG;
+			}
+			if (!charstring::isNullOrEmpty(key)) {
+				flags|=MULTIPLE_KEY_FLAG;
+			}
+			if (columntype==MYSQL_TYPE_TINY_BLOB ||
+				columntype==MYSQL_TYPE_MEDIUM_BLOB ||
+				columntype==MYSQL_TYPE_LONG_BLOB ||
+				columntype==MYSQL_TYPE_BLOB) {
+				flags|=BLOB_FLAG;
+			}
+			// FIXME: the "unsigned" test won't work with most db's
+			if (charstring::contains(columntypestring,"unsigned") ||
+				isUnsignedTypeChar(columntypestring)) {
+				flags|=UNSIGNED_FLAG;
+			}
+			// FIXME: there are probably other
+			// types that are zero-filled
+			if (columntype==MYSQL_TYPE_YEAR) {
+				flags|=ZEROFILL_FLAG;
+			}
+			if (isBinaryTypeChar(columntypestring)) {
+				flags|=BINARY_FLAG;
+			}
+			if (columntype==MYSQL_TYPE_ENUM) {
+				flags|=ENUM_FLAG;
+			}
+			if (charstring::contains(extra,"auto_increment")) {
+				flags|=AUTO_INCREMENT_FLAG;
+			}
+			if (columntype==MYSQL_TYPE_TIMESTAMP ||
+				columntype==MYSQL_TYPE_TIMESTAMP2) {
+				flags|=TIMESTAMP_FLAG|ON_UPDATE_NOW_FLAG;
+			}
+			if (columntype==MYSQL_TYPE_SET) {
+				flags|=SET_FLAG;
+			}
+			if (isNumberTypeChar(columntypestring)) {
+				flags|=NUM_FLAG;
+			}
+			fields[i].flags=flags;
+		
 			// set the number of decimal places (scale)
 			fields[i].decimals=scale;
 		}
@@ -1033,7 +1214,7 @@ int mysql_real_query(MYSQL *mysql, const char *query, unsigned long length) {
 
 const char *mysql_info(MYSQL *mysql) {
 	debugFunction();
-	return "";
+	return NULL;
 }
 
 my_ulonglong mysql_insert_id(MYSQL *mysql) {
@@ -1295,7 +1476,7 @@ static enum enum_field_types	mysqltypemap[]={
 	// "FLOAT"
 	MYSQL_TYPE_FLOAT,
 	// "TEXT"
-	MYSQL_TYPE_STRING,
+	MYSQL_TYPE_BLOB,
 	// "VARCHAR"
 	MYSQL_TYPE_VAR_STRING,
 	// "VARBINARY"
@@ -1322,9 +1503,9 @@ static enum enum_field_types	mysqltypemap[]={
 	// "DOUBLE"
 	MYSQL_TYPE_DOUBLE,
 	// "DATE"
-	MYSQL_TYPE_DATETIME,
+	MYSQL_TYPE_DATE,
 	// "TIME"
-	MYSQL_TYPE_DATETIME,
+	MYSQL_TYPE_TIME,
 	// "TIMESTAMP"
 	MYSQL_TYPE_TIMESTAMP,
 	// added by msql
@@ -1414,6 +1595,10 @@ static enum enum_field_types	mysqltypemap[]={
 	// "DOUBLE PRECISION"
 	MYSQL_TYPE_DOUBLE,
 	// added by postgresql
+	// "BOOL"
+	MYSQL_TYPE_TINY,
+	// "BYTEA"
+	MYSQL_TYPE_BLOB,
 	// "NAME"
 	MYSQL_TYPE_STRING,
 	// "INT8"
@@ -1629,6 +1814,28 @@ static enum enum_field_types	mysqltypemap[]={
 	MYSQL_TYPE_BLOB,
 	// "BOOLEAN"
 	MYSQL_TYPE_TINY,
+	// "TINYTEXT"
+	MYSQL_TYPE_BLOB,
+	// "MEDIUMTEXT"
+	MYSQL_TYPE_BLOB,
+	// "LONGTEXT"
+	MYSQL_TYPE_BLOB,
+	// "JSON"
+	MYSQL_TYPE_BLOB,
+	// "GEOMETRY"
+	MYSQL_TYPE_BLOB,
+	// "SDO_GEOMETRY"
+	MYSQL_TYPE_BLOB,
+	// "NCHAR"
+	MYSQL_TYPE_STRING,
+	// "NVARCHAR"
+	MYSQL_TYPE_VAR_STRING,
+	// "NTEXT"
+	MYSQL_TYPE_BLOB,
+	// "XML"
+	MYSQL_TYPE_BLOB,
+	// "DATETIMEOFFSET"
+	MYSQL_TYPE_DATETIME
 };
 
 enum enum_field_types map_col_type(const char *columntype, int64_t scale) {
@@ -1655,7 +1862,7 @@ enum enum_field_types map_col_type(const char *columntype, int64_t scale) {
 			enum_field_types	retval=mysqltypemap[index];
 
 			// Some DB's, like oracle, don't distinguish between
-			// float and integer types, they just have a numeric
+			// decimal and integer types, they just have a numeric
 			// field which may or may not have decimal points.
 			// Those fields types get translated to "decimal"
 			// but if there are 0 decimal points, then we need to
@@ -1665,17 +1872,18 @@ enum enum_field_types map_col_type(const char *columntype, int64_t scale) {
 				retval=MYSQL_TYPE_LONG;
 			}
 
-			// Some DB's, like oracle, only have a date type, not
-			// date, time and datetime types.  Sometimes the app
-			// might just want the column to be treated as a date,
-			// rather than datetime.  Use an environment variable
-			// to handle this.
-			if (retval==MYSQL_TYPE_DATETIME &&
-				!charstring::compareIgnoringCase(
+			// Some DB's, like oracle, don't have separate DATE
+			// and DATETIME types.  Rather, a DATE can store the
+			// date and time, but which components it reports
+			// depends on something like the NLS_DATE_FORMAT.  By
+			// default, we map DATE to MYSQL_TYPE_DATE, but we also
+			// provide the option of mapping it to
+			// MYSQL_TYPE_DATETIME.
+			if (retval==MYSQL_TYPE_DATE &&
+				charstring::isYes(
 					environment::getValue(
-					"SQLR_MYSQL_MAP_DATETIME_TO_DATE"),
-					"yes")) {
-				retval=MYSQL_TYPE_DATE;
+					"SQLR_MYSQL_MAP_DATE_TO_DATETIME"))) {
+				retval=MYSQL_TYPE_DATETIME;
 			}
 			return retval;
 		}
@@ -1688,7 +1896,6 @@ int mysql_execute(MYSQL_STMT *stmt) {
 	return mysql_stmt_execute(stmt);
 }
 
-#include <parsedatetime.h>
 static void getDate(const char *field, uint32_t length, MYSQL_BIND *bind) {
 
 	// result variables
@@ -1699,7 +1906,8 @@ static void getDate(const char *field, uint32_t length, MYSQL_BIND *bind) {
 	int16_t	hour=-1;
 	int16_t	minute=-1;
 	int16_t	second=-1;
-	int16_t	fraction=-1;
+	int32_t	usec=-1;
+	bool	isnegative=false;
 
 	// copy into a buffer (to make sure it's null-terminated)
 	char	*buffer=new char[length+1];
@@ -1707,20 +1915,18 @@ static void getDate(const char *field, uint32_t length, MYSQL_BIND *bind) {
 	buffer[length]='\0';
 
 	// parse
-	bool	ddmm=!charstring::compareIgnoringCase(
-					environment::getValue(
-					"SQLR_MYSQL_DATE_DDMM"),
-					"yes");
+	bool	ddmm=charstring::isYes(environment::getValue(
+					"SQLR_MYSQL_DATE_DDMM"));
 	bool		yyyyddmm=ddmm;
 	const char	*yyyyddmmstr=environment::getValue(
 					"SQLR_MYSQL_DATE_YYYYDDMM");
 	if (yyyyddmmstr) {
-		yyyyddmm=!charstring::compare(yyyyddmmstr,"yes");
+		yyyyddmm=charstring::isYes(yyyyddmmstr);
 	}
-	parseDateTime(buffer,ddmm,yyyyddmm,
+	datetime::parse(buffer,ddmm,yyyyddmm,
 				"/-:",&year,&month,&day,
 				&hour,&minute,&second,
-				&fraction);
+				&usec,&isnegative);
 
 	// copy back data
 	tm->year=(year!=-1)?year:0;
@@ -1729,6 +1935,7 @@ static void getDate(const char *field, uint32_t length, MYSQL_BIND *bind) {
 	tm->hour=(hour!=-1)?hour:0;
 	tm->minute=(minute!=-1)?minute:0;
 	tm->second=(second!=-1)?second:0;
+	tm->neg=isnegative;
 
 	// clean up
 	delete[] buffer;
@@ -1769,8 +1976,8 @@ int mysql_stmt_fetch(MYSQL_STMT *stmt) {
 		// is_null components are all settable.  If we find bind
 		// buffer with those values NULL then assume we've hit the
 		// NULL terminator.
-		if (!charstring::compareIgnoringCase(environment::getValue(
-			"SQLR_MYSQL_NULL_TERMINATED_RESULT_BINDS"),"yes") &&
+		if (charstring::isYes(environment::getValue(
+				"SQLR_MYSQL_NULL_TERMINATED_RESULT_BINDS")) &&
 			!stmt->resultbinds[i].buffer &&
 			!stmt->resultbinds[i].length &&
 			!stmt->resultbinds[i].is_null) {
@@ -1895,7 +2102,7 @@ int mysql_stmt_fetch(MYSQL_STMT *stmt) {
 						*((float *)stmt->
 							resultbinds[i].buffer)=
 							(float)charstring::
-								toFloat(row[i]);
+							toFloatC(row[i]);
 					}
 					break;
 				case MYSQL_TYPE_NEWDECIMAL:
@@ -1906,7 +2113,7 @@ int mysql_stmt_fetch(MYSQL_STMT *stmt) {
 						*((double *)stmt->
 							resultbinds[i].buffer)=
 							(double)charstring::
-								toFloat(row[i]);
+							toFloatC(row[i]);
 					}
 					break;
 				case MYSQL_TYPE_ENUM:
@@ -1967,9 +2174,8 @@ static void processFields(MYSQL_STMT *stmt) {
 			#if defined(COMPAT_MYSQL_4_1) || \
 				defined(COMPAT_MYSQL_5_0) || \
 				defined(COMPAT_MYSQL_5_1)
-  			fields[i].catalog=(char *)"";
-  			fields[i].org_name=const_cast<char *>(
-						sqlrcur->getColumnName(i));
+  			fields[i].catalog=(char *)"def";
+  			fields[i].org_name=(char *)"";
 			fields[i].name_length=
 				charstring::length(fields[i].name);
 			fields[i].org_name_length=
@@ -2012,69 +2218,52 @@ static void processFields(MYSQL_STMT *stmt) {
 			// figure out the flags
 			unsigned int	flags=0;
 			if (sqlrcur->getColumnIsNullable(i)) {
-				#define NOT_NULL_FLAG	1
 				flags|=NOT_NULL_FLAG;
 			}
 			if (sqlrcur->getColumnIsPrimaryKey(i)) {
-				#define PRI_KEY_FLAG	2
 				flags|=PRI_KEY_FLAG;
 			}
 			if (sqlrcur->getColumnIsUnique(i)) {
-				#define UNIQUE_KEY_FLAG 4
 				flags|=UNIQUE_KEY_FLAG;
 			}
 			if (sqlrcur->getColumnIsPartOfKey(i)) {
-				#define MULTIPLE_KEY_FLAG 8
 				flags|=MULTIPLE_KEY_FLAG;
 			}
 			if (columntype==MYSQL_TYPE_TINY_BLOB ||
 				columntype==MYSQL_TYPE_MEDIUM_BLOB ||
 				columntype==MYSQL_TYPE_LONG_BLOB ||
 				columntype==MYSQL_TYPE_BLOB) {
-				#define BLOB_FLAG	16
 				flags|=BLOB_FLAG;
 			}
-			if (sqlrcur->getColumnIsUnsigned(i) ||
+			// FIXME: the "unsigned" test won't work with most db's
+			if (charstring::contains(columntypestring,"unsigned") ||
+				sqlrcur->getColumnIsUnsigned(i) ||
 				isUnsignedTypeChar(columntypestring)) {
-				#define UNSIGNED_FLAG	32
 				flags|=UNSIGNED_FLAG;
 			}
 			if (sqlrcur->getColumnIsZeroFilled(i)) {
-				#define ZEROFILL_FLAG	64
 				flags|=ZEROFILL_FLAG;
 			}
 			if (sqlrcur->getColumnIsBinary(i) ||
 				isBinaryTypeChar(columntypestring)) {
-				#define BINARY_FLAG	128
 				flags|=BINARY_FLAG;
 			}
 			if (columntype==MYSQL_TYPE_ENUM) {
-				#define ENUM_FLAG	256
 				flags|=ENUM_FLAG;
 			}
 			if (sqlrcur->getColumnIsAutoIncrement(i)) {
-				#define AUTO_INCREMENT_FLAG 512
 				flags|=AUTO_INCREMENT_FLAG;
 			}
-			if (columntype==MYSQL_TYPE_TIMESTAMP) {
-				#define TIMESTAMP_FLAG	1024
-				flags|=TIMESTAMP_FLAG;
+			if (columntype==MYSQL_TYPE_TIMESTAMP ||
+				columntype==MYSQL_TYPE_TIMESTAMP2) {
+				flags|=TIMESTAMP_FLAG|ON_UPDATE_NOW_FLAG;
 			}
 			if (columntype==MYSQL_TYPE_SET) {
-				#define SET_FLAG	2048
 				flags|=SET_FLAG;
 			}
 			if (isNumberTypeChar(columntypestring)) {
-				#define NUM_FLAG	32768
 				flags|=NUM_FLAG;
 			}
-			// Presumably these don't matter...
-			// Intern; Part of some key
-			//#define PART_KEY_FLAG	16384
-			// Intern: Group field
-			//#define GROUP_FLAG	32768
-			// Intern: Used by sql_yacc
-			//#define UNIQUE_FLAG	65536
 			fields[i].flags=flags;
 
 			fields[i].decimals=scale;
@@ -2133,7 +2322,6 @@ my_bool mysql_send_long_data(MYSQL_STMT *stmt,
 MYSQL_STMT *mysql_stmt_init(MYSQL *mysql) {
 	debugFunction();
 	MYSQL_STMT	*stmt=new MYSQL_STMT;
-	stmt->bindvarnames=new memorypool(0,128,100);
 	stmt->mysql=mysql;
 	stmt->result=new MYSQL_RES;
 	stmt->result->stmtbackptr=stmt;
@@ -2210,7 +2398,6 @@ my_bool mysql_stmt_close(MYSQL_STMT *stmt) {
 	debugFunction();
 	if (stmt) {
 		mysql_free_result(stmt->result);
-		delete stmt->bindvarnames;
 		delete stmt;
 	}
 	return 0;
@@ -2294,7 +2481,7 @@ my_bool mysql_stmt_attr_get(MYSQL_STMT *stmt,
 my_bool mysql_stmt_bind_param(MYSQL_STMT *stmt, MYSQL_BIND *bind) {
 	debugFunction();
 
-	stmt->bindvarnames->deallocate();
+	stmt->bindvarnames.clear();
 
 	unsigned long	paramcount=mysql_param_count(stmt);
 	for (unsigned long i=0; i<paramcount; i++) {
@@ -2302,7 +2489,7 @@ my_bool mysql_stmt_bind_param(MYSQL_STMT *stmt, MYSQL_BIND *bind) {
 		// use 1-based index for variable names
 		size_t	buffersize=charstring::integerLength((uint32_t)i+1)+1;
 		char	*variable=
-			(char *)stmt->bindvarnames->allocate(buffersize);
+			(char *)stmt->bindvarnames.allocate(buffersize);
 		charstring::printf(variable,buffersize,"%ld",i+1);
 
 		// get the cursor
@@ -2326,21 +2513,51 @@ my_bool mysql_stmt_bind_param(MYSQL_STMT *stmt, MYSQL_BIND *bind) {
 				cursor->inputBind(variable,value);
 				break;
 			}
+			case MYSQL_TYPE_DATE: {
+				MYSQL_TIME	*tm=
+						(MYSQL_TIME *)bind[i].buffer;
+				cursor->inputBind(variable,
+						tm->year,
+						tm->month,
+						tm->day,
+						-1,
+						-1,
+						-1,
+						-1,
+						NULL,
+						tm->neg);
+				break;
+			}
+			case MYSQL_TYPE_TIME: {
+				MYSQL_TIME	*tm=
+						(MYSQL_TIME *)bind[i].buffer;
+				cursor->inputBind(variable,
+						-1,
+						-1,
+						((tm->neg)?-1:1)*tm->day,
+						tm->hour,
+						tm->minute,
+						tm->second,
+						0,
+						NULL,
+						tm->neg);
+				break;
+			}
 			case MYSQL_TYPE_TIMESTAMP:
-			case MYSQL_TYPE_DATE:
-			case MYSQL_TYPE_TIME:
 			case MYSQL_TYPE_DATETIME:
 			case MYSQL_TYPE_NEWDATE: {
 				MYSQL_TIME	*tm=
 						(MYSQL_TIME *)bind[i].buffer;
 				cursor->inputBind(variable,
-							tm->year,
-							tm->month,
-							tm->day,
-							tm->hour,
-							tm->minute,
-							tm->second,
-							0,NULL);
+						tm->year,
+						tm->month,
+						tm->day,
+						tm->hour,
+						tm->minute,
+						tm->second,
+						0,
+						NULL,
+						tm->neg);
 				break;
 			}
 			case MYSQL_TYPE_NEWDECIMAL:
@@ -2446,7 +2663,6 @@ int mysql_server_init(int argc, char **argv, char **groups) {
 void mysql_library_init(int argc, char **argv, char **groups) {
 	debugFunction();
 	my_init();
-	// FIXME: do something?
 }
 
 void mysql_server_end() {
@@ -2456,7 +2672,6 @@ void mysql_server_end() {
 
 void mysql_library_end() {
 	debugFunction();
-	// FIXME: do something?
 }
 
 my_bool mysql_embedded() {
@@ -2481,6 +2696,16 @@ unsigned int mapErrorNumber(MYSQL *mysql, int64_t errorno) {
 	unsigned int	retval=CR_UNKNOWN_ERROR;
 	if (mysql->errormap) {
 		mysql->errormap->getValue(errorno,&retval);
+	} else {
+		if (!mysql->backendchecked) {
+			mysql->backendismysql=
+				!charstring::compare(
+					mysql->sqlrcon->identify(),"mysql");
+			mysql->backendchecked=true;
+		}
+		if (mysql->backendismysql) {
+			retval=errorno;
+		}
 	}
 	return retval;
 }
