@@ -178,7 +178,6 @@ enum {
 	PDO_SQLRELAY_ATTR_BIND_FORMAT,
 	PDO_SQLRELAY_ATTR_CURRENT_DB,
 	PDO_SQLRELAY_ATTR_CONNECTION_TIMEOUT,
-	PDO_SQLRELAY_ATTR_AUTHENTICATION_TIMEOUT,
 	PDO_SQLRELAY_ATTR_RESPONSE_TIMEOUT,
 	PDO_SQLRELAY_ATTR_SQLRELAY_VERSION,
 	PDO_SQLRELAY_ATTR_RUDIMENTS_VERSION,
@@ -355,7 +354,6 @@ static int sqlrcursorDescribe(pdo_stmt_t *stmt, int colno TSRMLS_DC) {
 	sqlrstatement	*sqlrstmt=(sqlrstatement *)stmt->driver_data;
 	sqlrcursor	*sqlrcur=sqlrstmt->sqlrcur;
 	const char	*n=sqlrcur->getColumnName(colno);
-	const char	*type=sqlrcur->getColumnType(colno);
 #if PHP_MAJOR_VERSION >= 7
 	stmt->columns[colno].name=zend_string_init(n,charstring::length(n),0);
 #else
@@ -364,6 +362,8 @@ static int sqlrcursorDescribe(pdo_stmt_t *stmt, int colno TSRMLS_DC) {
 	stmt->columns[colno].namelen=charstring::length(name);
 #endif
 	stmt->columns[colno].maxlen=sqlrcur->getColumnLength(colno);
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+	const char	*type=sqlrcur->getColumnType(colno);
 	if (isBitTypeChar(type) || isNumberTypeChar(type)) {
 		if (isFloatTypeChar(type)) {
 			#ifdef HAVE_PHP_PDO_PARAM_ZVAL
@@ -383,23 +383,31 @@ static int sqlrcursorDescribe(pdo_stmt_t *stmt, int colno TSRMLS_DC) {
 	} else {
 		stmt->columns[colno].param_type=PDO_PARAM_STR;
 	}
+#endif
 	stmt->columns[colno].precision=sqlrcur->getColumnPrecision(colno);
 	return 1;
 }
 
 static int sqlrcursorGetField(pdo_stmt_t *stmt,
 				int colno,
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 				char **ptr,
-#if PHP_MAJOR_VERSION >= 7
+	#if PHP_MAJOR_VERSION >= 7
 				size_t *len,
-#else
+	#else
 				unsigned long *len,
+	#endif
+				int *caller_frees TSRMLS_DC
+#else
+				zval *result,
+				enum pdo_param_type *coltype TSRMLS_DC
 #endif
-				int *caller_frees TSRMLS_DC) {
+				) {
 
 	sqlrstatement	*sqlrstmt=(sqlrstatement *)stmt->driver_data;
 	sqlrcursor	*sqlrcur=sqlrstmt->sqlrcur;
 
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 	*caller_frees=0;
 
 	switch (stmt->columns[colno].param_type) {
@@ -462,6 +470,75 @@ static int sqlrcursorGetField(pdo_stmt_t *stmt,
 		default:
 			return 1;
 	}
+#else
+	enum pdo_param_type ctype;
+
+	const char	*ptr=
+			sqlrcur->getField(sqlrstmt->currentrow,colno);
+	uint64_t	 len=
+			sqlrcur->getFieldLength(sqlrstmt->currentrow,colno);
+	const char	*type=sqlrcur->getColumnType(colno);
+
+	if (!len) {
+
+		// handle NULLs and empty strings
+		if (ptr) {
+			if (isBlobTypeChar(type)) {
+				// empty lobs must be sent as empty streams
+				php_stream	*strm=
+						php_stream_memory_create(
+							TEMP_STREAM_DEFAULT);
+				PHP_STREAM_TO_ZVAL_P(strm,result);
+				ctype=PDO_PARAM_LOB;
+			} else {
+				ZVAL_STRINGL(result,ptr,0);
+				ctype=PDO_PARAM_STR;
+			}
+		} else {
+			ZVAL_NULL(result);
+			ctype=PDO_PARAM_NULL;
+		}
+
+	} else {
+
+		if (isBitTypeChar(type) || isNumberTypeChar(type)) {
+			if (isFloatTypeChar(type)) {
+				// FIXME: is this correct, there is no
+				// PDO_PARAM_ZVAL or PDO_PARAM_DOUBLE,
+				// or should I just make a string out of it?
+				ZVAL_DOUBLE(result,
+					sqlrcur->getFieldAsDouble(
+						sqlrstmt->currentrow,colno));
+				ctype=PDO_PARAM_STR;
+			} else {
+				ZVAL_LONG(result,
+					sqlrcur->getFieldAsInteger(
+						sqlrstmt->currentrow,colno));
+				ctype=PDO_PARAM_INT;
+			}
+		} else if (isBlobTypeChar(type)) {
+			php_stream	*strm=php_stream_memory_create(
+							TEMP_STREAM_DEFAULT);
+			TSRMLS_FETCH();
+			php_stream_write(strm,ptr,len);
+			php_stream_seek(strm,0,SEEK_SET);
+			PHP_STREAM_TO_ZVAL_P(strm,result);
+			ctype=PDO_PARAM_LOB;
+		} else if (isBoolTypeChar(type)) {
+			ZVAL_BOOL(result,
+				(bool)sqlrcur->getFieldAsInteger(
+						sqlrstmt->currentrow,colno));
+			ctype=PDO_PARAM_BOOL;
+		} else {
+			ZVAL_STRINGL(result,ptr,len);
+			ctype=PDO_PARAM_STR;
+		}
+	}
+	if (coltype) {
+		*coltype=ctype;
+	}
+	return 1;
+#endif
 	return 1;
 }
 
@@ -950,11 +1027,20 @@ static struct pdo_stmt_methods sqlrcursorMethods={
 };
 
 
-static int sqlrconnectionClose(pdo_dbh_t *dbh TSRMLS_DC) {
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
+#else
+void
+#endif
+sqlrconnectionClose(pdo_dbh_t *dbh TSRMLS_DC) {
 	sqlrdbhandle	*sqlrdbh=(sqlrdbhandle *)dbh->driver_data;
 	delete sqlrdbh->sqlrcon;
 	dbh->is_closed=1;
+	#if PHP_MAJOR_VERSION < 8 || \
+		(PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 	return 0;
+	#endif
 }
 
 static void sqlrconnectionRewriteQuery(sqlrconnection *sqlrcon,
@@ -1079,14 +1165,25 @@ static void sqlrconnectionRewriteQuery(sqlrconnection *sqlrcon,
 	} while (ptr<endptr);
 }
 
-static int sqlrconnectionPrepare(pdo_dbh_t *dbh, const char *sql,
-#if PHP_MAJOR_VERSION >= 7
-					size_t sqllen,
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
 #else
-					long sqllen,
+bool
 #endif
-					pdo_stmt_t *stmt,
-					zval *driveroptions TSRMLS_DC) {
+sqlrconnectionPrepare(pdo_dbh_t *dbh,
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+				const char *sql,
+	#if PHP_MAJOR_VERSION >= 7
+				size_t sqllen,
+	#else
+				long sqllen,
+	#endif
+#else
+				zend_string *zsql,
+#endif
+				pdo_stmt_t *stmt,
+				zval *driveroptions TSRMLS_DC) {
 
 	sqlrdbhandle	*sqlrdbh=(sqlrdbhandle *)dbh->driver_data;
 	sqlrstatement	*sqlrstmt=new sqlrstatement;
@@ -1136,6 +1233,11 @@ static int sqlrconnectionPrepare(pdo_dbh_t *dbh, const char *sql,
 	// hopefully this is ok.
 	stmt->supports_placeholders=PDO_PLACEHOLDER_POSITIONAL;
 
+#if PHP_MAJOR_VERSION > 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION >= 1)
+	const char	*sql=ZSTR_VAL(zsql);
+	size_t		sqllen=ZSTR_LEN(zsql);
+#endif
+
 	if (sqlrdbh->usesubvars) {
 		sqlrconnectionRewriteQuery(sqlrdbh->sqlrcon,sql,sqllen,
 							&sqlrstmt->subvarquery);
@@ -1151,7 +1253,12 @@ static int sqlrconnectionPrepare(pdo_dbh_t *dbh, const char *sql,
 	if (!charstring::isNullOrEmpty(sql)) {
 		sqlrstmt->sqlrcur->prepareQuery(sql,sqllen);
 	}
+
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 	return 1;
+#else
+	return true;
+#endif
 }
 
 static
@@ -1161,13 +1268,23 @@ zend_long
 long
 #endif
 sqlrconnectionExecute(pdo_dbh_t *dbh,
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 					const char *sql,
-#if PHP_MAJOR_VERSION >= 7
+	#if PHP_MAJOR_VERSION >= 7
 					size_t sqllen TSRMLS_DC
-#else
+	#else
 					long sqllen TSRMLS_DC
+	#endif
+#else
+					const zend_string *zsql TSRMLS_DC
 #endif
 					) {
+
+#if PHP_MAJOR_VERSION > 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION >= 1)
+	const char	*sql=ZSTR_VAL(zsql);
+	size_t		sqllen=ZSTR_LEN(zsql);
+#endif
+
 	sqlrdbhandle	*sqlrdbh=(sqlrdbhandle *)dbh->driver_data;
 	sqlrcursor	sqlrcur((sqlrconnection *)sqlrdbh->sqlrcon);
 	if (sqlrcur.sendQuery(sql,sqllen)) {
@@ -1177,18 +1294,28 @@ sqlrconnectionExecute(pdo_dbh_t *dbh,
 	return -1;
 }
 
-static int sqlrconnectionQuote(pdo_dbh_t *dbh,
-					const char *unquoted,
-#if PHP_MAJOR_VERSION >= 7
-					size_t unquotedlen,
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
 #else
-					int unquotedlen,
+zend_string *
 #endif
+sqlrconnectionQuote(pdo_dbh_t *dbh,
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+					const char *unquoted,
+	#if PHP_MAJOR_VERSION >= 7
+					size_t unquotedlen,
+	#else
+					int unquotedlen,
+	#endif
 					char **quoted,
-#if PHP_MAJOR_VERSION >= 7
+	#if PHP_MAJOR_VERSION >= 7
 					size_t *quotedlen,
-#else
+	#else
 					int *quotedlen,
+	#endif
+#else
+					const zend_string *zunquoted,
 #endif
 					enum pdo_param_type paramtype TSRMLS_DC
 					) {
@@ -1199,10 +1326,22 @@ static int sqlrconnectionQuote(pdo_dbh_t *dbh,
 	int	i;
 #endif
 
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 	// fail if quoted/quotedlen weren't provided
 	if (!quoted || !quotedlen) {
 		return 0;
 	}
+#else
+	const char	*unquoted=ZSTR_VAL(zunquoted);
+	size_t		unquotedlen=ZSTR_LEN(zunquoted);
+
+	// this is awkward, but it allows us to use
+	// the exisiting code below with PHP 8.1+
+	char	*q=NULL;
+	size_t	qlen=0;
+	char	**quoted=&q;
+	size_t	*quotedlen=&qlen;
+#endif
 
 	// determine size of new string
 	*quotedlen=unquotedlen+2;
@@ -1231,10 +1370,21 @@ static int sqlrconnectionQuote(pdo_dbh_t *dbh,
 	ptr++;
 	*ptr='\0';
 
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 	return 1;
+#else
+	// FIXME: free q?
+	return zend_string_init(q,qlen,0);
+#endif
 }
 
-static int sqlrconnectionBegin(pdo_dbh_t *dbh TSRMLS_DC) {
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
+#else
+bool
+#endif
+sqlrconnectionBegin(pdo_dbh_t *dbh TSRMLS_DC) {
 	sqlrdbhandle	*sqlrdbh=(sqlrdbhandle *)dbh->driver_data;
 	if (((sqlrconnection *)sqlrdbh->sqlrcon)->begin()) {
 		return 1;
@@ -1243,7 +1393,13 @@ static int sqlrconnectionBegin(pdo_dbh_t *dbh TSRMLS_DC) {
 	return 0;
 }
 
-static int sqlrconnectionCommit(pdo_dbh_t *dbh TSRMLS_DC) {
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
+#else
+bool
+#endif
+sqlrconnectionCommit(pdo_dbh_t *dbh TSRMLS_DC) {
 	sqlrdbhandle	*sqlrdbh=(sqlrdbhandle *)dbh->driver_data;
 	if (((sqlrconnection *)sqlrdbh->sqlrcon)->commit()) {
 		return 1;
@@ -1252,7 +1408,13 @@ static int sqlrconnectionCommit(pdo_dbh_t *dbh TSRMLS_DC) {
 	return 0;
 }
 
-static int sqlrconnectionRollback(pdo_dbh_t *dbh TSRMLS_DC) { 
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
+#else
+bool
+#endif
+sqlrconnectionRollback(pdo_dbh_t *dbh TSRMLS_DC) { 
 	sqlrdbhandle	*sqlrdbh=(sqlrdbhandle *)dbh->driver_data;
 	if (((sqlrconnection *)sqlrdbh->sqlrcon)->rollback()) {
 		return 1;
@@ -1261,7 +1423,13 @@ static int sqlrconnectionRollback(pdo_dbh_t *dbh TSRMLS_DC) {
 	return 0;
 }
 
-static int sqlrconnectionSetAttribute(pdo_dbh_t *dbh,
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
+#else
+bool
+#endif
+sqlrconnectionSetAttribute(pdo_dbh_t *dbh,
 #if PHP_MAJOR_VERSION >= 7
 					zend_long attr,
 #else
@@ -1295,7 +1463,6 @@ static int sqlrconnectionSetAttribute(pdo_dbh_t *dbh,
 			// all timeouts in seconds
 			convert_to_long(val);
 			sqlrcon->setConnectTimeout(Z_LVAL_P(val),0);
-			sqlrcon->setAuthenticationTimeout(Z_LVAL_P(val),0);
 			sqlrcon->setResponseTimeout(Z_LVAL_P(val),0);
 			return 1;
 	        case PDO_SQLRELAY_ATTR_CONNECTION_TIMEOUT:
@@ -1303,11 +1470,6 @@ static int sqlrconnectionSetAttribute(pdo_dbh_t *dbh,
 			convert_to_long(val);
 			sqlrcon->setConnectTimeout(Z_LVAL_P(val),0);
 			return 1;
-	        case PDO_SQLRELAY_ATTR_AUTHENTICATION_TIMEOUT:
-			// authentication timeout in seconds
-			convert_to_long(val);
-			sqlrcon->setAuthenticationTimeout(Z_LVAL_P(val),0);
-			return 1;
 	        case PDO_SQLRELAY_ATTR_RESPONSE_TIMEOUT:
 			// cresponse timeout in seconds
 			convert_to_long(val);
@@ -1370,26 +1532,45 @@ static int sqlrconnectionSetAttribute(pdo_dbh_t *dbh,
 	}
 }
 
-static char *sqlrconnectionLastInsertId(pdo_dbh_t *dbh,
-					const char *name,
-#if PHP_MAJOR_VERSION >= 7
-					size_t *len TSRMLS_DC
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+char *
 #else
+zend_string *
+#endif
+sqlrconnectionLastInsertId(pdo_dbh_t *dbh,
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+					const char *name,
+	#if PHP_MAJOR_VERSION >= 7
+					size_t *len TSRMLS_DC
+	#else
 					unsigned int *len TSRMLS_DC
+	#endif
+#else
+					const zend_string *name TSRMLS_DC
 #endif
 					) {
 	sqlrdbhandle	*sqlrdbh=(sqlrdbhandle *)dbh->driver_data;
-	char	*id=php_pdo_int64_to_str(
-				((sqlrconnection *)sqlrdbh->sqlrcon)->
-							getLastInsertId()
-				TSRMLS_CC);
-	*len=charstring::length(id);
+	uint64_t	lastid=((sqlrconnection *)sqlrdbh->sqlrcon)->
+							getLastInsertId();
+	uint16_t	idlen=charstring::integerLength(lastid)+1;
+	char		*id=(char *)safe_emalloc(idlen,sizeof(char),0);
+	charstring::printf(id,idlen,"%lld",lastid);
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+	*len=idlen;
 	return id;
+#else
+	return zend_string_init(id,charstring::length(id),0);
+#endif
 }
 
-static int sqlrconnectionError(pdo_dbh_t *dbh,
-					pdo_stmt_t *stmt,
-					zval *info TSRMLS_DC) {
+static
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
+int
+#else
+void
+#endif
+sqlrconnectionError(pdo_dbh_t *dbh, pdo_stmt_t *stmt, zval *info TSRMLS_DC) {
 
 	// FIXME: the first index in the info array should be the sqlstate
 	// currently we're leaving it at HY000 but it really ought to be
@@ -1417,7 +1598,9 @@ static int sqlrconnectionError(pdo_dbh_t *dbh,
 			ADD_NEXT_INDEX_STRING_P(info,msg);
 		}
 	}
+#if PHP_MAJOR_VERSION < 8 || (PHP_MAJOR_VERSION == 8 && PHP_MINOR_VERSION < 1)
 	return 1;
+#endif
 }
 
 static int sqlrconnectionGetAttribute(pdo_dbh_t *dbh,
@@ -1451,12 +1634,6 @@ static int sqlrconnectionGetAttribute(pdo_dbh_t *dbh,
 			timeout=timeoutsec+timeoutusec*1.0E-6;
 			ZVAL_DOUBLE(retval,timeout);
 			return 1;
-		case PDO_SQLRELAY_ATTR_AUTHENTICATION_TIMEOUT:
-			sqlrcon->getAuthenticationTimeout(&timeoutsec,
-								&timeoutusec);
-			timeout=timeoutsec+timeoutusec*1.0E-6;
-			ZVAL_DOUBLE(retval,timeout);
-			return 1;
 		case PDO_ATTR_TIMEOUT:
 			// Generic timeout. The closest concept would be the
 			// response timeout, so just fall through to that.
@@ -1978,8 +2155,6 @@ static PHP_MINIT_FUNCTION(pdo_sqlrelay) {
 				(long)PDO_SQLRELAY_ATTR_CURRENT_DB);
 	REGISTER_PDO_CLASS_CONST_LONG("SQLRELAY_ATTR_CONNECTION_TIMEOUT",
 				(long)PDO_SQLRELAY_ATTR_CONNECTION_TIMEOUT);
-	REGISTER_PDO_CLASS_CONST_LONG("SQLRELAY_ATTR_AUTHENTICATION_TIMEOUT",
-				(long)PDO_SQLRELAY_ATTR_AUTHENTICATION_TIMEOUT);
 	REGISTER_PDO_CLASS_CONST_LONG("SQLRELAY_ATTR_RESPONSE_TIMEOUT",
 				(long)PDO_SQLRELAY_ATTR_RESPONSE_TIMEOUT);
 	REGISTER_PDO_CLASS_CONST_LONG("SQLRELAY_ATTR_SQLRELAY_VERSION",
