@@ -17,7 +17,11 @@
 
 #if PY_MAJOR_VERSION >= 3
 	#define PyString_Check PyUnicode_Check
+#if PY_MINOR_VERSION >= 3
 	#define PyString_AsString(a) PyUnicode_AsUTF8AndSize(a,NULL)
+#else
+	#define PyString_AsString(a) PyBytes_AS_STRING(PyUnicode_AsEncodedString(a,"utf-8","strict"))
+#endif
 	#define PyInt_Check PyLong_Check
 	#define PyInt_AsLong PyLong_AsLong
 #endif
@@ -25,11 +29,11 @@
 
 extern "C" {
 
-#define NEED_IS_NUMBER_TYPE_CHAR
-#define NEED_IS_FLOAT_TYPE_CHAR
-#define NEED_IS_BIT_TYPE_CHAR
-#define NEED_BIT_STRING_TO_LONG
-#define NEED_IS_BOOL_TYPE_CHAR
+#define NEED_IS_NUMBER_TYPE_CHAR 1
+#define NEED_IS_FLOAT_TYPE_CHAR 1
+#define NEED_IS_BIT_TYPE_CHAR 1
+#define NEED_BIT_STRING_TO_LONG 1
+#define NEED_IS_BOOL_TYPE_CHAR 1
 #include <datatypes.h>
 
 bool usenumeric=false;
@@ -108,6 +112,52 @@ static PyObject *setResponseTimeout(PyObject *self, PyObject *args) {
   return Py_BuildValue("h", 0);
 }
 
+static PyObject *setBindVariableDelimiters(PyObject *self, PyObject *args) {
+  long sqlrcon;
+  char *delimiters;
+  if (!PyArg_ParseTuple(args, "ls", &sqlrcon, &delimiters))
+    return NULL;
+  ((sqlrconnection *)sqlrcon)->setBindVariableDelimiters(delimiters);
+  return Py_BuildValue("h", 0);
+}
+
+static PyObject *getBindVariableDelimiterQuestionMarkSupported(
+					PyObject *self, PyObject *args) {
+  long sqlrcon;
+  bool rc;
+  if (!PyArg_ParseTuple(args, "l", &sqlrcon))
+    return NULL;
+  rc=((sqlrconnection *)sqlrcon)->getBindVariableDelimiterQuestionMarkSupported();
+  return Py_BuildValue("h", (short)rc);
+}
+
+static PyObject *getBindVariableDelimiterColonSupported(PyObject *self, PyObject *args) {
+  long sqlrcon;
+  bool rc;
+  if (!PyArg_ParseTuple(args, "l", &sqlrcon))
+    return NULL;
+  rc=((sqlrconnection *)sqlrcon)->getBindVariableDelimiterColonSupported();
+  return Py_BuildValue("h", (short)rc);
+}
+
+static PyObject *getBindVariableDelimiterAtSignSupported(PyObject *self, PyObject *args) {
+  long sqlrcon;
+  bool rc;
+  if (!PyArg_ParseTuple(args, "l", &sqlrcon))
+    return NULL;
+  rc=((sqlrconnection *)sqlrcon)->getBindVariableDelimiterAtSignSupported();
+  return Py_BuildValue("h", (short)rc);
+}
+
+static PyObject *getBindVariableDelimiterDollarSignSupported(PyObject *self, PyObject *args) {
+  long sqlrcon;
+  bool rc;
+  if (!PyArg_ParseTuple(args, "l", &sqlrcon))
+    return NULL;
+  rc=((sqlrconnection *)sqlrcon)->getBindVariableDelimiterDollarSignSupported();
+  return Py_BuildValue("h", (short)rc);
+}
+
 static PyObject *enableKerberos(PyObject *self, PyObject *args) {
   long sqlrcon;
   char *service;
@@ -456,6 +506,24 @@ static PyObject *getClientInfo(PyObject *self, PyObject *args) {
   return Py_BuildValue("s", rc);
 }
 
+static PyObject *isYes(PyObject *self, PyObject *args) {
+  char *str;
+  bool rc;
+  if (!PyArg_ParseTuple(args, "s", &str))
+    return NULL;
+  rc=charstring::isYes(str);
+  return Py_BuildValue("h", (short)rc);
+}
+
+static PyObject *isNo(PyObject *self, PyObject *args) {
+  char *str;
+  bool rc;
+  if (!PyArg_ParseTuple(args, "s", &str))
+    return NULL;
+  rc=charstring::isNo(str);
+  return Py_BuildValue("h", (short)rc);
+}
+
 static PyObject *sqlrcur_alloc(PyObject *self, PyObject *args) {
   long	sqlrcon;
   sqlrcursor *sqlrcur;
@@ -736,7 +804,7 @@ static PyObject *substitutions(PyObject *self, PyObject *args) {
   PyObject *precisions;
   PyObject *scales;
   long sqlrcur;
-  char *variable;
+  const char *variable;
   uint16_t success;
   PyObject *value;
   if (!PyArg_ParseTuple(args, "lOOOO", &sqlrcur, &variables, &values, &precisions, &scales))
@@ -876,7 +944,7 @@ static PyObject *inputBinds(PyObject *self, PyObject *args) {
   PyObject *precisions;
   PyObject *scales;
   long sqlrcur;
-  char *variable;
+  const char *variable;
   uint16_t success;
   PyObject *value;
   if (!PyArg_ParseTuple(args, "lOOOO", &sqlrcur, &variables, &values, &precisions, &scales))
@@ -1194,17 +1262,21 @@ static PyObject *getField(PyObject *self, PyObject *args) {
 #endif
 	&sqlrcur, &row, &col))
     return NULL;
-  Py_BEGIN_ALLOW_THREADS
   if (PyString_Check(col)) {
-    rc=((sqlrcursor *)sqlrcur)->getField(row, PyString_AsString(col));
-    rl=((sqlrcursor *)sqlrcur)->getFieldLength(row, PyString_AsString(col));
-    type = ((sqlrcursor *)sqlrcur)->getColumnType(PyString_AsString(col));
+    const char *colname=PyString_AsString(col);
+    Py_BEGIN_ALLOW_THREADS
+    rc=((sqlrcursor *)sqlrcur)->getField(row, colname);
+    rl=((sqlrcursor *)sqlrcur)->getFieldLength(row, colname);
+    type = ((sqlrcursor *)sqlrcur)->getColumnType(colname);
+    Py_END_ALLOW_THREADS
   } else if (PyInt_Check(col)) {
-    rc=((sqlrcursor *)sqlrcur)->getField(row, PyInt_AsLong(col));
-    rl=((sqlrcursor *)sqlrcur)->getFieldLength(row, PyInt_AsLong(col));
-    type = ((sqlrcursor *)sqlrcur)->getColumnType(PyInt_AsLong(col));
+    uint32_t colind=PyInt_AsLong(col);
+    Py_BEGIN_ALLOW_THREADS
+    rc=((sqlrcursor *)sqlrcur)->getField(row, colind);
+    rl=((sqlrcursor *)sqlrcur)->getFieldLength(row, colind);
+    type = ((sqlrcursor *)sqlrcur)->getColumnType(colind);
+    Py_END_ALLOW_THREADS
   }
-  Py_END_ALLOW_THREADS
   if (!rc) {
     Py_INCREF(Py_None);
     return Py_None;
@@ -1214,7 +1286,7 @@ static PyObject *getField(PyObject *self, PyObject *args) {
       PyTuple_SetItem(tuple, 0, Py_BuildValue("s#", rc, rl));
       return PyObject_CallObject(decimal, tuple);
     } else {
-      return Py_BuildValue("f",(double)charstring::toFloat(rc));
+      return Py_BuildValue("f",(double)charstring::toFloatC(rc));
     }
   } else if (usenumeric && isNumberTypeChar(type)) {
     return Py_BuildValue("L",charstring::toInteger(rc));
@@ -1295,13 +1367,17 @@ static PyObject *getFieldLength(PyObject *self, PyObject *args) {
 #endif
 	&sqlrcur, &row, &col))
     return NULL;
-  Py_BEGIN_ALLOW_THREADS
   if (PyString_Check(col)) {
-    rc=((sqlrcursor *)sqlrcur)->getFieldLength(row, PyString_AsString(col));
+    const char *colname=PyString_AsString(col);
+    Py_BEGIN_ALLOW_THREADS
+    rc=((sqlrcursor *)sqlrcur)->getFieldLength(row, colname);
+    Py_END_ALLOW_THREADS
   } else if (PyInt_Check(col)) {
-    rc=((sqlrcursor *)sqlrcur)->getFieldLength(row, PyInt_AsLong(col));
+    uint32_t colind=PyInt_AsLong(col);
+    Py_BEGIN_ALLOW_THREADS
+    rc=((sqlrcursor *)sqlrcur)->getFieldLength(row, colind);
+    Py_END_ALLOW_THREADS
   }
-  Py_END_ALLOW_THREADS
   // FIXME: lame, python doesn't support building values from uint32_t's
   return Py_BuildValue("l", (long)rc);
 }
@@ -1337,7 +1413,7 @@ _get_row(sqlrcursor *sqlrcur, uint64_t row)
         PyTuple_SetItem(tuple, 0, Py_BuildValue("s#", row_data[counter], row_lengths[counter]));
         obj=PyObject_CallObject(decimal, tuple);
       } else {
-        obj=Py_BuildValue("f", (double)charstring::toFloat(row_data[counter]));
+        obj=Py_BuildValue("f", (double)charstring::toFloatC(row_data[counter]));
       }
       PyList_SetItem(my_list, counter, obj);
     } else if (usenumeric && isNumberTypeChar(type)) {
@@ -1408,7 +1484,7 @@ static PyObject *getRowDictionary(PyObject *self, PyObject *args) {
           PyTuple_SetItem(tuple, 0, Py_BuildValue("s", field));
           PyDict_SetItem(my_dictionary, Py_BuildValue("s", name), PyObject_CallObject(decimal, tuple));
         } else {
-          PyDict_SetItem(my_dictionary, Py_BuildValue("s", name), Py_BuildValue("f",(double)charstring::toFloat(field)));
+          PyDict_SetItem(my_dictionary, Py_BuildValue("s", name), Py_BuildValue("f",(double)charstring::toFloatC(field)));
         }
     } else if (usenumeric && isNumberTypeChar(type)) {
       PyDict_SetItem(my_dictionary, Py_BuildValue("s", name), Py_BuildValue("L", charstring::toInteger(field)));
@@ -1508,6 +1584,8 @@ static PyObject *getRowLengthsDictionary(PyObject *self, PyObject *args) {
   long sqlrcur;
   uint64_t row;
   PyObject *my_dictionary;
+  const char *name;
+  long fieldlength;
   if (!PyArg_ParseTuple(args,
 #ifdef SUPPORTS_UNSIGNED
 	"lK",
@@ -1518,12 +1596,19 @@ static PyObject *getRowLengthsDictionary(PyObject *self, PyObject *args) {
     return NULL;
   my_dictionary=PyDict_New();
   for (uint32_t counter=0; counter<((sqlrcursor *)sqlrcur)->colCount(); counter++) {
+    // Don't be tempted to embed this call inside of PyDict_SetItem.  Since
+    // it might have to fetch data from the server, it needs to be embedded
+    // in Py_BEGIN/END_ALLOW_THREADS.  On some platforms, embedding the entire
+    // PyDict_SetItem() call works, but on some, it doesn't.  I'm not sure
+    // why, exactly, but that's the case.  It's safe to call getColumnName()
+    // outside of Py_BEGIN/END_ALLOW_THREADS because it will never have to
+    // talk to the server.  It could be embedded in PyDict_SetItem, but I'll
+    // do it this way for consistency with getRowDictionary().
     Py_BEGIN_ALLOW_THREADS
-    PyDict_SetItem(my_dictionary,
-        Py_BuildValue("s",((sqlrcursor *)sqlrcur)->getColumnName(counter)),
-        // FIXME: lame, python doesn't support building values from uint32_t's
-        Py_BuildValue("l",(long)((sqlrcursor *)sqlrcur)->getFieldLength(row,counter)));
+    fieldlength=(long)((sqlrcursor *)sqlrcur)->getFieldLength(row,counter);
     Py_END_ALLOW_THREADS
+    name=((sqlrcursor *)sqlrcur)->getColumnName(counter);
+    PyDict_SetItem(my_dictionary,Py_BuildValue("s",name),Py_BuildValue("l",fieldlength));
   }
   return my_dictionary;
 }
@@ -1893,6 +1978,11 @@ static PyMethodDef SQLRMethods[] = {
   {"setConnectTimeout", setConnectTimeout, METH_VARARGS},
   {"setAuthenticationTimeout", setAuthenticationTimeout, METH_VARARGS},
   {"setResponseTimeout", setResponseTimeout, METH_VARARGS},
+  {"setBindVariableDelimiters", setBindVariableDelimiters, METH_VARARGS},
+  {"getBindVariableDelimiterQuestionMarkSupported", getBindVariableDelimiterQuestionMarkSupported, METH_VARARGS},
+  {"getBindVariableDelimiterColonSupported", getBindVariableDelimiterColonSupported, METH_VARARGS},
+  {"getBindVariableDelimiterAtSignSupported", getBindVariableDelimiterAtSignSupported, METH_VARARGS},
+  {"getBindVariableDelimiterDollarSignSupported", getBindVariableDelimiterDollarSignSupported, METH_VARARGS},
   {"enableKerberos", enableKerberos, METH_VARARGS},
   {"enableTls", enableTls, METH_VARARGS},
   {"disableEncryption", disableEncryption, METH_VARARGS},
@@ -1925,6 +2015,8 @@ static PyMethodDef SQLRMethods[] = {
   {"setDebugFile", setDebugFile, METH_VARARGS},
   {"setClientInfo", setClientInfo, METH_VARARGS},
   {"getClientInfo", getClientInfo, METH_VARARGS},
+  {"isYes", isYes, METH_VARARGS},
+  {"isNo", isNo, METH_VARARGS},
   {"sqlrcur_alloc",  sqlrcur_alloc, METH_VARARGS},
   {"sqlrcur_free",  sqlrcur_free, METH_VARARGS},
   {"setResultSetBufferSize", setResultSetBufferSize, METH_VARARGS},
