@@ -1,12 +1,14 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
 #include <rudiments/bytestring.h>
 #include <rudiments/regularexpression.h>
+#include <rudiments/file.h>
 #include <rudiments/sys.h>
 
 #include <datatypes.h>
+#include <defines.h>
 #include <config.h>
 
 extern "C" {
@@ -37,6 +39,8 @@ class SQLRSERVER_DLLSPEC mdbtoolsconnection : public sqlrserverconnection {
 		void	logOut();
 		bool	isTransactional();
 		bool	ping();
+		bool	selectDatabase(const char *database);
+		char	*getCurrentDatabase();
 		const char	*identify();
 		const char	*dbVersion();
 		const char	*dbHostName();
@@ -44,13 +48,16 @@ class SQLRSERVER_DLLSPEC mdbtoolsconnection : public sqlrserverconnection {
 		bool	getDatabaseList(sqlrservercursor *cursor,
 						const char *wild);
 		bool	getTableList(sqlrservercursor *cursor,
-						const char *wild);
+						const char *wild,
+						uint16_t objecttypes);
 		bool	getColumnList(sqlrservercursor *cursor,
 						const char *table,
 						const char *wild);
 		bool	setIsolationLevel(const char *isolevel);
+		const char	*noopQuery();
 		bool	autoCommitOn();
 		bool	autoCommitOff();
+		bool	supportsAutoCommit();
 		bool	commit();
 		bool	rollback();
 		void	errorMessage(char *errorbuffer,
@@ -59,9 +66,8 @@ class SQLRSERVER_DLLSPEC mdbtoolsconnection : public sqlrserverconnection {
 					int64_t	*errorcode,
 					bool *liveconnection);
 
-		const char	*db;
+		char		*db;
 		const char	*identity;
-
 		char		*hostname;
 };
 
@@ -69,7 +75,8 @@ enum cursortype_t {
 	QUERY_CURSORTYPE=0,
 	DB_LIST_CURSORTYPE,
 	TABLE_LIST_CURSORTYPE,
-	COLUMN_LIST_CURSORTYPE
+	COLUMN_LIST_CURSORTYPE,
+	NOOP_CURSORTYPE
 };
 
 class SQLRSERVER_DLLSPEC mdbtoolscursor : public sqlrservercursor {
@@ -88,7 +95,7 @@ class SQLRSERVER_DLLSPEC mdbtoolscursor : public sqlrservercursor {
 		uint32_t	colCount();
 		const char	*getColumnName(uint32_t col);
 		bool		noRowsToReturn();
-		bool		fetchRow();
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 						const char **field,
 						uint64_t *fieldlength,
@@ -96,7 +103,8 @@ class SQLRSERVER_DLLSPEC mdbtoolscursor : public sqlrservercursor {
 						bool *null);
 		void		closeResultSet();
 		bool		getDatabaseList(const char *wild);
-		bool		getTableList(const char *wild);
+		bool		getTableList(const char *wild,
+						uint16_t objecttypes);
 		bool		getColumnList(const char *table,
 						const char *wild);
 		void		resetListValues(const char *wild);
@@ -121,22 +129,31 @@ class SQLRSERVER_DLLSPEC mdbtoolscursor : public sqlrservercursor {
 
 mdbtoolsconnection::mdbtoolsconnection(sqlrservercontroller *cont) :
 						sqlrserverconnection(cont) {
-	hostname=NULL;
+	db=NULL;
 	identity=NULL;
+	hostname=NULL;
 }
 
 mdbtoolsconnection::~mdbtoolsconnection() {
+	delete[] db;
 	delete[] hostname;
 }
 
 void mdbtoolsconnection::handleConnectString() {
-	db=cont->getConnectStringValue("db");
+
+	sqlrserverconnection::handleConnectString();
+
+	db=charstring::duplicate(cont->getConnectStringValue("db"));
 	identity=cont->getConnectStringValue("identity");
+
+	cont->setFetchAtOnce(1);
+	cont->setMaxColumnCount(0);
+	cont->setMaxFieldLength(0);
 }
 
 bool mdbtoolsconnection::logIn(const char **error, const char **warning) {
 	mdb_init_backends();
-	return true;
+	return file::exists(db);
 }
 
 sqlrservercursor *mdbtoolsconnection::newCursor(uint16_t id) {
@@ -158,6 +175,41 @@ bool mdbtoolsconnection::ping() {
 	return true;
 }
 
+bool mdbtoolsconnection::selectDatabase(const char *database) {
+
+	// keep track of the original db and host
+	char	*originaldb=db;
+
+	// reset the db/host
+	db=charstring::duplicate(database);
+
+	cont->clearError();
+
+	// log out and log back in to the specified database
+	logOut();
+	if (!logIn(NULL,NULL)) {
+
+		// Set the error.
+		cont->setError(SQLR_ERROR_DBNOTFOUND_STRING,
+				SQLR_ERROR_DBNOTFOUND,true);
+
+		// log back in to the original database, we'll assume that works
+		delete[] db;
+		db=originaldb;
+		logOut();
+		logIn(NULL,NULL);
+		return false;
+	}
+
+	// clean up
+	delete[] originaldb;
+	return true;
+}
+
+char *mdbtoolsconnection::getCurrentDatabase() {
+	return charstring::duplicate(db);
+}
+
 const char *mdbtoolsconnection::identify() {
 	return (identity)?identity:"mdbtools";
 }
@@ -187,8 +239,9 @@ bool mdbtoolsconnection::getDatabaseList(sqlrservercursor *cursor,
 }
 
 bool mdbtoolsconnection::getTableList(sqlrservercursor *cursor,
-						const char *wild) {
-	return ((mdbtoolscursor *)cursor)->getTableList(wild);
+						const char *wild,
+						uint16_t objecttypes) {
+	return ((mdbtoolscursor *)cursor)->getTableList(wild,objecttypes);
 }
 
 bool mdbtoolsconnection::getColumnList(sqlrservercursor *cursor,
@@ -206,6 +259,10 @@ bool mdbtoolsconnection::setIsolationLevel(const char *isolevel) {
 	return true;
 }
 
+const char *mdbtoolsconnection::noopQuery() {
+	return "noop";
+}
+
 bool mdbtoolsconnection::autoCommitOn() {
 	// do nothing
 	return true;
@@ -216,6 +273,11 @@ bool mdbtoolsconnection::autoCommitOff() {
 	return true;
 }
 
+bool mdbtoolsconnection::supportsAutoCommit() {
+	// fake this
+	return true;
+}
+
 bool mdbtoolsconnection::commit() {
 	// do nothing
 	return true;
@@ -296,6 +358,11 @@ bool mdbtoolscursor::supportsNativeBinds(const char *query, uint32_t length) {
 
 bool mdbtoolscursor::executeQuery(const char *query, uint32_t length) {
 
+	if (!charstring::compare(query,"noop")) {
+		cursortype=NOOP_CURSORTYPE;
+		return true;
+	}
+
 	cursortype=QUERY_CURSORTYPE;
 
 	// execute the query
@@ -325,7 +392,7 @@ bool mdbtoolscursor::getDatabaseList(const char *wild) {
 	return true;
 }
 
-bool mdbtoolscursor::getTableList(const char *wild) {
+bool mdbtoolscursor::getTableList(const char *wild, uint16_t objecttypes) {
 
 	cursortype=TABLE_LIST_CURSORTYPE;
 
@@ -445,7 +512,9 @@ bool mdbtoolscursor::knowsAffectedRows() {
 }
 
 uint32_t mdbtoolscursor::colCount() {
-	if (cursortype==QUERY_CURSORTYPE) {
+	if (cursortype==NOOP_CURSORTYPE) {
+		return 0;
+	} else if (cursortype==QUERY_CURSORTYPE) {
 		return ((MdbSQL *)mdbsql)->num_columns;
 	} else if (cursortype==COLUMN_LIST_CURSORTYPE) {
 		return 5;
@@ -464,6 +533,8 @@ const char *mdbtoolscursor::getColumnName(uint32_t col) {
 	} else if (cursortype==TABLE_LIST_CURSORTYPE) {
 		if (col==0) {
 			return "TABLE";
+		} else if (col==1) {
+			return "TYPE";
 		}
 	} else if (cursortype==COLUMN_LIST_CURSORTYPE) {
 		switch (col) {
@@ -483,8 +554,9 @@ const char *mdbtoolscursor::getColumnName(uint32_t col) {
 }
 
 bool mdbtoolscursor::noRowsToReturn() {
-
-	if (cursortype==QUERY_CURSORTYPE) {
+	if (cursortype==NOOP_CURSORTYPE) {
+		return true;
+	} else if (cursortype==QUERY_CURSORTYPE) {
 		// if there were no columns then there can be no rows
 		return (((MdbSQL *)mdbsql)->num_columns==0);
 	} else if (cursortype==DB_LIST_CURSORTYPE) {
@@ -497,7 +569,13 @@ bool mdbtoolscursor::noRowsToReturn() {
 	return true;
 }
 
-bool mdbtoolscursor::fetchRow() {
+bool mdbtoolscursor::fetchRow(bool *error) {
+
+	*error=false;
+
+	if (cursortype==NOOP_CURSORTYPE) {
+		return false;
+	}
 	if (cursortype==QUERY_CURSORTYPE) {
 		#ifdef HAVE_MDB_SQL_FETCH_ROW
 			return mdb_sql_fetch_row((MdbSQL *)mdbsql,
@@ -596,7 +674,7 @@ void mdbtoolscursor::getField(uint32_t col,
 				} else {
 					*null=true;
 				}
-				return;
+				break;
 			}
 		}
 
@@ -609,6 +687,9 @@ void mdbtoolscursor::getField(uint32_t col,
 		if (col==0 && currenttable) {
 			*field=currenttable->object_name;
 			*fieldlength=charstring::length(*field);
+		} else if (col==1 && currenttable) {
+			*field="TABLE";
+			*fieldlength=5;
 		}
 	} else if (cursortype==COLUMN_LIST_CURSORTYPE) {
 		*field=NULL;
