@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2014  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -7,40 +7,161 @@
 
 #include <defines.h>
 
+#define FETCH_AT_ONCE		10
+#define MAX_COLUMN_COUNT	256
+#define MAX_FIELD_LENGTH	32768	
+#define MAX_OUT_BIND_LOB_SIZE	2097152
+
+class sqlrserverconnectionprivate {
+	friend class sqlrserverconnection;
+
+		uint32_t	_maxquerysize;
+		uint32_t	_maxerrorlength;
+
+		char		*_error;
+		uint32_t	_errorlength;
+		int64_t		_errnum;
+		bool		_liveconnection;
+
+		char		*_dbhostname;
+		char		*_dbipaddress;
+		uint32_t	_dbhostiploop;
+
+		bool		_detachbeforelogin;
+
+		stringbuffer	_tablelistquery;
+};
+
 sqlrserverconnection::sqlrserverconnection(sqlrservercontroller *cont) {
 
+	pvt=new sqlrserverconnectionprivate;
+
 	this->cont=cont;
 
-	maxquerysize=cont->cfg->getMaxQuerySize();
-	maxerrorlength=cont->cfg->getMaxErrorLength();
+	pvt->_maxquerysize=cont->getConfig()->getMaxQuerySize();
+	pvt->_maxerrorlength=cont->getConfig()->getMaxErrorLength();
 
-	error=new char[maxerrorlength+1];
-	errorlength=0;
-	errnum=0;
-	liveconnection=false;
+	pvt->_error=new char[pvt->_maxerrorlength+1];
+	pvt->_errorlength=0;
+	pvt->_errnum=0;
+	pvt->_liveconnection=false;
 
-	autocommit=false;
-	fakeautocommit=false;
+	pvt->_dbhostname=NULL;
+	pvt->_dbipaddress=NULL;
+	pvt->_dbhostiploop=0;
 
-	dbhostname=NULL;
-	dbipaddress=NULL;
-	dbhostiploop=0;
+	pvt->_detachbeforelogin=false;
 }
 
 sqlrserverconnection::~sqlrserverconnection() {
-	delete[] error;
-	delete[] dbhostname;
-	delete[] dbipaddress;
+	delete[] pvt->_error;
+	delete[] pvt->_dbhostname;
+	delete[] pvt->_dbipaddress;
+	delete pvt;
 }
 
 bool sqlrserverconnection::mustDetachBeforeLogIn() {
-	return false;
+	return pvt->_detachbeforelogin;
 }
 
 bool sqlrserverconnection::supportsAuthOnDatabase() {
 	return true;
 }
 
+void sqlrserverconnection::handleConnectString() {
+
+	// get some parameters that are common to most db's
+
+	// user and password
+	cont->setUser(cont->getConnectStringValue("user"));
+	cont->setPassword(cont->getConnectStringValue("password"));
+
+	// autocommit
+	cont->setInitialAutoCommit(charstring::isYes(
+			cont->getConnectStringValue("autocommit")));
+
+	// fake transaction blocks
+	cont->setFakeTransactionBlocks(charstring::isYes(
+			cont->getConnectStringValue("faketransactionblocks")));
+
+	// fake binds
+	if (charstring::isYes(cont->getConnectStringValue("fakebinds"))) {
+		cont->setFakeInputBinds(true);
+	}
+
+	// rows to fetch-at-once
+	uint32_t	fetchatonce=FETCH_AT_ONCE;
+	const char	*fao=cont->getConnectStringValue("fetchatonce");
+	if (fao) {
+		fetchatonce=charstring::toUnsignedInteger(fao);
+		if (fetchatonce<1) {
+			fetchatonce=1;
+		}
+	}
+	cont->setFetchAtOnce(fetchatonce);
+
+	// max column count
+	int32_t		maxcolumncount=MAX_COLUMN_COUNT;
+	const char	*mcc=cont->getConnectStringValue("maxcolumncount");
+	if (!mcc) {
+		mcc=cont->getConnectStringValue("maxselectlistsize");
+	}
+	if (mcc) {
+		maxcolumncount=charstring::toInteger(mcc);
+		if (maxcolumncount<0) {
+			maxcolumncount=0;
+		}
+	}
+	cont->setMaxColumnCount(maxcolumncount);
+
+	// max field length
+	int32_t		maxfieldlength=MAX_FIELD_LENGTH;
+	const char	*mfl=cont->getConnectStringValue("maxfieldlength");
+	if (!mfl) {
+		mfl=cont->getConnectStringValue("maxitembuffersize");
+	}
+	if (mfl) {
+		maxfieldlength=charstring::toInteger(mfl);
+		if (maxfieldlength<0) {
+			maxfieldlength=0;
+		}
+	}
+	cont->setMaxFieldLength(maxfieldlength);
+
+	// connect timeout
+	int64_t		connecttimeout=0;
+	const char	*cto=cont->getConnectStringValue("connecttimeout");
+	if (!cto) {
+		cto=cont->getConnectStringValue("timeout");
+	}
+	if (cto) {
+		connecttimeout=charstring::toInteger(cto);
+		if (connecttimeout<0) {
+			connecttimeout=0;
+		}
+	}
+	cont->setConnectTimeout(connecttimeout);
+
+	// query timeout
+	int64_t		querytimeout=0;
+	const char	*qto=cont->getConnectStringValue("querytimeout");
+	if (qto) {
+		querytimeout=charstring::toInteger(qto);
+		if (querytimeout<0) {
+			querytimeout=0;
+		}
+	}
+	cont->setQueryTimeout(querytimeout);
+
+	// execute-direct
+	cont->setExecuteDirect(charstring::isYes(
+			cont->getConnectStringValue("executedirect")));
+
+	// detach before login
+	pvt->_detachbeforelogin=charstring::isYes(
+			cont->getConnectStringValue("detachbeforelogin"));
+}
+
 bool sqlrserverconnection::changeUser(const char *newuser,
 						const char *newpassword) {
 	return cont->changeUser(newuser,newpassword);
@@ -52,14 +173,12 @@ bool sqlrserverconnection::changeProxiedUser(const char *newuser,
 }
 
 bool sqlrserverconnection::autoCommitOn() {
-	fakeautocommit=true;
-	autocommit=true;
+	cont->setFakeAutoCommit(true);
 	return true;
 }
 
 bool sqlrserverconnection::autoCommitOff() {
-	fakeautocommit=true;
-	autocommit=false;
+	cont->setFakeAutoCommit(false);
 	return true;
 }
 
@@ -71,10 +190,14 @@ bool sqlrserverconnection::supportsTransactionBlocks() {
 	return true;
 }
 
+bool sqlrserverconnection::supportsAutoCommit() {
+	return false;
+}
+
 bool sqlrserverconnection::begin() {
 
 	// re-init error data
-	clearError();
+	cont->clearError();
 
 	// for db's that don't support begin queries,
 	// don't do anything, just return true
@@ -99,8 +222,7 @@ bool sqlrserverconnection::begin() {
 	// If there was an error, copy it out.  We'll be destroying the
 	// cursor in a moment and the error will be lost otherwise.
 	if (!retval) {
-		begincur->errorMessage(error,maxerrorlength,
-					&errorlength,&errnum,&liveconnection);
+		cont->saveErrorFromCursor(begincur);
 	}
 
 	// clean up
@@ -110,7 +232,7 @@ bool sqlrserverconnection::begin() {
 
 	// we will need to commit or rollback at the end of the session now
 	if (retval) {
-		cont->commitOrRollbackIsNeeded();
+		cont->setNeedsCommitOrRollback(true);
 	}
 
 	return retval;
@@ -123,7 +245,7 @@ const char *sqlrserverconnection::beginTransactionQuery() {
 bool sqlrserverconnection::commit() {
 
 	// re-init error data
-	clearError();
+	cont->clearError();
 
 	// init some variables
 	const char	*commitquery="commit";
@@ -140,8 +262,7 @@ bool sqlrserverconnection::commit() {
 	// If there was an error, copy it out.  We'll be destroying the
 	// cursor in a moment and the error will be lost otherwise.
 	if (!retval) {
-		commitcur->errorMessage(error,maxerrorlength,
-					&errorlength,&errnum,&liveconnection);
+		cont->saveErrorFromCursor(commitcur);
 	}
 
 	// clean up
@@ -151,7 +272,7 @@ bool sqlrserverconnection::commit() {
 
 	// we don't need to commit or rollback at the end of the session now
 	if (retval) {
-		cont->commitOrRollbackIsNotNeeded();
+		cont->setNeedsCommitOrRollback(false);
 	}
 
 	return retval;
@@ -160,7 +281,7 @@ bool sqlrserverconnection::commit() {
 bool sqlrserverconnection::rollback() {
 
 	// re-init error data
-	clearError();
+	cont->clearError();
 
 	// init some variables
 	const char	*rollbackquery="rollback";
@@ -177,8 +298,7 @@ bool sqlrserverconnection::rollback() {
 	// If there was an error, copy it out.  We'll be destroying the
 	// cursor in a moment and the error will be lost otherwise.
 	if (!retval) {
-		rbcur->errorMessage(error,maxerrorlength,
-					&errorlength,&errnum,&liveconnection);
+		cont->saveErrorFromCursor(rbcur);
 	}
 
 	// clean up
@@ -188,7 +308,7 @@ bool sqlrserverconnection::rollback() {
 
 	// we don't need to commit or rollback at the end of the session now
 	if (retval) {
-		cont->commitOrRollbackIsNotNeeded();
+		cont->setNeedsCommitOrRollback(false);
 	}
 
 	return retval;
@@ -197,7 +317,7 @@ bool sqlrserverconnection::rollback() {
 bool sqlrserverconnection::selectDatabase(const char *database) {
 
 	// re-init error data
-	clearError();
+	cont->clearError();
 
 	// handle the degenerate case
 	if (!database) {
@@ -216,7 +336,7 @@ bool sqlrserverconnection::selectDatabase(const char *database) {
 	// bounds checking
 	size_t		sdquerylen=charstring::length(sdquerybase)+
 					charstring::length(database)+1;
-	if (sdquerylen>maxquerysize) {
+	if (sdquerylen>pvt->_maxquerysize) {
 		return false;
 	}
 
@@ -226,25 +346,25 @@ bool sqlrserverconnection::selectDatabase(const char *database) {
 	sdquerylen=charstring::length(sdquery);
 
 	// run the query...
+	// (enable translations, triggers, etc. for this one)
 	bool	retval=false;
 	sqlrservercursor	*sdcur=cont->newCursor();
-	if (sdcur->open() &&
-		sdcur->prepareQuery(sdquery,sdquerylen) &&
-		sdcur->executeQuery(sdquery,sdquerylen)) {
-		sdcur->closeResultSet();
+	if (cont->open(sdcur) &&
+		cont->prepareQuery(sdcur,sdquery,sdquerylen,true,true,true) &&
+		cont->executeQuery(sdcur,true,true,true,true)) {
+		cont->closeResultSet(sdcur);
 		retval=true;
 
 		// set a flag indicating that the db has been changed
 		// so it can be reset at the end of the session
 		cont->dbHasChanged();
 	} else {
-		// If there was an error, copy it out.  We'l be destroying the
+		// If there was an error, copy it out.  We'll be destroying the
 		// cursor in a moment and the error will be lost otherwise.
-		sdcur->errorMessage(error,maxerrorlength,
-					&errorlength,&errnum,&liveconnection);
+		cont->saveErrorFromCursor(sdcur);
 	}
 	delete[] sdquery;
-	sdcur->close();
+	cont->close(sdcur);
 	cont->deleteCursor(sdcur);
 	return retval;
 }
@@ -258,8 +378,7 @@ char *sqlrserverconnection::getCurrentDatabase() {
 	// get the get current database query base
 	const char	*gcdquery=getCurrentDatabaseQuery();
 
-	// If there is no query for this then the db we're using doesn't
-	// support switching.
+	// bail if there is no query for this
 	if (!gcdquery) {
 		return NULL;
 	}
@@ -273,7 +392,8 @@ char *sqlrserverconnection::getCurrentDatabase() {
 		gcdcur->prepareQuery(gcdquery,gcdquerylen) &&
 		gcdcur->executeQuery(gcdquery,gcdquerylen)) {
 
-		if (!gcdcur->noRowsToReturn() && gcdcur->fetchRow()) {
+		bool	error=false;
+		if (!gcdcur->noRowsToReturn() && gcdcur->fetchRow(&error)) {
 
 			// get the first field of the row and return it
 			const char	*field=NULL;
@@ -294,10 +414,51 @@ const char *sqlrserverconnection::getCurrentDatabaseQuery() {
 	return NULL;
 }
 
+char *sqlrserverconnection::getCurrentSchema() {
+
+	// get the get current database query base
+	const char	*gcsquery=getCurrentSchemaQuery();
+
+	// bail if there is no query for this
+	if (!gcsquery) {
+		return NULL;
+	}
+
+	size_t		gcsquerylen=charstring::length(gcsquery);
+
+	// run the query...
+	char	*retval=NULL;
+	sqlrservercursor	*gcscur=cont->newCursor();
+	if (gcscur->open() &&
+		gcscur->prepareQuery(gcsquery,gcsquerylen) &&
+		gcscur->executeQuery(gcsquery,gcsquerylen)) {
+
+		bool	error=false;
+		if (!gcscur->noRowsToReturn() && gcscur->fetchRow(&error)) {
+
+			// get the first field of the row and return it
+			const char	*field=NULL;
+			uint64_t	fieldlength=0;
+			bool		blob=false;
+			bool		null=false;
+			gcscur->getField(0,&field,&fieldlength,&blob,&null);
+			retval=charstring::duplicate(field);
+		} 
+	}
+	gcscur->closeResultSet();
+	gcscur->close();
+	cont->deleteCursor(gcscur);
+	return retval;
+}
+
+const char *sqlrserverconnection::getCurrentSchemaQuery() {
+	return NULL;
+}
+
 bool sqlrserverconnection::getLastInsertId(uint64_t *id) {
 
 	// re-init error data
-	clearError();
+	cont->clearError();
 
 	// get the get current database query base
 	const char	*liiquery=getLastInsertIdQuery();
@@ -305,8 +466,9 @@ bool sqlrserverconnection::getLastInsertId(uint64_t *id) {
 	// If there is no query for this then the db we're using doesn't
 	// support switching.
 	if (!liiquery) {
-		setError(SQLR_ERROR_LASTINSERTIDNOTSUPPORTED_STRING,
-				SQLR_ERROR_LASTINSERTIDNOTSUPPORTED,true);
+		cont->setError(
+			SQLR_ERROR_LASTINSERTIDNOTSUPPORTED_STRING,
+			SQLR_ERROR_LASTINSERTIDNOTSUPPORTED,true);
 		return false;
 	}
 
@@ -319,7 +481,8 @@ bool sqlrserverconnection::getLastInsertId(uint64_t *id) {
 		liicur->prepareQuery(liiquery,liiquerylen) &&
 		liicur->executeQuery(liiquery,liiquerylen)) {
 
-		if (!liicur->noRowsToReturn() && liicur->fetchRow()) {
+		bool	error=false;
+		if (!liicur->noRowsToReturn() && liicur->fetchRow(&error)) {
 
 			// get the first field of the row and return it
 			const char	*field=NULL;
@@ -332,16 +495,16 @@ bool sqlrserverconnection::getLastInsertId(uint64_t *id) {
 
 		}  else {
 
-			setError(SQLR_ERROR_LASTINSERTIDNOTSUPPORTED_STRING,
+			cont->setError(
+				SQLR_ERROR_LASTINSERTIDNOTSUPPORTED_STRING,
 				SQLR_ERROR_LASTINSERTIDNOTSUPPORTED,true);
 			retval=false;
 		}
 
 	} else {
-		// If there was an error, copy it out.  We'l be destroying the
+		// If there was an error, copy it out.  We'll be destroying the
 		// cursor in a moment and the error will be lost otherwise.
-		liicur->errorMessage(error,maxerrorlength,
-					&errorlength,&errnum,&liveconnection);
+		cont->saveErrorFromCursor(liicur);
 	}
 
 	liicur->closeResultSet();
@@ -354,6 +517,10 @@ const char *sqlrserverconnection::getLastInsertIdQuery() {
 	return NULL;
 }
 
+const char *sqlrserverconnection::noopQuery() {
+	return "";
+}
+
 bool sqlrserverconnection::setIsolationLevel(const char *isolevel) {
 
 	// if no isolation level was passed in then bail
@@ -373,7 +540,7 @@ bool sqlrserverconnection::setIsolationLevel(const char *isolevel) {
 	// bounds checking
 	size_t		silquerylen=charstring::length(silquerybase)+
 					charstring::length(isolevel)+1;
-	if (silquerylen>maxquerysize) {
+	if (silquerylen>pvt->_maxquerysize) {
 		return false;
 	}
 
@@ -394,8 +561,7 @@ bool sqlrserverconnection::setIsolationLevel(const char *isolevel) {
 	// FIXME: we don't really need to do this now but we will
 	// later if we ever add an API call to set the isolation level
 	/* else {
-		silcur->errorMessage(error,maxerrorlength,
-					&errorlength,&errnum,&liveconnection));
+		cont->saveErrorFromCursor(silcur);
 	} */
 
 	delete[] silquery;
@@ -440,16 +606,16 @@ const char *sqlrserverconnection::dbIpAddressQuery() {
 
 const char *sqlrserverconnection::dbHostName() {
 
-	if (dbhostname) {
-		return dbhostname;
+	if (pvt->_dbhostname) {
+		return pvt->_dbhostname;
 	}
 
 	// don't get looped up...
-	if (dbhostiploop==2) {
-		dbhostiploop=0;
+	if (pvt->_dbhostiploop==2) {
+		pvt->_dbhostiploop=0;
 		return NULL;
 	}
-	dbhostiploop++;
+	pvt->_dbhostiploop++;
 
 	// if we have a host name query then use it, otherwise get the
 	// ip address and convert it to a host name...
@@ -463,14 +629,16 @@ const char *sqlrserverconnection::dbHostName() {
 			dbhncur->prepareQuery(dbhnquery,dbhnquerylen) &&
 			dbhncur->executeQuery(dbhnquery,dbhnquerylen)) {
 
-			if (!dbhncur->noRowsToReturn() && dbhncur->fetchRow()) {
+			bool	error=false;
+			if (!dbhncur->noRowsToReturn() &&
+					dbhncur->fetchRow(&error)) {
 				const char	*field=NULL;
 				uint64_t	fieldlength=0;
 				bool		blob=false;
 				bool		null=false;
 				dbhncur->getField(0,&field,&fieldlength,
 								&blob,&null);
-				dbhostname=charstring::duplicate(field);
+				pvt->_dbhostname=charstring::duplicate(field);
 			} 
 		
 			dbhncur->closeResultSet();
@@ -489,24 +657,24 @@ const char *sqlrserverconnection::dbHostName() {
 				ipaddr++;
 			}
 		}
-		dbhostname=hostentry::getName(ip,4,AF_INET);
+		pvt->_dbhostname=hostentry::getName(ip,4,AF_INET);
 	}
-	dbhostiploop=0;
-	return dbhostname;
+	pvt->_dbhostiploop=0;
+	return pvt->_dbhostname;
 }
 
 const char *sqlrserverconnection::dbIpAddress() {
 
-	if (dbipaddress) {
-		return dbipaddress;
+	if (pvt->_dbipaddress) {
+		return pvt->_dbipaddress;
 	}
 
 	// don't get looped up...
-	if (dbhostiploop==2) {
-		dbhostiploop=0;
+	if (pvt->_dbhostiploop==2) {
+		pvt->_dbhostiploop=0;
 		return NULL;
 	}
-	dbhostiploop++;
+	pvt->_dbhostiploop++;
 
 	// if we have an ip address query then use it, otherwise get the
 	// host name and convert it to an ip address...
@@ -520,14 +688,16 @@ const char *sqlrserverconnection::dbIpAddress() {
 			dbiacur->prepareQuery(dbiaquery,dbiaquerylen) &&
 			dbiacur->executeQuery(dbiaquery,dbiaquerylen)) {
 
-			if (!dbiacur->noRowsToReturn() && dbiacur->fetchRow()) {
+			bool	error=false;
+			if (!dbiacur->noRowsToReturn() &&
+					dbiacur->fetchRow(&error)) {
 				const char	*field=NULL;
 				uint64_t	fieldlength=0;
 				bool		blob=false;
 				bool		null=false;
 				dbiacur->getField(0,&field,&fieldlength,
 								&blob,&null);
-				dbipaddress=charstring::duplicate(field);
+				pvt->_dbipaddress=charstring::duplicate(field);
 			} 
 		
 			dbiacur->closeResultSet();
@@ -536,10 +706,14 @@ const char *sqlrserverconnection::dbIpAddress() {
 		cont->deleteCursor(dbiacur);
 
 	} else {
-		dbipaddress=hostentry::getAddressString(dbHostName());
+		pvt->_dbipaddress=hostentry::getAddressString(dbHostName());
 	}
-	dbhostiploop=0;
-	return dbipaddress;
+	pvt->_dbhostiploop=0;
+	return pvt->_dbipaddress;
+}
+
+bool sqlrserverconnection::cacheDbHostInfo() {
+	return true;
 }
 
 bool sqlrserverconnection::getListsByApiCalls() {
@@ -548,17 +722,78 @@ bool sqlrserverconnection::getListsByApiCalls() {
 
 bool sqlrserverconnection::getDatabaseList(sqlrservercursor *cursor,
 						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
+	return false;
+}
+
+bool sqlrserverconnection::getSchemaList(sqlrservercursor *cursor,
+						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
 	return false;
 }
 
 bool sqlrserverconnection::getTableList(sqlrservercursor *cursor,
+						const char *wild,
+						uint16_t objecttypes) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
+	return false;
+}
+
+bool sqlrserverconnection::getTableTypeList(sqlrservercursor *cursor,
 						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
 	return false;
 }
 
 bool sqlrserverconnection::getColumnList(sqlrservercursor *cursor,
 						const char *table,
 						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
+	return false;
+}
+
+bool sqlrserverconnection::getPrimaryKeyList(sqlrservercursor *cursor,
+						const char *table,
+						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
+	return false;
+}
+
+bool sqlrserverconnection::getKeyAndIndexList(sqlrservercursor *cursor,
+						const char *table,
+						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
+	return false;
+}
+
+bool sqlrserverconnection::getProcedureBindAndColumnList(
+						sqlrservercursor *cursor,
+						const char *procedure,
+						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
+	return false;
+}
+
+bool sqlrserverconnection::getTypeInfoList(sqlrservercursor *cursor,
+						const char *type,
+						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
+	return false;
+}
+
+bool sqlrserverconnection::getProcedureList(sqlrservercursor *cursor,
+						const char *wild) {
+	cont->setError(cursor,SQLR_ERROR_NOTIMPLEMENTED_STRING,
+				SQLR_ERROR_NOTIMPLEMENTED,true);
 	return false;
 }
 
@@ -566,7 +801,75 @@ const char *sqlrserverconnection::getDatabaseListQuery(bool wild) {
 	return "select 1";
 }
 
-const char *sqlrserverconnection::getTableListQuery(bool wild) {
+const char *sqlrserverconnection::getSchemaListQuery(bool wild) {
+	return "select 1";
+}
+
+const char *sqlrserverconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes) {
+	return getTableListQuery(wild,objecttypes,NULL);
+
+}
+
+const char *sqlrserverconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes,
+						const char *extrawhere) {
+
+	stringbuffer	otypes;
+	otypes.append("	(");
+	if (objecttypes&DB_OBJECT_TABLE) {
+		otypes.append("	table_type = 'BASE TABLE' ");
+	}
+	if (objecttypes&DB_OBJECT_VIEW) {
+		if (otypes.getSize()) {
+			otypes.append("	or ");
+		}
+		otypes.append("	table_type = 'VIEW' ");
+	}
+	if (objecttypes&DB_OBJECT_ALIAS) {
+		if (otypes.getSize()) {
+			otypes.append("	or ");
+		}
+		otypes.append("	table_type = 'ALIAS' ");
+	}
+	if (objecttypes&DB_OBJECT_SYNONYM) {
+		if (otypes.getSize()) {
+			otypes.append("	or ");
+		}
+		otypes.append("	table_type = 'SYNONYM' ");
+	}
+	otypes.append(") ");
+
+	pvt->_tablelistquery.clear();
+	pvt->_tablelistquery.append("select ");
+	pvt->_tablelistquery.append("	table_catalog as table_cat, ");
+	pvt->_tablelistquery.append("	table_schema as table_schem, ");
+	pvt->_tablelistquery.append("	table_name, ");
+	pvt->_tablelistquery.append("	case ");
+	pvt->_tablelistquery.append("		when table_type = ");
+	pvt->_tablelistquery.append("'BASE TABLE' then 'TABLE' ");
+	pvt->_tablelistquery.append("		else table_type ");
+	pvt->_tablelistquery.append("	end as table_type, ");
+	pvt->_tablelistquery.append("	NULL as remarks, ");
+	pvt->_tablelistquery.append("	NULL as extra ");
+	pvt->_tablelistquery.append("from ");
+	pvt->_tablelistquery.append("	information_schema.tables ");
+	pvt->_tablelistquery.append("where ");
+	if (wild) {
+		pvt->_tablelistquery.append("	table_name like '%s' ");
+		pvt->_tablelistquery.append("	and ");
+	}
+	pvt->_tablelistquery.append(otypes.getString());
+	pvt->_tablelistquery.append(extrawhere);
+	pvt->_tablelistquery.append("order by ");
+	pvt->_tablelistquery.append("	table_cat, ");
+	pvt->_tablelistquery.append("	table_schem, ");
+	pvt->_tablelistquery.append("	table_name");
+
+	return pvt->_tablelistquery.getString();
+}
+
+const char *sqlrserverconnection::getTableTypeListQuery(bool wild) {
 	return "select 1";
 }
 
@@ -575,7 +878,32 @@ const char *sqlrserverconnection::getGlobalTempTableListQuery() {
 }
 
 const char *sqlrserverconnection::getColumnListQuery(const char *table,
-								bool wild) {
+							bool wild) {
+	return "select 1";
+}
+
+const char *sqlrserverconnection::getPrimaryKeyListQuery(const char *table,
+							bool wild) {
+	return "select 1";
+}
+
+const char *sqlrserverconnection::getKeyAndIndexListQuery(const char *table,
+							bool wild) {
+	return "select 1";
+}
+
+const char *sqlrserverconnection::getProcedureBindAndColumnListQuery(
+							const char *procedure,
+							bool wild) {
+	return "select 1";
+}
+
+const char *sqlrserverconnection::getTypeInfoListQuery(const char *type,
+							bool wild) {
+	return "select 1";
+}
+
+const char *sqlrserverconnection::getProcedureListQuery(bool wild) {
 	return "select 1";
 }
 
@@ -595,11 +923,12 @@ bool sqlrserverconnection::isSynonym(const char *table) {
 	synquerylen=charstring::length(synquery);
 
 	sqlrservercursor	*syncur=cont->newCursor();
+	bool	error=false;
 	bool	result=(syncur->open() &&
 			syncur->prepareQuery(synquery,synquerylen) &&
 			syncur->executeQuery(synquery,synquerylen) &&
 			!syncur->noRowsToReturn() &&
-			syncur->fetchRow());
+			syncur->fetchRow(&error));
 	syncur->closeResultSet();
 	syncur->close();
 	cont->deleteCursor(syncur);
@@ -623,10 +952,6 @@ int16_t sqlrserverconnection::nullBindValue() {
 	return -1;
 }
 
-char sqlrserverconnection::bindVariablePrefix() {
-	return ':';
-}
-
 bool sqlrserverconnection::bindValueIsNull(int16_t isnull) {
 	return (isnull==nullBindValue());
 }
@@ -643,59 +968,40 @@ void sqlrserverconnection::endSession() {
 	// by default, do nothing
 }
 
-bool sqlrserverconnection::getAutoCommit() {
-	return autocommit;
-}
-
-void sqlrserverconnection::setAutoCommit(bool autocommit) {
-	this->autocommit=autocommit;
-}
-
-bool sqlrserverconnection::getFakeAutoCommit() {
-	return fakeautocommit;
-}
-
-void sqlrserverconnection::clearError() {
-	setError(NULL,0,true);
-}
-
-void sqlrserverconnection::setError(const char *err,
-					int64_t errn,
-					bool liveconn) {
-	errorlength=charstring::length(err);
-	if (errorlength>maxerrorlength-1) {
-		errorlength=maxerrorlength-1;
-	}
-	charstring::copy(error,err,errorlength);
-	error[errorlength]='\0';
-	errnum=errn;
-	liveconnection=liveconn;
-}
-
 char *sqlrserverconnection::getErrorBuffer() {
-	return error;
+	return pvt->_error;
 }
 
 uint32_t sqlrserverconnection::getErrorLength() {
-	return errorlength;
+	return pvt->_errorlength;
 }
 
 void sqlrserverconnection::setErrorLength(uint32_t errorlength) {
-	this->errorlength=errorlength;
+	pvt->_errorlength=errorlength;
 }
 
 uint32_t sqlrserverconnection::getErrorNumber() {
-	return errnum;
+	return pvt->_errnum;
 }
 
 void sqlrserverconnection::setErrorNumber(uint32_t errnum) {
-	this->errnum=errnum;
+	pvt->_errnum=errnum;
 }
 
 bool sqlrserverconnection::getLiveConnection() {
-	return liveconnection;
+	return pvt->_liveconnection;
 }
 
 void sqlrserverconnection::setLiveConnection(bool liveconnection) {
-	this->liveconnection=liveconnection;
+	pvt->_liveconnection=liveconnection;
+}
+
+bool sqlrserverconnection::send(unsigned char *data, size_t size) {
+	// by default, do nothing
+	return false;
+}
+
+bool sqlrserverconnection::recv(unsigned char **data, size_t *size) {
+	// by default, do nothing
+	return false;
 }
