@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
@@ -83,7 +83,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -119,8 +119,8 @@ int	main(int argc, char **argv) {
 	cur->inputBind("6",2.2,4,2);
 	cur->inputBind("7","testchar2");
 	cur->inputBind("8","testvarchar2");
-	cur->inputBind("9","01/01/2002");
-	cur->inputBind("10","02:00:00");
+	cur->inputBind("9",2002,1,1,-1,-1,-1,-1,NULL,false);
+	cur->inputBind("10",-1,-1,-1,2,0,0,0,NULL,false);
 	cur->inputBindClob("11","testclob2",9);
 	cur->inputBindBlob("12","testblob2",9);
 	checkSuccess(cur->executeQuery(),1);
@@ -133,8 +133,8 @@ int	main(int argc, char **argv) {
 	cur->inputBind("6",3.3,4,2);
 	cur->inputBind("7","testchar3");
 	cur->inputBind("8","testvarchar3");
-	cur->inputBind("9","01/01/2003");
-	cur->inputBind("10","03:00:00");
+	cur->inputBind("9",2003,1,1,-1,-1,-1,-1,NULL,false);
+	cur->inputBind("10",-1,-1,-1,3,0,0,0,NULL,false);
 	cur->inputBindClob("11","testclob3",9);
 	cur->inputBindBlob("12","testblob3",9);
 	checkSuccess(cur->executeQuery(),1);
@@ -200,8 +200,8 @@ int	main(int argc, char **argv) {
 	cur->inputBindClob("1",clobval,20*1024);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testclob from testtable1");
-	checkSuccess(cur->getFieldLength(0,"testclob"),20*1024);
-	checkSuccess(cur->getField(0,"testclob"),clobval);
+	checkSuccess(cur->getFieldLength(0,"TESTCLOB"),20*1024);
+	checkSuccess(cur->getField(0,"TESTCLOB"),clobval);
 	checkSuccess(cur->sendQuery("create procedure testproc(in in1 clob, out out1 clob) language sql begin set out1 = in1; end"),1);
 	cur->prepareQuery("call testproc(?,?)");
 	cur->inputBindClob("1",clobval,20*1024);
@@ -384,51 +384,51 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY NAME: \n");
-	checkSuccess(cur->getField(0,"testsmallint"),"1");
-	checkSuccess(cur->getField(0,"testint"),"1");
-	checkSuccess(cur->getField(0,"testbigint"),"1");
-	checkSuccess(cur->getField(0,"testdecimal"),"1.10");
-	//checkSuccess(cur->getField(0,"testreal"),"1.1");
-	//checkSuccess(cur->getField(0,"testdouble"),"1.1");
-	checkSuccess(cur->getField(0,"testchar"),"testchar1                               ");
-	checkSuccess(cur->getField(0,"testvarchar"),"testvarchar1");
-	checkSuccess(cur->getField(0,"testdate"),"2001-01-01");
-	checkSuccess(cur->getField(0,"testtime"),"01:00:00");
+	checkSuccess(cur->getField(0,"TESTSMALLINT"),"1");
+	checkSuccess(cur->getField(0,"TESTINT"),"1");
+	checkSuccess(cur->getField(0,"TESTBIGINT"),"1");
+	checkSuccess(cur->getField(0,"TESTDECIMAL"),"1.10");
+	//checkSuccess(cur->getField(0,"TESTREAL"),"1.1");
+	//checkSuccess(cur->getField(0,"TESTDOUBLE"),"1.1");
+	checkSuccess(cur->getField(0,"TESTCHAR"),"testchar1                               ");
+	checkSuccess(cur->getField(0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccess(cur->getField(0,"TESTDATE"),"2001-01-01");
+	checkSuccess(cur->getField(0,"TESTTIME"),"01:00:00");
 	stdoutput.printf("\n");
-	checkSuccess(cur->getField(7,"testsmallint"),"8");
-	checkSuccess(cur->getField(7,"testint"),"8");
-	checkSuccess(cur->getField(7,"testbigint"),"8");
-	checkSuccess(cur->getField(7,"testdecimal"),"8.80");
-	//checkSuccess(cur->getField(7,"testreal"),"8.8");
-	//checkSuccess(cur->getField(7,"testdouble"),"8.8");
-	checkSuccess(cur->getField(7,"testchar"),"testchar8                               ");
-	checkSuccess(cur->getField(7,"testvarchar"),"testvarchar8");
-	checkSuccess(cur->getField(7,"testdate"),"2008-01-01");
-	checkSuccess(cur->getField(7,"testtime"),"08:00:00");
+	checkSuccess(cur->getField(7,"TESTSMALLINT"),"8");
+	checkSuccess(cur->getField(7,"TESTINT"),"8");
+	checkSuccess(cur->getField(7,"TESTBIGINT"),"8");
+	checkSuccess(cur->getField(7,"TESTDECIMAL"),"8.80");
+	//checkSuccess(cur->getField(7,"TESTREAL"),"8.8");
+	//checkSuccess(cur->getField(7,"TESTDOUBLE"),"8.8");
+	checkSuccess(cur->getField(7,"TESTCHAR"),"testchar8                               ");
+	checkSuccess(cur->getField(7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccess(cur->getField(7,"TESTDATE"),"2008-01-01");
+	checkSuccess(cur->getField(7,"TESTTIME"),"08:00:00");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELD LENGTHS BY NAME: \n");
-	checkSuccess(cur->getFieldLength(0,"testsmallint"),1);
-	checkSuccess(cur->getFieldLength(0,"testint"),1);
-	checkSuccess(cur->getFieldLength(0,"testbigint"),1);
-	checkSuccess(cur->getFieldLength(0,"testdecimal"),4);
-	//checkSuccess(cur->getFieldLength(0,"testreal"),3);
-	//checkSuccess(cur->getFieldLength(0,"testdouble"),3);
-	checkSuccess(cur->getFieldLength(0,"testchar"),40);
-	checkSuccess(cur->getFieldLength(0,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(0,"testdate"),10);
-	checkSuccess(cur->getFieldLength(0,"testtime"),8);
+	checkSuccess(cur->getFieldLength(0,"TESTSMALLINT"),1);
+	checkSuccess(cur->getFieldLength(0,"TESTINT"),1);
+	checkSuccess(cur->getFieldLength(0,"TESTBIGINT"),1);
+	checkSuccess(cur->getFieldLength(0,"TESTDECIMAL"),4);
+	//checkSuccess(cur->getFieldLength(0,"TESTREAL"),3);
+	//checkSuccess(cur->getFieldLength(0,"TESTDOUBLE"),3);
+	checkSuccess(cur->getFieldLength(0,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(0,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(0,"TESTDATE"),10);
+	checkSuccess(cur->getFieldLength(0,"TESTTIME"),8);
 	stdoutput.printf("\n");
-	checkSuccess(cur->getFieldLength(7,"testsmallint"),1);
-	checkSuccess(cur->getFieldLength(7,"testint"),1);
-	checkSuccess(cur->getFieldLength(7,"testbigint"),1);
-	checkSuccess(cur->getFieldLength(7,"testdecimal"),4);
-	//checkSuccess(cur->getFieldLength(7,"testreal"),3);
-	//checkSuccess(cur->getFieldLength(7,"testdouble"),3);
-	checkSuccess(cur->getFieldLength(7,"testchar"),40);
-	checkSuccess(cur->getFieldLength(7,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(7,"testdate"),10);
-	checkSuccess(cur->getFieldLength(7,"testtime"),8);
+	checkSuccess(cur->getFieldLength(7,"TESTSMALLINT"),1);
+	checkSuccess(cur->getFieldLength(7,"TESTINT"),1);
+	checkSuccess(cur->getFieldLength(7,"TESTBIGINT"),1);
+	checkSuccess(cur->getFieldLength(7,"TESTDECIMAL"),4);
+	//checkSuccess(cur->getFieldLength(7,"TESTREAL"),3);
+	//checkSuccess(cur->getFieldLength(7,"TESTDOUBLE"),3);
+	checkSuccess(cur->getFieldLength(7,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(7,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(7,"TESTDATE"),10);
+	checkSuccess(cur->getFieldLength(7,"TESTTIME"),8);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY ARRAY: \n");
@@ -803,4 +803,6 @@ int	main(int argc, char **argv) {
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	stdoutput.printf("\n");
+
+	return 0;
 }
