@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
@@ -84,7 +84,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -115,8 +115,8 @@ int	main(int argc, char **argv) {
 	cur->inputBind("4",2.2,2,1);
 	cur->inputBind("5",2.2,2,1);
 	cur->inputBind("6",2.2,2,1);
-	cur->inputBind("7","01-JAN-2002");
-	cur->inputBind("8","02:00:00");
+	cur->inputBind("7",2002,1,1,-1,-1,-1,-1,NULL,false);
+	cur->inputBind("8",-1,-1,-1,2,0,0,0,NULL,false);
 	cur->inputBind("9","testchar2");
 	cur->inputBind("10","testvarchar2");
 	cur->inputBind("11",(char *)NULL);
@@ -129,8 +129,8 @@ int	main(int argc, char **argv) {
 	cur->inputBind("4",3.3,2,1);
 	cur->inputBind("5",3.3,2,1);
 	cur->inputBind("6",3.3,2,1);
-	cur->inputBind("7","01-JAN-2003");
-	cur->inputBind("8","03:00:00");
+	cur->inputBind("7",2003,1,1,-1,-1,-1,-1,NULL,false);
+	cur->inputBind("8",-1,-1,-1,3,0,0,0,NULL,false);
 	cur->inputBind("9","testchar3");
 	cur->inputBind("10","testvarchar3");
 	cur->inputBind("11",(char *)NULL);
@@ -193,8 +193,8 @@ int	main(int argc, char **argv) {
 	cur->inputBindClob("1",blobval,20*1024);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testblob from testtable1");
-	checkSuccess(cur->getFieldLength(0,"testblob"),20*1024);
-	checkSuccess(cur->getField(0,"testblob"),blobval);
+	checkSuccess(cur->getFieldLength(0,"TESTBLOB"),20*1024);
+	checkSuccess(cur->getField(0,"TESTBLOB"),blobval);
 	cur->prepareQuery("execute procedure testproc1 ?");
 	cur->inputBindBlob("1",blobval,20*1024);
 	cur->defineOutputBindBlob("1");
@@ -768,7 +768,7 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COMMIT AND ROLLBACK: \n");
-	secondcon=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	secondcon=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	secondcur=new sqlrcursor(secondcon);
 	checkSuccess(secondcur->sendQuery("select count(*) from testtable"),1);
@@ -825,4 +825,6 @@ int	main(int argc, char **argv) {
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	stdoutput.printf("\n");
+
+	return 0;
 }
