@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
@@ -81,7 +81,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -123,8 +123,8 @@ int	main(int argc, char **argv) {
 	cur->inputBind("12","testvarchar2");
 	cur->inputBind("13","testvarnchar2");
 	cur->inputBind("14","testvarlchar2");
-	cur->inputBind("15","01/01/2002");
-	cur->inputBind("16","2002-01-01 02:00:00");
+	cur->inputBind("15",2002,1,1,-1,-1,-1,-1,NULL,false);
+	cur->inputBind("16",2002,1,1,2,0,0,0,NULL,false);
 	cur->inputBindClob("17","testtext1",9);
 	cur->inputBindBlob("18","testbyte1",9);
 	checkSuccess(cur->executeQuery(),1);
@@ -143,8 +143,8 @@ int	main(int argc, char **argv) {
 	cur->inputBind("12","testvarchar3");
 	cur->inputBind("13","testvarnchar3");
 	cur->inputBind("14","testvarlchar3");
-	cur->inputBind("15","01/01/2003");
-	cur->inputBind("16","2003-01-01 03:00:00");
+	cur->inputBind("15",2003,1,1,-1,-1,-1,-1,NULL,false);
+	cur->inputBind("16",2003,1,1,3,0,0,0,NULL,false);
 	cur->inputBindClob("17","testtext3",9);
 	cur->inputBindBlob("18","testbyte3",9);
 	checkSuccess(cur->executeQuery(),1);
@@ -269,127 +269,127 @@ int	main(int argc, char **argv) {
 
 	stdoutput.printf("COLUMN TYPES: \n");
 	checkSuccess(cur->getColumnType((uint32_t)0),"BOOLEAN");
-	checkSuccess(cur->getColumnType("TESTBOOLEAN"),"BOOLEAN");
+	checkSuccess(cur->getColumnType("testboolean"),"BOOLEAN");
 	checkSuccess(cur->getColumnType(1),"SMALLINT");
-	checkSuccess(cur->getColumnType("TESTSMALLINT"),"SMALLINT");
+	checkSuccess(cur->getColumnType("testsmallint"),"SMALLINT");
 	checkSuccess(cur->getColumnType(2),"INTEGER");
-	checkSuccess(cur->getColumnType("TESTINT"),"INTEGER");
+	checkSuccess(cur->getColumnType("testint"),"INTEGER");
 	checkSuccess(cur->getColumnType(3),"BIGINT");
-	checkSuccess(cur->getColumnType("TESTBIGINT"),"BIGINT");
+	checkSuccess(cur->getColumnType("testbigint"),"BIGINT");
 	checkSuccess(cur->getColumnType(4),"INT8");
-	checkSuccess(cur->getColumnType("TESTINT8"),"INT8");
+	checkSuccess(cur->getColumnType("testint8"),"INT8");
 	checkSuccess(cur->getColumnType(5),"DECIMAL");
-	checkSuccess(cur->getColumnType("TESTDECIMAL"),"DECIMAL");
+	checkSuccess(cur->getColumnType("testdecimal"),"DECIMAL");
 	//checkSuccess(cur->getColumnType(6),"MONEY");
-	//checkSuccess(cur->getColumnType("TESTMONEY"),"MONEY");
+	//checkSuccess(cur->getColumnType("testmoney"),"MONEY");
 	checkSuccess(cur->getColumnType(6),"DECIMAL");
-	checkSuccess(cur->getColumnType("TESTMONEY"),"DECIMAL");
+	checkSuccess(cur->getColumnType("testmoney"),"DECIMAL");
 	checkSuccess(cur->getColumnType(7),"SMALLFLOAT");
-	checkSuccess(cur->getColumnType("TESTSMALLFLOAT"),"SMALLFLOAT");
+	checkSuccess(cur->getColumnType("testsmallfloat"),"SMALLFLOAT");
 	checkSuccess(cur->getColumnType(8),"FLOAT");
-	checkSuccess(cur->getColumnType("TESTFLOAT"),"FLOAT");
+	checkSuccess(cur->getColumnType("testfloat"),"FLOAT");
 	checkSuccess(cur->getColumnType(9),"CHAR");
-	checkSuccess(cur->getColumnType("TESTCHAR"),"CHAR");
+	checkSuccess(cur->getColumnType("testchar"),"CHAR");
 	//checkSuccess(cur->getColumnType(10),"NCHAR");
-	//checkSuccess(cur->getColumnType("TESTNCHAR"),"NCHAR");
+	//checkSuccess(cur->getColumnType("testnchar"),"NCHAR");
 	checkSuccess(cur->getColumnType(10),"CHAR");
-	checkSuccess(cur->getColumnType("TESTNCHAR"),"CHAR");
+	checkSuccess(cur->getColumnType("testnchar"),"CHAR");
 	checkSuccess(cur->getColumnType(11),"VARCHAR");
-	checkSuccess(cur->getColumnType("TESTVARCHAR"),"VARCHAR");
+	checkSuccess(cur->getColumnType("testvarchar"),"VARCHAR");
 	//checkSuccess(cur->getColumnType(12),"NVARCHAR");
-	//checkSuccess(cur->getColumnType("TESTNVARCHAR"),"NVARCHAR");
+	//checkSuccess(cur->getColumnType("testnvarchar"),"NVARCHAR");
 	checkSuccess(cur->getColumnType(12),"VARCHAR");
-	checkSuccess(cur->getColumnType("TESTNVARCHAR"),"VARCHAR");
+	checkSuccess(cur->getColumnType("testnvarchar"),"VARCHAR");
 	//checkSuccess(cur->getColumnType(13),"LVARCHAR");
-	//checkSuccess(cur->getColumnType("TESTLVARCHAR"),"LVARCHAR");
+	//checkSuccess(cur->getColumnType("testlvarchar"),"LVARCHAR");
 	checkSuccess(cur->getColumnType(13),"VARCHAR");
-	checkSuccess(cur->getColumnType("TESTLVARCHAR"),"VARCHAR");
+	checkSuccess(cur->getColumnType("testlvarchar"),"VARCHAR");
 	checkSuccess(cur->getColumnType(14),"DATE");
-	checkSuccess(cur->getColumnType("TESTDATE"),"DATE");
+	checkSuccess(cur->getColumnType("testdate"),"DATE");
 	checkSuccess(cur->getColumnType(15),"DATETIME");
-	checkSuccess(cur->getColumnType("TESTDATETIME"),"DATETIME");
+	checkSuccess(cur->getColumnType("testdatetime"),"DATETIME");
 	checkSuccess(cur->getColumnType(16),"TEXT");
-	checkSuccess(cur->getColumnType("TESTTEXT"),"TEXT");
+	checkSuccess(cur->getColumnType("testtext"),"TEXT");
 	checkSuccess(cur->getColumnType(17),"BYTE");
-	checkSuccess(cur->getColumnType("TESTBYTE"),"BYTE");
+	checkSuccess(cur->getColumnType("testbyte"),"BYTE");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COLUMN LENGTH: \n");
 	checkSuccess(cur->getColumnLength((uint32_t)0),1);
-	checkSuccess(cur->getColumnLength("TESTBOOLEAN"),1);
+	checkSuccess(cur->getColumnLength("testboolean"),1);
 	checkSuccess(cur->getColumnLength(1),5);
-	checkSuccess(cur->getColumnLength("TESTSMALLINT"),5);
+	checkSuccess(cur->getColumnLength("testsmallint"),5);
 	checkSuccess(cur->getColumnLength(2),10);
-	checkSuccess(cur->getColumnLength("TESTINT"),10);
+	checkSuccess(cur->getColumnLength("testint"),10);
 	checkSuccess(cur->getColumnLength(3),20);
-	checkSuccess(cur->getColumnLength("TESTBIGINT"),20);
+	checkSuccess(cur->getColumnLength("testbigint"),20);
 	checkSuccess(cur->getColumnLength(4),20);
-	checkSuccess(cur->getColumnLength("TESTINT8"),20);
+	checkSuccess(cur->getColumnLength("testint8"),20);
 	checkSuccess(cur->getColumnLength(5),10);
-	checkSuccess(cur->getColumnLength("TESTDECIMAL"),10);
+	checkSuccess(cur->getColumnLength("testdecimal"),10);
 	checkSuccess(cur->getColumnLength(6),16);
-	checkSuccess(cur->getColumnLength("TESTMONEY"),16);
+	checkSuccess(cur->getColumnLength("testmoney"),16);
 	checkSuccess(cur->getColumnLength(7),7);
-	checkSuccess(cur->getColumnLength("TESTSMALLFLOAT"),7);
+	checkSuccess(cur->getColumnLength("testsmallfloat"),7);
 	checkSuccess(cur->getColumnLength(8),15);
-	checkSuccess(cur->getColumnLength("TESTFLOAT"),15);
+	checkSuccess(cur->getColumnLength("testfloat"),15);
 	checkSuccess(cur->getColumnLength(9),40);
-	checkSuccess(cur->getColumnLength("TESTCHAR"),40);
+	checkSuccess(cur->getColumnLength("testchar"),40);
 	checkSuccess(cur->getColumnLength(10),40);
-	checkSuccess(cur->getColumnLength("TESTNCHAR"),40);
+	checkSuccess(cur->getColumnLength("testnchar"),40);
 	checkSuccess(cur->getColumnLength(11),40);
-	checkSuccess(cur->getColumnLength("TESTVARCHAR"),40);
+	checkSuccess(cur->getColumnLength("testvarchar"),40);
 	checkSuccess(cur->getColumnLength(12),40);
-	checkSuccess(cur->getColumnLength("TESTNVARCHAR"),40);
+	checkSuccess(cur->getColumnLength("testnvarchar"),40);
 	checkSuccess(cur->getColumnLength(13),40);
-	checkSuccess(cur->getColumnLength("TESTLVARCHAR"),40);
+	checkSuccess(cur->getColumnLength("testlvarchar"),40);
 	checkSuccess(cur->getColumnLength(14),10);
-	checkSuccess(cur->getColumnLength("TESTDATE"),10);
+	checkSuccess(cur->getColumnLength("testdate"),10);
 	checkSuccess(cur->getColumnLength(15),19);
-	checkSuccess(cur->getColumnLength("TESTDATETIME"),19);
+	checkSuccess(cur->getColumnLength("testdatetime"),19);
 	checkSuccess(cur->getColumnLength(16),2147483647);
-	checkSuccess(cur->getColumnLength("TESTTEXT"),2147483647);
+	checkSuccess(cur->getColumnLength("testtext"),2147483647);
 	//checkSuccess(cur->getColumnLength(17),2157483647);
-	//checkSuccess(cur->getColumnLength("TESTBYTE"),2157483647);
+	//checkSuccess(cur->getColumnLength("testbyte"),2157483647);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("LONGEST COLUMN: \n");
 	checkSuccess(cur->getLongest((uint32_t)0),1);
-	checkSuccess(cur->getLongest("TESTBOOLEAN"),1);
+	checkSuccess(cur->getLongest("testboolean"),1);
 	checkSuccess(cur->getLongest(1),1);
-	checkSuccess(cur->getLongest("TESTSMALLINT"),1);
+	checkSuccess(cur->getLongest("testsmallint"),1);
 	checkSuccess(cur->getLongest(2),1);
-	checkSuccess(cur->getLongest("TESTINT"),1);
+	checkSuccess(cur->getLongest("testint"),1);
 	checkSuccess(cur->getLongest(3),1);
-	checkSuccess(cur->getLongest("TESTBIGINT"),1);
+	checkSuccess(cur->getLongest("testbigint"),1);
 	checkSuccess(cur->getLongest(4),1);
-	checkSuccess(cur->getLongest("TESTINT8"),1);
+	checkSuccess(cur->getLongest("testint8"),1);
 	checkSuccess(cur->getLongest(5),4);
-	checkSuccess(cur->getLongest("TESTDECIMAL"),4);
+	checkSuccess(cur->getLongest("testdecimal"),4);
 	checkSuccess(cur->getLongest(6),4);
-	checkSuccess(cur->getLongest("TESTMONEY"),4);
+	checkSuccess(cur->getLongest("testmoney"),4);
 	checkSuccess(cur->getLongest(7),3);
-	checkSuccess(cur->getLongest("TESTSMALLFLOAT"),3);
+	checkSuccess(cur->getLongest("testsmallfloat"),3);
 	checkSuccess(cur->getLongest(8),3);
-	checkSuccess(cur->getLongest("TESTFLOAT"),3);
+	checkSuccess(cur->getLongest("testfloat"),3);
 	checkSuccess(cur->getLongest(9),40);
-	checkSuccess(cur->getLongest("TESTCHAR"),40);
+	checkSuccess(cur->getLongest("testchar"),40);
 	checkSuccess(cur->getLongest(10),40);
-	checkSuccess(cur->getLongest("TESTNCHAR"),40);
+	checkSuccess(cur->getLongest("testnchar"),40);
 	checkSuccess(cur->getLongest(11),12);
-	checkSuccess(cur->getLongest("TESTVARCHAR"),12);
+	checkSuccess(cur->getLongest("testvarchar"),12);
 	checkSuccess(cur->getLongest(12),13);
-	checkSuccess(cur->getLongest("TESTNVARCHAR"),13);
+	checkSuccess(cur->getLongest("testnvarchar"),13);
 	checkSuccess(cur->getLongest(13),13);
-	checkSuccess(cur->getLongest("TESTLVARCHAR"),13);
+	checkSuccess(cur->getLongest("testlvarchar"),13);
 	checkSuccess(cur->getLongest(14),10);
-	checkSuccess(cur->getLongest("TESTDATE"),10);
+	checkSuccess(cur->getLongest("testdate"),10);
 	checkSuccess(cur->getLongest(15),19);
-	checkSuccess(cur->getLongest("TESTDATETIME"),19);
+	checkSuccess(cur->getLongest("testdatetime"),19);
 	checkSuccess(cur->getLongest(16),9);
-	checkSuccess(cur->getLongest("TESTTEXT"),9);
+	checkSuccess(cur->getLongest("testtext"),9);
 	checkSuccess(cur->getLongest(17),9);
-	checkSuccess(cur->getLongest("TESTBYTE"),9);
+	checkSuccess(cur->getLongest("testbyte"),9);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("ROW COUNT: \n");
@@ -487,83 +487,83 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY NAME: \n");
-	checkSuccess(cur->getField(0,"TESTBOOLEAN"),"1");
-	checkSuccess(cur->getField(0,"TESTSMALLINT"),"1");
-	checkSuccess(cur->getField(0,"TESTINT"),"1");
-	checkSuccess(cur->getField(0,"TESTBIGINT"),"1");
-	checkSuccess(cur->getField(0,"TESTINT8"),"1");
-	checkSuccess(cur->getField(0,"TESTDECIMAL"),"1.10");
-	checkSuccess(cur->getField(0,"TESTMONEY"),"1.10");
-	checkSuccess(cur->getField(0,"TESTSMALLFLOAT"),"1.1");
-	checkSuccess(cur->getField(0,"TESTFLOAT"),"1.1");
-	checkSuccess(cur->getField(0,"TESTCHAR"),"testchar1                               ");
-	checkSuccess(cur->getField(0,"TESTNCHAR"),"testnchar1                              ");
-	checkSuccess(cur->getField(0,"TESTVARCHAR"),"testvarchar1");
-	checkSuccess(cur->getField(0,"TESTNVARCHAR"),"testnvarchar1");
-	checkSuccess(cur->getField(0,"TESTLVARCHAR"),"testlvarchar1");
-	checkSuccess(cur->getField(0,"TESTDATE"),"2001-01-01");
-	checkSuccess(cur->getField(0,"TESTDATETIME"),"2001-01-01 01:00:00");
-	checkSuccess(cur->getField(0,"TESTTEXT"),"testtext1");
-	checkSuccess(cur->getField(0,"TESTBYTE"),"");
+	checkSuccess(cur->getField(0,"testboolean"),"1");
+	checkSuccess(cur->getField(0,"testsmallint"),"1");
+	checkSuccess(cur->getField(0,"testint"),"1");
+	checkSuccess(cur->getField(0,"testbigint"),"1");
+	checkSuccess(cur->getField(0,"testint8"),"1");
+	checkSuccess(cur->getField(0,"testdecimal"),"1.10");
+	checkSuccess(cur->getField(0,"testmoney"),"1.10");
+	checkSuccess(cur->getField(0,"testsmallfloat"),"1.1");
+	checkSuccess(cur->getField(0,"testfloat"),"1.1");
+	checkSuccess(cur->getField(0,"testchar"),"testchar1                               ");
+	checkSuccess(cur->getField(0,"testnchar"),"testnchar1                              ");
+	checkSuccess(cur->getField(0,"testvarchar"),"testvarchar1");
+	checkSuccess(cur->getField(0,"testnvarchar"),"testnvarchar1");
+	checkSuccess(cur->getField(0,"testlvarchar"),"testlvarchar1");
+	checkSuccess(cur->getField(0,"testdate"),"2001-01-01");
+	checkSuccess(cur->getField(0,"testdatetime"),"2001-01-01 01:00:00");
+	checkSuccess(cur->getField(0,"testtext"),"testtext1");
+	checkSuccess(cur->getField(0,"testbyte"),"");
 	stdoutput.printf("\n");
-	checkSuccess(cur->getField(7,"TESTBOOLEAN"),"1");
-	checkSuccess(cur->getField(7,"TESTSMALLINT"),"8");
-	checkSuccess(cur->getField(7,"TESTINT"),"8");
-	checkSuccess(cur->getField(7,"TESTBIGINT"),"8");
-	checkSuccess(cur->getField(7,"TESTINT8"),"8");
-	checkSuccess(cur->getField(7,"TESTDECIMAL"),"8.80");
-	checkSuccess(cur->getField(7,"TESTMONEY"),"8.80");
-	checkSuccess(cur->getField(7,"TESTSMALLFLOAT"),"8.8");
-	checkSuccess(cur->getField(7,"TESTFLOAT"),"8.8");
-	checkSuccess(cur->getField(7,"TESTCHAR"),"testchar8                               ");
-	checkSuccess(cur->getField(7,"TESTNCHAR"),"testnchar8                              ");
-	checkSuccess(cur->getField(7,"TESTVARCHAR"),"testvarchar8");
-	checkSuccess(cur->getField(7,"TESTNVARCHAR"),"testnvarchar8");
-	checkSuccess(cur->getField(7,"TESTLVARCHAR"),"testlvarchar8");
-	checkSuccess(cur->getField(7,"TESTDATE"),"2008-01-01");
-	checkSuccess(cur->getField(7,"TESTDATETIME"),"2008-01-01 08:00:00");
-	checkSuccess(cur->getField(7,"TESTTEXT"),"testtext8");
-	checkSuccess(cur->getField(7,"TESTBYTE"),"");
+	checkSuccess(cur->getField(7,"testboolean"),"1");
+	checkSuccess(cur->getField(7,"testsmallint"),"8");
+	checkSuccess(cur->getField(7,"testint"),"8");
+	checkSuccess(cur->getField(7,"testbigint"),"8");
+	checkSuccess(cur->getField(7,"testint8"),"8");
+	checkSuccess(cur->getField(7,"testdecimal"),"8.80");
+	checkSuccess(cur->getField(7,"testmoney"),"8.80");
+	checkSuccess(cur->getField(7,"testsmallfloat"),"8.8");
+	checkSuccess(cur->getField(7,"testfloat"),"8.8");
+	checkSuccess(cur->getField(7,"testchar"),"testchar8                               ");
+	checkSuccess(cur->getField(7,"testnchar"),"testnchar8                              ");
+	checkSuccess(cur->getField(7,"testvarchar"),"testvarchar8");
+	checkSuccess(cur->getField(7,"testnvarchar"),"testnvarchar8");
+	checkSuccess(cur->getField(7,"testlvarchar"),"testlvarchar8");
+	checkSuccess(cur->getField(7,"testdate"),"2008-01-01");
+	checkSuccess(cur->getField(7,"testdatetime"),"2008-01-01 08:00:00");
+	checkSuccess(cur->getField(7,"testtext"),"testtext8");
+	checkSuccess(cur->getField(7,"testbyte"),"");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELD LENGTHS BY NAME: \n");
-	checkSuccess(cur->getFieldLength(0,"TESTBOOLEAN"),1);
-	checkSuccess(cur->getFieldLength(0,"TESTSMALLINT"),1);
-	checkSuccess(cur->getFieldLength(0,"TESTINT"),1);
-	checkSuccess(cur->getFieldLength(0,"TESTBIGINT"),1);
-	checkSuccess(cur->getFieldLength(0,"TESTINT8"),1);
-	checkSuccess(cur->getFieldLength(0,"TESTDECIMAL"),4);
-	checkSuccess(cur->getFieldLength(0,"TESTMONEY"),4);
-	checkSuccess(cur->getFieldLength(0,"TESTSMALLFLOAT"),3);
-	checkSuccess(cur->getFieldLength(0,"TESTFLOAT"),3);
-	checkSuccess(cur->getFieldLength(0,"TESTCHAR"),40);
-	checkSuccess(cur->getFieldLength(0,"TESTNCHAR"),40);
-	checkSuccess(cur->getFieldLength(0,"TESTVARCHAR"),12);
-	checkSuccess(cur->getFieldLength(0,"TESTNVARCHAR"),13);
-	checkSuccess(cur->getFieldLength(0,"TESTLVARCHAR"),13);
-	checkSuccess(cur->getFieldLength(0,"TESTDATE"),10);
-	checkSuccess(cur->getFieldLength(0,"TESTDATETIME"),19);
-	checkSuccess(cur->getFieldLength(0,"TESTTEXT"),9);
-	checkSuccess(cur->getFieldLength(0,"TESTBYTE"),0);
+	checkSuccess(cur->getFieldLength(0,"testboolean"),1);
+	checkSuccess(cur->getFieldLength(0,"testsmallint"),1);
+	checkSuccess(cur->getFieldLength(0,"testint"),1);
+	checkSuccess(cur->getFieldLength(0,"testbigint"),1);
+	checkSuccess(cur->getFieldLength(0,"testint8"),1);
+	checkSuccess(cur->getFieldLength(0,"testdecimal"),4);
+	checkSuccess(cur->getFieldLength(0,"testmoney"),4);
+	checkSuccess(cur->getFieldLength(0,"testsmallfloat"),3);
+	checkSuccess(cur->getFieldLength(0,"testfloat"),3);
+	checkSuccess(cur->getFieldLength(0,"testchar"),40);
+	checkSuccess(cur->getFieldLength(0,"testnchar"),40);
+	checkSuccess(cur->getFieldLength(0,"testvarchar"),12);
+	checkSuccess(cur->getFieldLength(0,"testnvarchar"),13);
+	checkSuccess(cur->getFieldLength(0,"testlvarchar"),13);
+	checkSuccess(cur->getFieldLength(0,"testdate"),10);
+	checkSuccess(cur->getFieldLength(0,"testdatetime"),19);
+	checkSuccess(cur->getFieldLength(0,"testtext"),9);
+	checkSuccess(cur->getFieldLength(0,"testbyte"),0);
 	stdoutput.printf("\n");
-	checkSuccess(cur->getFieldLength(7,"TESTBOOLEAN"),1);
-	checkSuccess(cur->getFieldLength(7,"TESTSMALLINT"),1);
-	checkSuccess(cur->getFieldLength(7,"TESTINT"),1);
-	checkSuccess(cur->getFieldLength(7,"TESTBIGINT"),1);
-	checkSuccess(cur->getFieldLength(7,"TESTINT8"),1);
-	checkSuccess(cur->getFieldLength(7,"TESTDECIMAL"),4);
-	checkSuccess(cur->getFieldLength(7,"TESTMONEY"),4);
-	checkSuccess(cur->getFieldLength(7,"TESTSMALLFLOAT"),3);
-	checkSuccess(cur->getFieldLength(7,"TESTFLOAT"),3);
-	checkSuccess(cur->getFieldLength(7,"TESTCHAR"),40);
-	checkSuccess(cur->getFieldLength(7,"TESTNCHAR"),40);
-	checkSuccess(cur->getFieldLength(7,"TESTVARCHAR"),12);
-	checkSuccess(cur->getFieldLength(7,"TESTNVARCHAR"),13);
-	checkSuccess(cur->getFieldLength(7,"TESTLVARCHAR"),13);
-	checkSuccess(cur->getFieldLength(7,"TESTDATE"),10);
-	checkSuccess(cur->getFieldLength(7,"TESTDATETIME"),19);
-	checkSuccess(cur->getFieldLength(7,"TESTTEXT"),9);
-	checkSuccess(cur->getFieldLength(7,"TESTBYTE"),0);
+	checkSuccess(cur->getFieldLength(7,"testboolean"),1);
+	checkSuccess(cur->getFieldLength(7,"testsmallint"),1);
+	checkSuccess(cur->getFieldLength(7,"testint"),1);
+	checkSuccess(cur->getFieldLength(7,"testbigint"),1);
+	checkSuccess(cur->getFieldLength(7,"testint8"),1);
+	checkSuccess(cur->getFieldLength(7,"testdecimal"),4);
+	checkSuccess(cur->getFieldLength(7,"testmoney"),4);
+	checkSuccess(cur->getFieldLength(7,"testsmallfloat"),3);
+	checkSuccess(cur->getFieldLength(7,"testfloat"),3);
+	checkSuccess(cur->getFieldLength(7,"testchar"),40);
+	checkSuccess(cur->getFieldLength(7,"testnchar"),40);
+	checkSuccess(cur->getFieldLength(7,"testvarchar"),12);
+	checkSuccess(cur->getFieldLength(7,"testnvarchar"),13);
+	checkSuccess(cur->getFieldLength(7,"testlvarchar"),13);
+	checkSuccess(cur->getFieldLength(7,"testdate"),10);
+	checkSuccess(cur->getFieldLength(7,"testdatetime"),19);
+	checkSuccess(cur->getFieldLength(7,"testtext"),9);
+	checkSuccess(cur->getFieldLength(7,"testbyte"),0);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY ARRAY: \n");
@@ -986,4 +986,6 @@ int	main(int argc, char **argv) {
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	stdoutput.printf("\n");
+
+	return 0;
 }
