@@ -1,9 +1,11 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
 #include <rudiments/charstring.h>
+#include <rudiments/sys.h>
 #include <rudiments/process.h>
+#include <rudiments/snooze.h>
 #include <rudiments/stdio.h>
 
 sqlrconnection	*con;
@@ -117,7 +119,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -153,7 +155,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("1",2);
 	cur->inputBind("2","testchar2");
 	cur->inputBind("3","testvarchar2");
-	cur->inputBind("4",2002,1,1,0,0,0,0,NULL);
+	cur->inputBind("4",2002,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("5","testlong2");
 	cur->inputBindClob("6","testclob2",9);
 	cur->inputBindBlob("7","testblob2",9);
@@ -162,7 +164,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("1",3);
 	cur->inputBind("2","testchar3");
 	cur->inputBind("3","testvarchar3");
-	cur->inputBind("4",2003,1,1,0,0,0,0,NULL);
+	cur->inputBind("4",2003,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("5","testlong3");
 	cur->inputBindClob("6","testclob3",9);
 	cur->inputBindBlob("7","testblob3",9);
@@ -182,7 +184,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("var1",5);
 	cur->inputBind("var2","testchar5");
 	cur->inputBind("var3","testvarchar5");
-	cur->inputBind("var4",2005,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",2005,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong5");
 	cur->inputBindClob("var6","testclob5",9);
 	cur->inputBindBlob("var7","testblob5",9);
@@ -191,7 +193,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("var1",6);
 	cur->inputBind("var2","testchar6");
 	cur->inputBind("var3","testvarchar6");
-	cur->inputBind("var4",2006,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",2006,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong6");
 	cur->inputBindClob("var6","testclob6",9);
 	cur->inputBindBlob("var7","testblob6",9);
@@ -211,7 +213,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("var1",8);
 	cur->inputBind("var2","testchar8");
 	cur->inputBind("var3","testvarchar8");
-	cur->inputBind("var4",2008,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",2008,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong8");
 	cur->inputBindClob("var6","testclob8",9);
 	cur->inputBindBlob("var7","testblob8",9);
@@ -237,9 +239,11 @@ int	main(int argc, char **argv) {
 	int16_t	minute=0;
 	int16_t	second=0;
 	int32_t	microsecond=0;
+	bool	isnegative=false;
 	const char	*tz=NULL;
 	cur->getOutputBindDate("datevar",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -264,7 +268,8 @@ int	main(int argc, char **argv) {
 	stringvar=cur->getOutputBindString("2");
 	floatvar=cur->getOutputBindDouble("3");
 	cur->getOutputBindDate("4",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -291,7 +296,8 @@ int	main(int argc, char **argv) {
 	stringvar=cur->getOutputBindString("stringvar");
 	floatvar=cur->getOutputBindDouble("floatvar");
 	cur->getOutputBindDate("datevar",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+				&hour,&minute,&second,&microsecond,&tz,
+				&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -333,53 +339,53 @@ int	main(int argc, char **argv) {
 
 	stdoutput.printf("COLUMN TYPES: \n");
 	checkSuccess(cur->getColumnType((uint32_t)0),"NUMBER");
-	checkSuccess(cur->getColumnType("testnumber"),"NUMBER");
+	checkSuccess(cur->getColumnType("TESTNUMBER"),"NUMBER");
 	checkSuccess(cur->getColumnType(1),"CHAR");
-	checkSuccess(cur->getColumnType("testchar"),"CHAR");
+	checkSuccess(cur->getColumnType("TESTCHAR"),"CHAR");
 	checkSuccess(cur->getColumnType(2),"VARCHAR2");
-	checkSuccess(cur->getColumnType("testvarchar"),"VARCHAR2");
+	checkSuccess(cur->getColumnType("TESTVARCHAR"),"VARCHAR2");
 	checkSuccess(cur->getColumnType(3),"DATE");
-	checkSuccess(cur->getColumnType("testdate"),"DATE");
+	checkSuccess(cur->getColumnType("TESTDATE"),"DATE");
 	checkSuccess(cur->getColumnType(4),"LONG");
-	checkSuccess(cur->getColumnType("testlong"),"LONG");
+	checkSuccess(cur->getColumnType("TESTLONG"),"LONG");
 	checkSuccess(cur->getColumnType(5),"CLOB");
-	checkSuccess(cur->getColumnType("testclob"),"CLOB");
+	checkSuccess(cur->getColumnType("TESTCLOB"),"CLOB");
 	checkSuccess(cur->getColumnType(6),"BLOB");
-	checkSuccess(cur->getColumnType("testblob"),"BLOB");
+	checkSuccess(cur->getColumnType("TESTBLOB"),"BLOB");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COLUMN LENGTH: \n");
 	checkSuccess(cur->getColumnLength((uint32_t)0),22);
-	checkSuccess(cur->getColumnLength("testnumber"),22);
+	checkSuccess(cur->getColumnLength("TESTNUMBER"),22);
 	checkSuccess(cur->getColumnLength(1),40);
-	checkSuccess(cur->getColumnLength("testchar"),40);
+	checkSuccess(cur->getColumnLength("TESTCHAR"),40);
 	checkSuccess(cur->getColumnLength(2),40);
-	checkSuccess(cur->getColumnLength("testvarchar"),40);
+	checkSuccess(cur->getColumnLength("TESTVARCHAR"),40);
 	checkSuccess(cur->getColumnLength(3),7);
-	checkSuccess(cur->getColumnLength("testdate"),7);
+	checkSuccess(cur->getColumnLength("TESTDATE"),7);
 	checkSuccess(cur->getColumnLength(4),0);
-	checkSuccess(cur->getColumnLength("testlong"),0);
+	checkSuccess(cur->getColumnLength("TESTLONG"),0);
 	checkSuccess(cur->getColumnLength(5),0);
-	checkSuccess(cur->getColumnLength("testclob"),0);
+	checkSuccess(cur->getColumnLength("TESTCLOB"),0);
 	checkSuccess(cur->getColumnLength(6),0);
-	checkSuccess(cur->getColumnLength("testblob"),0);
+	checkSuccess(cur->getColumnLength("TESTBLOB"),0);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("LONGEST COLUMN: \n");
 	checkSuccess(cur->getLongest((uint32_t)0),1);
-	checkSuccess(cur->getLongest("testnumber"),1);
+	checkSuccess(cur->getLongest("TESTNUMBER"),1);
 	checkSuccess(cur->getLongest(1),40);
-	checkSuccess(cur->getLongest("testchar"),40);
+	checkSuccess(cur->getLongest("TESTCHAR"),40);
 	checkSuccess(cur->getLongest(2),12);
-	checkSuccess(cur->getLongest("testvarchar"),12);
+	checkSuccess(cur->getLongest("TESTVARCHAR"),12);
 	checkSuccess(cur->getLongest(3),9);
-	checkSuccess(cur->getLongest("testdate"),9);
+	checkSuccess(cur->getLongest("TESTDATE"),9);
 	checkSuccess(cur->getLongest(4),9);
-	checkSuccess(cur->getLongest("testlong"),9);
+	checkSuccess(cur->getLongest("TESTLONG"),9);
 	checkSuccess(cur->getLongest(5),9);
-	checkSuccess(cur->getLongest("testclob"),9);
+	checkSuccess(cur->getLongest("TESTCLOB"),9);
 	checkSuccess(cur->getLongest(6),9);
-	checkSuccess(cur->getLongest("testblob"),9);
+	checkSuccess(cur->getLongest("TESTBLOB"),9);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("ROW COUNT: \n");
@@ -435,39 +441,39 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY NAME: \n");
-	checkSuccess(cur->getField(0,"testnumber"),"1");
-	checkSuccess(cur->getField(0,"testchar"),"testchar1                               ");
-	checkSuccess(cur->getField(0,"testvarchar"),"testvarchar1");
-	checkSuccess(cur->getField(0,"testdate"),"01-JAN-01");
-	checkSuccess(cur->getField(0,"testlong"),"testlong1");
-	checkSuccess(cur->getField(0,"testclob"),"testclob1");
-	checkSuccess(cur->getField(0,"testblob"),"");
+	checkSuccess(cur->getField(0,"TESTNUMBER"),"1");
+	checkSuccess(cur->getField(0,"TESTCHAR"),"testchar1                               ");
+	checkSuccess(cur->getField(0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccess(cur->getField(0,"TESTDATE"),"01-JAN-01");
+	checkSuccess(cur->getField(0,"TESTLONG"),"testlong1");
+	checkSuccess(cur->getField(0,"TESTCLOB"),"testclob1");
+	checkSuccess(cur->getField(0,"TESTBLOB"),"");
 	stdoutput.printf("\n");
-	checkSuccess(cur->getField(7,"testnumber"),"8");
-	checkSuccess(cur->getField(7,"testchar"),"testchar8                               ");
-	checkSuccess(cur->getField(7,"testvarchar"),"testvarchar8");
-	checkSuccess(cur->getField(7,"testdate"),"01-JAN-08");
-	checkSuccess(cur->getField(7,"testlong"),"testlong8");
-	checkSuccess(cur->getField(7,"testclob"),"testclob8");
-	checkSuccess(cur->getField(7,"testblob"),"testblob8");
+	checkSuccess(cur->getField(7,"TESTNUMBER"),"8");
+	checkSuccess(cur->getField(7,"TESTCHAR"),"testchar8                               ");
+	checkSuccess(cur->getField(7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccess(cur->getField(7,"TESTDATE"),"01-JAN-08");
+	checkSuccess(cur->getField(7,"TESTLONG"),"testlong8");
+	checkSuccess(cur->getField(7,"TESTCLOB"),"testclob8");
+	checkSuccess(cur->getField(7,"TESTBLOB"),"testblob8");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELD LENGTHS BY NAME: \n");
-	checkSuccess(cur->getFieldLength(0,"testnumber"),1);
-	checkSuccess(cur->getFieldLength(0,"testchar"),40);
-	checkSuccess(cur->getFieldLength(0,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(0,"testdate"),9);
-	checkSuccess(cur->getFieldLength(0,"testlong"),9);
-	checkSuccess(cur->getFieldLength(0,"testclob"),9);
-	checkSuccess(cur->getFieldLength(0,"testblob"),0);
+	checkSuccess(cur->getFieldLength(0,"TESTNUMBER"),1);
+	checkSuccess(cur->getFieldLength(0,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(0,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(0,"TESTDATE"),9);
+	checkSuccess(cur->getFieldLength(0,"TESTLONG"),9);
+	checkSuccess(cur->getFieldLength(0,"TESTCLOB"),9);
+	checkSuccess(cur->getFieldLength(0,"TESTBLOB"),0);
 	stdoutput.printf("\n");
-	checkSuccess(cur->getFieldLength(7,"testnumber"),1);
-	checkSuccess(cur->getFieldLength(7,"testchar"),40);
-	checkSuccess(cur->getFieldLength(7,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(7,"testdate"),9);
-	checkSuccess(cur->getFieldLength(7,"testlong"),9);
-	checkSuccess(cur->getFieldLength(7,"testclob"),9);
-	checkSuccess(cur->getFieldLength(7,"testblob"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTNUMBER"),1);
+	checkSuccess(cur->getFieldLength(7,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(7,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(7,"TESTDATE"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTLONG"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTCLOB"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTBLOB"),9);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY ARRAY: \n");
@@ -611,6 +617,7 @@ int	main(int argc, char **argv) {
 	port=con->getConnectionPort();
 	socket=charstring::duplicate(con->getConnectionSocket());
 	checkSuccess(con->resumeSession(port,socket),1);
+	delete[] socket;
 	stdoutput.printf("\n");
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
 	checkSuccess(cur->getField(1,(uint32_t)0),"2");
@@ -627,6 +634,7 @@ int	main(int argc, char **argv) {
 	port=con->getConnectionPort();
 	socket=charstring::duplicate(con->getConnectionSocket());
 	checkSuccess(con->resumeSession(port,socket),1);
+	delete[] socket;
 	stdoutput.printf("\n");
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
 	checkSuccess(cur->getField(1,(uint32_t)0),"2");
@@ -643,6 +651,7 @@ int	main(int argc, char **argv) {
 	port=con->getConnectionPort();
 	socket=charstring::duplicate(con->getConnectionSocket());
 	checkSuccess(con->resumeSession(port,socket),1);
+	delete[] socket;
 	stdoutput.printf("\n");
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
 	checkSuccess(cur->getField(1,(uint32_t)0),"2");
@@ -664,6 +673,7 @@ int	main(int argc, char **argv) {
 	port=con->getConnectionPort();
 	socket=charstring::duplicate(con->getConnectionSocket());
 	checkSuccess(con->resumeSession(port,socket),1);
+	delete[] socket;
 	checkSuccess(cur->resumeResultSet(id),1);
 	stdoutput.printf("\n");
 	checkSuccess(cur->firstRowIndex(),4);
@@ -766,6 +776,7 @@ int	main(int argc, char **argv) {
 	socket=charstring::duplicate(con->getConnectionSocket());
 	stdoutput.printf("\n");
 	checkSuccess(con->resumeSession(port,socket),1);
+	delete[] socket;
 	checkSuccess(cur->resumeCachedResultSet(id,filename),1);
 	stdoutput.printf("\n");
 	checkSuccess(cur->firstRowIndex(),4);
@@ -791,7 +802,7 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COMMIT AND ROLLBACK: \n");
-	secondcon=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	secondcon=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	secondcur=new sqlrcursor(secondcon);
 	checkSuccess(secondcur->sendQuery("select count(*) from testtable"),1);
@@ -818,6 +829,7 @@ int	main(int argc, char **argv) {
 	port=con->getConnectionPort();
 	socket=charstring::duplicate(con->getConnectionSocket());
 	checkSuccess(con->resumeSession(port,socket),1);
+	delete[] socket;
 	checkSuccess(cur->resumeResultSet(id),1);
 	checkSuccess(cur->getField(4,(uint32_t)0),NULL);
 	checkSuccess(cur->getField(5,(uint32_t)0),NULL);
@@ -897,8 +909,9 @@ int	main(int argc, char **argv) {
 	clobval[8*1024]='\0';
 	cur->inputBindClob("clobval",clobval,8*1024);
 	checkSuccess(cur->executeQuery(),1);
+
 	cur->sendQuery("select testclob from testtable2");
-	checkSuccess(clobval,cur->getField(0,"testclob"));
+	checkSuccess(clobval,cur->getField(0,"TESTCLOB"));
 	cur->prepareQuery("begin select testclob into :clobbindval from testtable2; end;");
 	cur->defineOutputBindClob("clobbindval");
 	checkSuccess(cur->executeQuery(),1);
@@ -921,7 +934,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("testval",testval);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testval from testtable2");
-	checkSuccess(testval,cur->getField(0,"testval"));
+	checkSuccess(testval,cur->getField(0,"TESTVAL"));
 	char	query[4000+25];
 	charstring::printf(query,sizeof(query),
 				"begin :bindval:='%s'; end;",testval);
@@ -940,7 +953,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("testval",-1);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testval from testtable2");
-	checkSuccess(cur->getField(0,"testval"),"-1");
+	checkSuccess(cur->getField(0,"TESTVAL"),"-1");
 	cur->sendQuery("drop table testtable2");
 	stdoutput.printf("\n");
 
@@ -979,31 +992,71 @@ int	main(int argc, char **argv) {
 
 
 	// temporary tables
+	char	*hostname=sys::getHostName();
+	char	*dot=(char *)charstring::findFirstOrEnd(hostname,'.');
+	*dot='\0';
 	stdoutput.printf("TEMPORARY TABLES: \n");
-	cur->sendQuery("drop table temptabledelete\n");
-	cur->sendQuery("create global temporary table temptabledelete (col1 number) on commit delete rows");
-	checkSuccess(cur->sendQuery("insert into temptabledelete values (1)"),1);
-	checkSuccess(cur->sendQuery("select count(*) from temptabledelete"),1);
+	cur->prepareQuery("drop table $(HOSTNAME)_temptabledelete");
+	cur->substitution("HOSTNAME",hostname);
+	cur->executeQuery();
+	cur->prepareQuery("create global temporary table $(HOSTNAME)_temptabledelete (col1 number) on commit delete rows");
+	cur->substitution("HOSTNAME",hostname);
+	cur->executeQuery();
+	cur->prepareQuery("insert into $(HOSTNAME)_temptabledelete values (1)");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
+	cur->prepareQuery("select count(*) from $(HOSTNAME)_temptabledelete");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
 	checkSuccess(con->commit(),1);
-	checkSuccess(cur->sendQuery("select count(*) from temptabledelete"),1);
+	cur->prepareQuery("select count(*) from $(HOSTNAME)_temptabledelete");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
 	checkSuccess(cur->getField(0,(uint32_t)0),"0");
-	cur->sendQuery("drop table temptabledelete\n");
+	cur->prepareQuery("drop table $(HOSTNAME)_temptabledelete");
+	cur->substitution("HOSTNAME",hostname);
+	cur->executeQuery();
 	stdoutput.printf("\n");
-	cur->sendQuery("drop table temptablepreserve\n");
-	cur->sendQuery("create global temporary table temptablepreserve (col1 number) on commit preserve rows");
-	checkSuccess(cur->sendQuery("insert into temptablepreserve values (1)"),1);
-	checkSuccess(cur->sendQuery("select count(*) from temptablepreserve"),1);
+	cur->prepareQuery("truncate table $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	cur->executeQuery();
+	cur->prepareQuery("drop table $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	cur->executeQuery();
+	cur->prepareQuery("create global temporary table $(HOSTNAME)_temptablepreserve (col1 number) on commit preserve rows");
+	cur->substitution("HOSTNAME",hostname);
+	cur->executeQuery();
+	cur->prepareQuery("insert into $(HOSTNAME)_temptablepreserve values (1)");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
+	cur->prepareQuery("select count(*) from $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
 	checkSuccess(con->commit(),1);
-	checkSuccess(cur->sendQuery("select count(*) from temptablepreserve"),1);
+	cur->prepareQuery("select count(*) from $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
 	con->endSession();
 	stdoutput.printf("\n");
-	checkSuccess(cur->sendQuery("select count(*) from temptablepreserve"),1);
+	cur->prepareQuery("select count(*) from $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
 	checkSuccess(cur->getField(0,(uint32_t)0),"0");
-	cur->sendQuery("drop table temptablepreserve\n");
+	cur->prepareQuery("truncate table $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
+	snooze::macrosnooze(2);
+	cur->prepareQuery("drop table $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),1);
+	cur->prepareQuery("select count(*) from $(HOSTNAME)_temptablepreserve");
+	cur->substitution("HOSTNAME",hostname);
+	checkSuccess(cur->executeQuery(),0);
 	stdoutput.printf("\n");
+	delete[] hostname;
 
 
 	// stored procedures
@@ -1086,6 +1139,25 @@ int	main(int argc, char **argv) {
 	cur->sendQuery("drop procedure testproc");
 	stdoutput.printf("\n");
 
+	// cursors
+	cur->closeResultSet();
+	stdoutput.printf("CURSORS: \n");
+	sqlrcursor	*curs[10];
+	for (uint16_t i=0; i<10; i++) {
+		curs[i]=new sqlrcursor(con);
+		stringbuffer	q;
+		q.append("select ")->append(i)->append(" from dual");
+		bool	success=curs[i]->sendQuery(q.getString());
+		if (i<5) {
+			checkSuccess(success,1);
+		} else {
+			checkSuccess(curs[i]->errorMessage(),
+				"No server-side cursors were "
+				"available to process the query.");
+		}
+	}
+	stdoutput.printf("\n");
+
 
 	// invalid queries...
 	stdoutput.printf("INVALID QUERIES: \n");
@@ -1108,4 +1180,6 @@ int	main(int argc, char **argv) {
 
 	delete cur;
 	delete con;
+
+	return 0;
 }
