@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclientwrapper.h>
@@ -129,14 +129,14 @@ int	main(int argc, char **argv) {
 
 	const char	*service=NULL;
 	#ifdef _WIN32
-		service="sqlrelay/fedora22x64.firstworks.com@AD.FIRSTWORKS.COM";
+		service="sqlrelay/fedora24x64.firstworks.com@AD.FIRSTWORKS.COM";
 	#endif
 
 
 	// instantiation
-	con=sqlrcon_alloc("sqlrserver",9000,"/tmp/test.socket",NULL,NULL,0,1);
+	con=sqlrcon_alloc("sqlrelay",9000,"/tmp/test.socket",NULL,NULL,0,1);
 	cur=sqlrcur_alloc(con);
-	sqlrcon_enableKerberos(con,NULL,NULL,NULL);
+	sqlrcon_enableKerberos(con,service,NULL,NULL);
 
 	// get database type
 	printf("IDENTIFY: \n");
@@ -197,7 +197,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"1",2);
 	sqlrcur_inputBindString(cur,"2","testchar2");
 	sqlrcur_inputBindString(cur,"3","testvarchar2");
-	sqlrcur_inputBindDate(cur,"4",2002,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"4",2002,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"5","testlong2");
 	sqlrcur_inputBindClob(cur,"6","testclob2",9);
 	sqlrcur_inputBindBlob(cur,"7","testblob2",9);
@@ -206,7 +206,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"1",3);
 	sqlrcur_inputBindString(cur,"2","testchar3");
 	sqlrcur_inputBindString(cur,"3","testvarchar3");
-	sqlrcur_inputBindDate(cur,"4",2003,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"4",2003,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"5","testlong3");
 	sqlrcur_inputBindClob(cur,"6","testclob3",9);
 	sqlrcur_inputBindBlob(cur,"7","testblob3",9);
@@ -226,7 +226,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"var1",5);
 	sqlrcur_inputBindString(cur,"var2","testchar5");
 	sqlrcur_inputBindString(cur,"var3","testvarchar5");
-	sqlrcur_inputBindDate(cur,"var4",2005,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"var4",2005,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"var5","testlong5");
 	sqlrcur_inputBindClob(cur,"var6","testclob5",9);
 	sqlrcur_inputBindBlob(cur,"var7","testblob5",9);
@@ -235,7 +235,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"var1",6);
 	sqlrcur_inputBindString(cur,"var2","testchar6");
 	sqlrcur_inputBindString(cur,"var3","testvarchar6");
-	sqlrcur_inputBindDate(cur,"var4",2006,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"var4",2006,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"var5","testlong6");
 	sqlrcur_inputBindClob(cur,"var6","testclob6",9);
 	sqlrcur_inputBindBlob(cur,"var7","testblob6",9);
@@ -255,7 +255,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"var1",8);
 	sqlrcur_inputBindString(cur,"var2","testchar8");
 	sqlrcur_inputBindString(cur,"var3","testvarchar8");
-	sqlrcur_inputBindDate(cur,"var4",2008,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"var4",2008,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"var5","testlong8");
 	sqlrcur_inputBindClob(cur,"var6","testclob8",9);
 	sqlrcur_inputBindBlob(cur,"var7","testblob8",9);
@@ -795,7 +795,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COMMIT AND ROLLBACK: \n");
-	secondcon=sqlrcon_alloc("sqlrserver",9000,"/tmp/test.socket",
+	secondcon=sqlrcon_alloc("sqlrelay",9000,"/tmp/test.socket",
 							NULL,NULL,0,1);
 	secondcur=sqlrcur_alloc(secondcon);
 	sqlrcon_enableKerberos(secondcon,NULL,NULL,NULL);
@@ -960,4 +960,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	return 0;
 }
