@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclientwrapper.h>
@@ -69,7 +69,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=sqlrcon_alloc("sqlrserver",9000,
+	con=sqlrcon_alloc("sqlrelay",9000,
 				"/tmp/test.socket","test","test",0,1);
 	cur=sqlrcur_alloc(con);
 
@@ -883,4 +883,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	return 0;
 }
