@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 import com.firstworks.sqlrelay.SQLRConnection;
@@ -89,7 +89,7 @@ class sap {
 		long[]	fieldlens;
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection("sqlrserver",
+		SQLRConnection con=new SQLRConnection("sqlrelay",
 						(short)9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
@@ -902,6 +902,7 @@ class sap {
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		System.out.println();
-	
+
+		System.exit(0);
 	}
 }
