@@ -141,12 +141,12 @@ class tls {
 		String[]	arraybindvals={"7","testchar7","testvarchar7","01-JAN-2007","testlong7"};
 		long[]	fieldlens;
 	
-		String		cert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
-		String		ca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
+		String		cert="../sqlrelay.conf.d/tls/client.pem";
+		String		ca="../sqlrelay.conf.d/tls/ca.pem";
 		if (System.getProperty("os.name").
 			toLowerCase().indexOf("win")>=0) {
-			cert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
-			ca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
+			cert="..\\sqlrelay.conf.d\\tls\\client.pfx";
+			ca="..\\sqlrelay.conf.d\\tls\\ca.pfx";
 		}
 	
 	
