@@ -1,6 +1,6 @@
 #! /usr/bin/env perl
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
@@ -15,7 +15,7 @@ sub checkUndef {
 		print("success ");
 	} else {
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -27,8 +27,9 @@ sub checkSuccess {
 	if ($value==$success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -40,21 +41,16 @@ sub checkSuccessString {
 	if ($value eq $success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
 
-# usage...
-if ($#ARGV+1<5) {
-	print("usage: db2.pl host port socket user password");
-	exit;
-}
-
 # instantiation
-$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
-					$ARGV[2],$ARGV[3],$ARGV[4],0,1);
+$con=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket",
+							"test","test",0,1);
 $cur=SQLRelay::Cursor->new($con);
 
 # get database type
@@ -132,9 +128,9 @@ $cur->sendQuery("drop procedure testproc");
 checkSuccess($cur->sendQuery("create procedure testproc(in invar int, out outvar int) language sql begin set outvar = invar; end"),1);
 $cur->prepareQuery("call testproc(?,?)");
 $cur->inputBind("1",5);
-$cur->defineOutputBind("2",10);
+$cur->defineOutputBindString("2",10);
 checkSuccess($cur->executeQuery(),1);
-checkSuccess($cur->getOutputBind("2"),"5");
+checkSuccess($cur->getOutputBindString("2"),"5");
 checkSuccess($cur->sendQuery("drop procedure testproc"),1);
 print("\n");
 
@@ -250,7 +246,7 @@ checkSuccess($cur->rowCount(),8);
 print("\n");
 
 print("TOTAL ROWS: \n");
-checkSuccess($cur->totalRows(),-1);
+checkSuccess($cur->totalRows(),0);
 print("\n");
 
 print("FIRST ROW INDEX: \n");
@@ -310,51 +306,51 @@ checkSuccess($cur->getFieldLength(7,9),8);
 print("\n");
 
 print("FIELDS BY NAME: \n");
-checkSuccessString($cur->getField(0,"testsmallint"),"1");
-checkSuccessString($cur->getField(0,"testint"),"1");
-checkSuccessString($cur->getField(0,"testbigint"),"1");
-checkSuccessString($cur->getField(0,"testdecimal"),"1.10");
-#checkSuccessString($cur->getField(0,"testreal"),"1.1");
-#checkSuccessString($cur->getField(0,"testdouble"),"1.1");
-checkSuccessString($cur->getField(0,"testchar"),"testchar1                               ");
-checkSuccessString($cur->getField(0,"testvarchar"),"testvarchar1");
-checkSuccessString($cur->getField(0,"testdate"),"2001-01-01");
-checkSuccessString($cur->getField(0,"testtime"),"01:00:00");
+checkSuccessString($cur->getField(0,"TESTSMALLINT"),"1");
+checkSuccessString($cur->getField(0,"TESTINT"),"1");
+checkSuccessString($cur->getField(0,"TESTBIGINT"),"1");
+checkSuccessString($cur->getField(0,"TESTDECIMAL"),"1.10");
+#checkSuccessString($cur->getField(0,"TESTREAL"),"1.1");
+#checkSuccessString($cur->getField(0,"TESTDOUBLE"),"1.1");
+checkSuccessString($cur->getField(0,"TESTCHAR"),"testchar1                               ");
+checkSuccessString($cur->getField(0,"TESTVARCHAR"),"testvarchar1");
+checkSuccessString($cur->getField(0,"TESTDATE"),"2001-01-01");
+checkSuccessString($cur->getField(0,"TESTTIME"),"01:00:00");
 print("\n");
-checkSuccessString($cur->getField(7,"testsmallint"),"8");
-checkSuccessString($cur->getField(7,"testint"),"8");
-checkSuccessString($cur->getField(7,"testbigint"),"8");
-checkSuccessString($cur->getField(7,"testdecimal"),"8.80");
-#checkSuccessString($cur->getField(7,"testreal"),"8.8");
-#checkSuccessString($cur->getField(7,"testdouble"),"8.8");
-checkSuccessString($cur->getField(7,"testchar"),"testchar8                               ");
-checkSuccessString($cur->getField(7,"testvarchar"),"testvarchar8");
-checkSuccessString($cur->getField(7,"testdate"),"2008-01-01");
-checkSuccessString($cur->getField(7,"testtime"),"08:00:00");
+checkSuccessString($cur->getField(7,"TESTSMALLINT"),"8");
+checkSuccessString($cur->getField(7,"TESTINT"),"8");
+checkSuccessString($cur->getField(7,"TESTBIGINT"),"8");
+checkSuccessString($cur->getField(7,"TESTDECIMAL"),"8.80");
+#checkSuccessString($cur->getField(7,"TESTREAL"),"8.8");
+#checkSuccessString($cur->getField(7,"TESTDOUBLE"),"8.8");
+checkSuccessString($cur->getField(7,"TESTCHAR"),"testchar8                               ");
+checkSuccessString($cur->getField(7,"TESTVARCHAR"),"testvarchar8");
+checkSuccessString($cur->getField(7,"TESTDATE"),"2008-01-01");
+checkSuccessString($cur->getField(7,"TESTTIME"),"08:00:00");
 print("\n");
 
 print("FIELD LENGTHS BY NAME: \n");
-checkSuccess($cur->getFieldLength(0,"testsmallint"),1);
-checkSuccess($cur->getFieldLength(0,"testint"),1);
-checkSuccess($cur->getFieldLength(0,"testbigint"),1);
-checkSuccess($cur->getFieldLength(0,"testdecimal"),4);
-#checkSuccess($cur->getFieldLength(0,"testreal"),3);
-#checkSuccess($cur->getFieldLength(0,"testdouble"),3);
-checkSuccess($cur->getFieldLength(0,"testchar"),40);
-checkSuccess($cur->getFieldLength(0,"testvarchar"),12);
-checkSuccess($cur->getFieldLength(0,"testdate"),10);
-checkSuccess($cur->getFieldLength(0,"testtime"),8);
+checkSuccess($cur->getFieldLength(0,"TESTSMALLINT"),1);
+checkSuccess($cur->getFieldLength(0,"TESTINT"),1);
+checkSuccess($cur->getFieldLength(0,"TESTBIGINT"),1);
+checkSuccess($cur->getFieldLength(0,"TESTDECIMAL"),4);
+#checkSuccess($cur->getFieldLength(0,"TESTREAL"),3);
+#checkSuccess($cur->getFieldLength(0,"TESTDOUBLE"),3);
+checkSuccess($cur->getFieldLength(0,"TESTCHAR"),40);
+checkSuccess($cur->getFieldLength(0,"TESTVARCHAR"),12);
+checkSuccess($cur->getFieldLength(0,"TESTDATE"),10);
+checkSuccess($cur->getFieldLength(0,"TESTTIME"),8);
 print("\n");
-checkSuccess($cur->getFieldLength(7,"testsmallint"),1);
-checkSuccess($cur->getFieldLength(7,"testint"),1);
-checkSuccess($cur->getFieldLength(7,"testbigint"),1);
-checkSuccess($cur->getFieldLength(7,"testdecimal"),4);
-#checkSuccess($cur->getFieldLength(7,"testreal"),3);
-#checkSuccess($cur->getFieldLength(7,"testdouble"),3);
-checkSuccess($cur->getFieldLength(7,"testchar"),40);
-checkSuccess($cur->getFieldLength(7,"testvarchar"),12);
-checkSuccess($cur->getFieldLength(7,"testdate"),10);
-checkSuccess($cur->getFieldLength(7,"testtime"),8);
+checkSuccess($cur->getFieldLength(7,"TESTSMALLINT"),1);
+checkSuccess($cur->getFieldLength(7,"TESTINT"),1);
+checkSuccess($cur->getFieldLength(7,"TESTBIGINT"),1);
+checkSuccess($cur->getFieldLength(7,"TESTDECIMAL"),4);
+#checkSuccess($cur->getFieldLength(7,"TESTREAL"),3);
+#checkSuccess($cur->getFieldLength(7,"TESTDOUBLE"),3);
+checkSuccess($cur->getFieldLength(7,"TESTCHAR"),40);
+checkSuccess($cur->getFieldLength(7,"TESTVARCHAR"),12);
+checkSuccess($cur->getFieldLength(7,"TESTDATE"),10);
+checkSuccess($cur->getFieldLength(7,"TESTTIME"),8);
 print("\n");
 
 print("FIELDS BY ARRAY: \n");
@@ -760,5 +756,4 @@ checkSuccess($cur->sendQuery("create table testtable"),0);
 checkSuccess($cur->sendQuery("create table testtable"),0);
 print("\n");
 
-
-
+exit(0);
