@@ -1,6 +1,6 @@
 #! /usr/bin/env perl
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
@@ -49,7 +49,7 @@ sub checkSuccessString {
 
 
 # instantiation
-$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+$con=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 $cur=SQLRelay::Cursor->new($con);
 
@@ -498,7 +498,7 @@ print("\n");
 print("RESULT SET BUFFER SIZE: \n");
 checkSuccess($cur->getResultSetBufferSize(),0);
 $cur->setResultSetBufferSize(2);
-checkSuccess($cur->sendQuery("select * from testtable"),1);
+checkSuccess($cur->sendQuery("select * from testtable order by testinteger"),1);
 checkSuccess($cur->getResultSetBufferSize(),2);
 print("\n");
 checkSuccess($cur->firstRowIndex(),0);
@@ -729,7 +729,7 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 #print("COMMIT AND ROLLBACK: \n");
-$secondcon=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+$secondcon=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 $secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
@@ -787,5 +787,4 @@ checkSuccess($cur->sendQuery("create table testtable"),0);
 checkSuccess($cur->sendQuery("create table testtable"),0);
 print("\n");
 
-
-
+exit(0);
