@@ -1,6 +1,6 @@
 #! /usr/bin/env perl
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
@@ -50,7 +50,7 @@ sub checkSuccessString {
 
 
 # instantiation
-$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+$con=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 $cur=SQLRelay::Cursor->new($con);
 
@@ -129,7 +129,6 @@ $cur->inputBind("5","testchar8");
 $cur->inputBind("6","testvarchar8");
 $cur->inputBind("7","01/01/2008");
 $cur->inputBind("8","08:00:00");
-$cur->inputBind("9","junkvalue");
 $cur->validateBinds();
 checkSuccess($cur->executeQuery(),1);
 print("\n");
@@ -229,9 +228,9 @@ print("ROW COUNT: \n");
 checkSuccess($cur->rowCount(),8);
 print("\n");
 
-print("TOTAL ROWS: \n");
-checkSuccess($cur->totalRows(),8);
-print("\n");
+#print("TOTAL ROWS: \n");
+#checkSuccess($cur->totalRows(),8);
+#print("\n");
 
 print("FIRST ROW INDEX: \n");
 checkSuccess($cur->firstRowIndex(),0);
@@ -663,7 +662,7 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+$secondcon=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 $secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
@@ -765,5 +764,4 @@ checkSuccess($cur->sendQuery("create table testtable"),0);
 checkSuccess($cur->sendQuery("create table testtable"),0);
 print("\n");
 
-
-
+exit(0);
