@@ -60,11 +60,11 @@ sub checkSuccessString {
 	}
 }
 
-$tlscert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
-$tlsca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
+$tlscert="../sqlrelay.conf.d/tls/client.pem";
+$tlsca="../sqlrelay.conf.d/tls/ca.pem";
 if ($^O eq "MSWin32") {
-	$tlscert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
-	$tlsca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
+	$tlscert="..\\sqlrelay.conf.d\\tls\\client.pfx";
+	$tlsca="..\\sqlrelay.conf.d\\tls\\ca.pfx";
 }
 
 
