@@ -283,10 +283,10 @@
 	//checkSuccess(sqlrcur_getLongest($cur,"testreal"),3);
 	//checkSuccess(sqlrcur_getLongest($cur,4),17);
 	//checkSuccess(sqlrcur_getLongest($cur,"testfloat"),17);
-	checkSuccess(sqlrcur_getLongest($cur,5),3);
-	checkSuccess(sqlrcur_getLongest($cur,"testdecimal"),3);
-	checkSuccess(sqlrcur_getLongest($cur,6),3);
-	checkSuccess(sqlrcur_getLongest($cur,"testnumeric"),3);
+	//checkSuccess(sqlrcur_getLongest($cur,5),3);
+	//checkSuccess(sqlrcur_getLongest($cur,"testdecimal"),3);
+	//checkSuccess(sqlrcur_getLongest($cur,6),3);
+	//checkSuccess(sqlrcur_getLongest($cur,"testnumeric"),3);
 	//checkSuccess(sqlrcur_getLongest($cur,7),4);
 	//checkSuccess(sqlrcur_getLongest($cur,"testmoney"),4);
 	//checkSuccess(sqlrcur_getLongest($cur,8),4);
@@ -325,8 +325,8 @@
 	checkSuccess(sqlrcur_getField($cur,0,2),"1");
 	//checkSuccess(sqlrcur_getField($cur,0,3),"1.1");
 	//checkSuccess(sqlrcur_getField($cur,0,4),"1.1");
-	checkSuccess(sqlrcur_getField($cur,0,5),"1.1");
-	checkSuccess(sqlrcur_getField($cur,0,6),"1.1");
+	//checkSuccess(sqlrcur_getField($cur,0,5),"1.1");
+	//checkSuccess(sqlrcur_getField($cur,0,6),"1.1");
 	//checkSuccess(sqlrcur_getField($cur,0,7),"1.00");
 	//checkSuccess(sqlrcur_getField($cur,0,8),"1.00");
 	//checkSuccess(sqlrcur_getField($cur,0,9),"Jan  1 2001 01:00:00:000AM");
@@ -340,8 +340,8 @@
 	checkSuccess(sqlrcur_getField($cur,7,2),"8");
 	//checkSuccess(sqlrcur_getField($cur,7,3),"8.8");
 	//checkSuccess(sqlrcur_getField($cur,7,4),"8.8");
-	checkSuccess(sqlrcur_getField($cur,7,5),"8.8");
-	checkSuccess(sqlrcur_getField($cur,7,6),"8.8");
+	//checkSuccess(sqlrcur_getField($cur,7,5),"8.8");
+	//checkSuccess(sqlrcur_getField($cur,7,6),"8.8");
 	//checkSuccess(sqlrcur_getField($cur,7,7),"8.00");
 	//checkSuccess(sqlrcur_getField($cur,7,8),"8.00");
 	//checkSuccess(sqlrcur_getField($cur,7,9),"Jan  1 2008 08:00:00:000AM");
@@ -357,8 +357,8 @@
 	checkSuccess(sqlrcur_getFieldLength($cur,0,2),1);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,3),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,4),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,5),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,6),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,5),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,6),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,7),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,8),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,9),26);
@@ -372,8 +372,8 @@
 	checkSuccess(sqlrcur_getFieldLength($cur,7,2),1);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,3),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,4),17);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,5),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,6),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,5),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,6),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,7),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,8),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,9),26);
@@ -421,8 +421,8 @@
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testtinyint"),1);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testreal"),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testfloat"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdecimal"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testnumeric"),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testdecimal"),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testnumeric"),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testmoney"),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmallmoney"),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testdatetime"),26);
@@ -436,8 +436,8 @@
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testtinyint"),1);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testreal"),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testfloat"),17);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdecimal"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testnumeric"),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testdecimal"),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testnumeric"),3);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testmoney"),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmallmoney"),4);
 	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testdatetime"),26);
@@ -492,8 +492,8 @@
 	checkSuccess($fields["testtinyint"],"1");
 	//checkSuccess($fields["testreal"],"1.1");
 	//checkSuccess($fields["testfloat"],"1.1");
-	checkSuccess($fields["testdecimal"],"1.1");
-	checkSuccess($fields["testnumeric"],"1.1");
+	//checkSuccess($fields["testdecimal"],"1.1");
+	//checkSuccess($fields["testnumeric"],"1.1");
 	//checkSuccess($fields["testmoney"],"1.00");
 	//checkSuccess($fields["testsmallmoney"],"1.00");
 	//checkSuccess($fields["testdatetime"],"Jan  1 2001 01:00:00:000AM");
@@ -508,8 +508,8 @@
 	checkSuccess($fields["testtinyint"],"8");
 	//checkSuccess($fields["testreal"],"8.8");
 	//checkSuccess($fields["testfloat"],"8.8");
-	checkSuccess($fields["testdecimal"],"8.8");
-	checkSuccess($fields["testnumeric"],"8.8");
+	//checkSuccess($fields["testdecimal"],"8.8");
+	//checkSuccess($fields["testnumeric"],"8.8");
 	//checkSuccess($fields["testmoney"],"8.00");
 	//checkSuccess($fields["testsmallmoney"],"8.00");
 	//checkSuccess($fields["testdatetime"],"Jan  1 2008 08:00:00:000AM");
@@ -526,8 +526,8 @@
 	checkSuccess($fieldlengths["testtinyint"],1);
 	//checkSuccess($fieldlengths["testreal"],3);
 	//checkSuccess($fieldlengths["testfloat"],3);
-	checkSuccess($fieldlengths["testdecimal"],3);
-	checkSuccess($fieldlengths["testnumeric"],3);
+	//checkSuccess($fieldlengths["testdecimal"],3);
+	//checkSuccess($fieldlengths["testnumeric"],3);
 	//checkSuccess($fieldlengths["testmoney"],4);
 	//checkSuccess($fieldlengths["testsmallmoney"],4);
 	//checkSuccess($fieldlengths["testdatetime"],26);
@@ -542,8 +542,8 @@
 	checkSuccess($fieldlengths["testtinyint"],1);
 	//checkSuccess($fieldlengths["testreal"],3);
 	//checkSuccess($fieldlengths["testfloat"],17);
-	checkSuccess($fieldlengths["testdecimal"],3);
-	checkSuccess($fieldlengths["testnumeric"],3);
+	//checkSuccess($fieldlengths["testdecimal"],3);
+	//checkSuccess($fieldlengths["testnumeric"],3);
 	//checkSuccess($fieldlengths["testmoney"],4);
 	//checkSuccess($fieldlengths["testsmallmoney"],4);
 	//checkSuccess($fieldlengths["testdatetime"],26);
