@@ -18,11 +18,11 @@
 	$socket="/tmp/test.socket";
 	$user="";
 	$password="";
-	$tlscert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
-	$tlsca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
+	$tlscert="../sqlrelay.conf.d/tls/client.pem";
+	$tlsca="../sqlrelay.conf.d/tls/ca.pem";
 	if (strtoupper(substr(PHP_OS,0,3))==='WIN') {
-		$tlscert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
-		$tlsca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
+		$tlscert="..\\sqlrelay.conf.d\\tls\\client.pfx";
+		$tlsca="..\\sqlrelay.conf.d\\tls\\ca.pfx";
 	}
 	$dsn = "sqlrelay:host=$host;port=$port;socket=$socket;tries=0;retrytime=1;tls=yes;tlscert=$tlscert;tlsvalidate=ca;tlsca=$tlsca;debug=0";
 
@@ -34,7 +34,10 @@
 	}
 
 	# drop existing table
-	$dbh->exec("drop table testtable");
+	try {
+		$dbh->exec("drop table testtable");
+	} catch (Exception $e) {
+	}
 
 	echo("CREATE TEMPTABLE: \n");
 	checkSuccess($dbh->exec("create table testtable (testnumber number, testchar char(40), testvarchar varchar(40), testdate date, testlong long, testclob clob, testblob blob)"),0);
@@ -518,7 +521,10 @@
 	echo("\n");
 
 	echo("COMMIT AND ROLLBACK: \n");
-	$dbh->exec("drop table testtable1");
+	try {
+		$dbh->exec("drop table testtable1");
+	} catch (Exception $e) {
+	}
 	checkSuccess($dbh->exec("create table testtable1 (testnumber number)"),0);
 	if (method_exists($dbh,"inTransaction")) {
 		checkSuccess($dbh->inTransaction(),0);
@@ -584,8 +590,14 @@
 	echo("\n");
 
 	# drop testtables
-	$dbh->exec("drop table testtable");
-	$dbh->exec("drop table testtable1");
+	try {
+		$dbh->exec("drop table testtable");
+	} catch (Exception $e) {
+	}
+	try {
+		$dbh->exec("drop table testtable1");
+	} catch (Exception $e) {
+	}
 
 # output binds don't appear to work with PDO for PHP7
 if (PHP_VERSION_ID < 70000) {
@@ -612,7 +624,10 @@ if (PHP_VERSION_ID < 70000) {
 	echo("\n");
 
 	echo("CLOB AND BLOB OUTPUT BIND: \n");
-	$dbh->exec("drop table testtable1");
+	try {
+		$dbh->exec("drop table testtable1");
+	} catch (Exception $e) {
+	}
 	checkSuccess($dbh->exec("create table testtable1 (testclob clob, testblob blob)"),0);
 	$stmt=$dbh->prepare("insert into testtable1 values ('hello',:var1)");
 	checkSuccess($stmt->bindValue("var1","hello",PDO::PARAM_LOB),true);
@@ -625,7 +640,10 @@ if (PHP_VERSION_ID < 70000) {
 	echo("\n");
 
 	echo("CLOB AND BLOB OUTPUT BIND TO AND FROM FILE: \n");
-	$dbh->exec("drop table testtable1");
+	try {
+		$dbh->exec("drop table testtable1");
+	} catch (Exception $e) {
+	}
 	checkSuccess($dbh->exec("create table testtable1 (testclob clob, testblob blob)"),0);
 	$stmt=$dbh->prepare("insert into testtable1 values ('hello',:var1)");
 	$stream=fopen("test.blob","w+b");
@@ -690,6 +708,9 @@ if (PHP_VERSION_ID < 70000) {
 	#checkSuccess($stmt->bindValue(1,1,9999),true);
 	echo("\n");
 
-	$dbh->exec("drop table testtable");
+	try {
+		$dbh->exec("drop table testtable");
+	} catch (Exception $e) {
+	}
 
 ?></pre></html>
