@@ -294,10 +294,10 @@ def main():
 	#checkSuccess(cur.getLongest('testreal'),3)
 	#checkSuccess(cur.getLongest(4),17)
 	#checkSuccess(cur.getLongest('testfloat'),17)
-	checkSuccess(cur.getLongest(5),3)
-	checkSuccess(cur.getLongest('testdecimal'),3)
-	checkSuccess(cur.getLongest(6),3)
-	checkSuccess(cur.getLongest('testnumeric'),3)
+	#checkSuccess(cur.getLongest(5),3)
+	#checkSuccess(cur.getLongest('testdecimal'),3)
+	#checkSuccess(cur.getLongest(6),3)
+	#checkSuccess(cur.getLongest('testnumeric'),3)
 	#checkSuccess(cur.getLongest(7),4)
 	#checkSuccess(cur.getLongest('testmoney'),4)
 	#checkSuccess(cur.getLongest(8),4)
@@ -351,8 +351,8 @@ def main():
 	checkSuccess(cur.getField(7,2),8)
 	#checkSuccess(cur.getField(7,3),Decimal("8.8"))
 	#checkSuccess(cur.getField(7,4),Decimal("8.8"))
-	checkSuccess(cur.getField(7,5),Decimal("8.8"))
-	checkSuccess(cur.getField(7,6),Decimal("8.8"))
+	#checkSuccess(cur.getField(7,5),Decimal("8.8"))
+	#checkSuccess(cur.getField(7,6),Decimal("8.8"))
 	#checkSuccess(cur.getField(7,7),Decimal("8.00"))
 	#checkSuccess(cur.getField(7,8),Decimal("8.00"))
 	#checkSuccess(cur.getField(7,9),"Jan  1 2008 08:00:00:000AM")
@@ -368,8 +368,8 @@ def main():
 	checkSuccess(cur.getFieldLength(0,2),1)
 	#checkSuccess(cur.getFieldLength(0,3),3)
 	#checkSuccess(cur.getFieldLength(0,4),3)
-	checkSuccess(cur.getFieldLength(0,5),3)
-	checkSuccess(cur.getFieldLength(0,6),3)
+	#checkSuccess(cur.getFieldLength(0,5),3)
+	#checkSuccess(cur.getFieldLength(0,6),3)
 	#checkSuccess(cur.getFieldLength(0,7),4)
 	#checkSuccess(cur.getFieldLength(0,8),4)
 	#checkSuccess(cur.getFieldLength(0,9),26)
@@ -383,8 +383,8 @@ def main():
 	checkSuccess(cur.getFieldLength(7,2),1)
 	#checkSuccess(cur.getFieldLength(7,3),3)
 	#checkSuccess(cur.getFieldLength(7,4),17)
-	checkSuccess(cur.getFieldLength(7,5),3)
-	checkSuccess(cur.getFieldLength(7,6),3)
+	#checkSuccess(cur.getFieldLength(7,5),3)
+	#checkSuccess(cur.getFieldLength(7,6),3)
 	#checkSuccess(cur.getFieldLength(7,7),4)
 	#checkSuccess(cur.getFieldLength(7,8),4)
 	#checkSuccess(cur.getFieldLength(7,9),26)
@@ -400,8 +400,8 @@ def main():
 	checkSuccess(cur.getField(0,"testtinyint"),1)
 	#checkSuccess(cur.getField(0,"testreal"),Decimal("1.1"))
 	#checkSuccess(cur.getField(0,"testfloat"),Decimal("1.1"))
-	checkSuccess(cur.getField(0,"testdecimal"),Decimal("1.1"))
-	checkSuccess(cur.getField(0,"testnumeric"),Decimal("1.1"))
+	#checkSuccess(cur.getField(0,"testdecimal"),Decimal("1.1"))
+	#checkSuccess(cur.getField(0,"testnumeric"),Decimal("1.1"))
 	#checkSuccess(cur.getField(0,"testmoney"),Decimal("1.00"))
 	#checkSuccess(cur.getField(0,"testsmallmoney"),Decimal("1.00"))
 	#checkSuccess(cur.getField(0,"testdatetime"),"Jan  1 2001 01:00:00:000AM")
@@ -415,8 +415,8 @@ def main():
 	checkSuccess(cur.getField(7,"testtinyint"),8)
 	#checkSuccess(cur.getField(7,"testreal"),Decimal("8.8"))
 	#checkSuccess(cur.getField(7,"testfloat"),Decimal("8.8"))
-	checkSuccess(cur.getField(7,"testdecimal"),Decimal("8.8"))
-	checkSuccess(cur.getField(7,"testnumeric"),Decimal("8.8"))
+	#checkSuccess(cur.getField(7,"testdecimal"),Decimal("8.8"))
+	#checkSuccess(cur.getField(7,"testnumeric"),Decimal("8.8"))
 	#checkSuccess(cur.getField(7,"testmoney"),Decimal("8.00"))
 	#checkSuccess(cur.getField(7,"testsmallmoney"),Decimal("8.00"))
 	#checkSuccess(cur.getField(7,"testdatetime"),"Jan  1 2008 08:00:00:000AM")
@@ -432,8 +432,8 @@ def main():
 	checkSuccess(cur.getFieldLength(0,"testtinyint"),1)
 	#checkSuccess(cur.getFieldLength(0,"testreal"),3)
 	#checkSuccess(cur.getFieldLength(0,"testfloat"),3)
-	checkSuccess(cur.getFieldLength(0,"testdecimal"),3)
-	checkSuccess(cur.getFieldLength(0,"testnumeric"),3)
+	#checkSuccess(cur.getFieldLength(0,"testdecimal"),3)
+	#checkSuccess(cur.getFieldLength(0,"testnumeric"),3)
 	#checkSuccess(cur.getFieldLength(0,"testmoney"),4)
 	#checkSuccess(cur.getFieldLength(0,"testsmallmoney"),4)
 	#checkSuccess(cur.getFieldLength(0,"testdatetime"),26)
@@ -447,8 +447,8 @@ def main():
 	checkSuccess(cur.getFieldLength(7,"testtinyint"),1)
 	#checkSuccess(cur.getFieldLength(7,"testreal"),3)
 	#checkSuccess(cur.getFieldLength(7,"testfloat"),17)
-	checkSuccess(cur.getFieldLength(7,"testdecimal"),3)
-	checkSuccess(cur.getFieldLength(7,"testnumeric"),3)
+	#checkSuccess(cur.getFieldLength(7,"testdecimal"),3)
+	#checkSuccess(cur.getFieldLength(7,"testnumeric"),3)
 	#checkSuccess(cur.getFieldLength(7,"testmoney"),4)
 	#checkSuccess(cur.getFieldLength(7,"testsmallmoney"),4)
 	#checkSuccess(cur.getFieldLength(7,"testdatetime"),26)
@@ -501,8 +501,8 @@ def main():
 	checkSuccess(fields["testtinyint"],1)
 	#checkSuccess(fields["testreal"],Decimal("1.1"))
 	#checkSuccess(fields["testfloat"],Decimal("1.1"))
-	checkSuccess(fields["testdecimal"],Decimal("1.1"))
-	checkSuccess(fields["testnumeric"],Decimal("1.1"))
+	#checkSuccess(fields["testdecimal"],Decimal("1.1"))
+	#checkSuccess(fields["testnumeric"],Decimal("1.1"))
 	#checkSuccess(fields["testmoney"],Decimal("1.0"))
 	#checkSuccess(fields["testsmallmoney"],Decimal("1.0"))
 	#checkSuccess(fields["testdatetime"],"Jan  1 2001 01:00:00:000AM")
@@ -535,8 +535,8 @@ def main():
 	checkSuccess(fieldlengths["testtinyint"],1)
 	#checkSuccess(fieldlengths["testreal"],3)
 	#checkSuccess(fieldlengths["testfloat"],3)
-	checkSuccess(fieldlengths["testdecimal"],3)
-	checkSuccess(fieldlengths["testnumeric"],3)
+	#checkSuccess(fieldlengths["testdecimal"],3)
+	#checkSuccess(fieldlengths["testnumeric"],3)
 	#checkSuccess(fieldlengths["testmoney"],4)
 	#checkSuccess(fieldlengths["testsmallmoney"],4)
 	#checkSuccess(fieldlengths["testdatetime"],26)
@@ -550,8 +550,8 @@ def main():
 	checkSuccess(fieldlengths["testtinyint"],1)
 	#checkSuccess(fieldlengths["testreal"],3)
 	#checkSuccess(fieldlengths["testfloat"],17)
-	checkSuccess(fieldlengths["testdecimal"],3)
-	checkSuccess(fieldlengths["testnumeric"],3)
+	#checkSuccess(fieldlengths["testdecimal"],3)
+	#checkSuccess(fieldlengths["testnumeric"],3)
 	#checkSuccess(fieldlengths["testmoney"],4)
 	#checkSuccess(fieldlengths["testsmallmoney"],4)
 	#checkSuccess(fieldlengths["testdatetime"],26)
