@@ -20,11 +20,11 @@ def checkSuccess(value,success):
 
 def main():
 
-	cert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem"
-	ca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem"
+	cert="../sqlrelay.conf.d/tls/client.pem"
+	ca="../sqlrelay.conf.d/tls/ca.pem"
 	if platform.system()=="Windows":
-		cert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx"
-		ca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx"
+		cert="..\\sqlrelay.conf.d\\tls\\client.pfx"
+		ca="..\\sqlrelay.conf.d\\tls\\ca.pfx"
 
 	PySQLRClient.getNumericFieldsAsNumbers()
 
