@@ -1,10 +1,11 @@
 #! /usr/bin/env ruby
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
 
+require 'rbconfig'
 require 'sqlrelay'
 
 def checkSuccess(value,success)
@@ -18,8 +19,11 @@ def checkSuccess(value,success)
 end
 
 
+
+
+
 # instantiation
-con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket","","",0,1)
+con=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket","","",0,1)
 cur=SQLRCursor.new(con)
 con.enableKerberos("","","")
 
@@ -191,41 +195,41 @@ print "\n"
 
 print "COLUMN TYPES: \n"
 checkSuccess(cur.getColumnType(0),"NUMBER")
-checkSuccess(cur.getColumnType('testnumber'),"NUMBER")
+checkSuccess(cur.getColumnType('TESTNUMBER'),"NUMBER")
 checkSuccess(cur.getColumnType(1),"CHAR")
-checkSuccess(cur.getColumnType('testchar'),"CHAR")
+checkSuccess(cur.getColumnType('TESTCHAR'),"CHAR")
 checkSuccess(cur.getColumnType(2),"VARCHAR2")
-checkSuccess(cur.getColumnType('testvarchar'),"VARCHAR2")
+checkSuccess(cur.getColumnType('TESTVARCHAR'),"VARCHAR2")
 checkSuccess(cur.getColumnType(3),"DATE")
-checkSuccess(cur.getColumnType('testdate'),"DATE")
+checkSuccess(cur.getColumnType('TESTDATE'),"DATE")
 checkSuccess(cur.getColumnType(4),"LONG")
-checkSuccess(cur.getColumnType('testlong'),"LONG")
+checkSuccess(cur.getColumnType('TESTLONG'),"LONG")
 print "\n"
 
 print "COLUMN LENGTH: \n"
 checkSuccess(cur.getColumnLength(0),22)
-checkSuccess(cur.getColumnLength('testnumber'),22)
+checkSuccess(cur.getColumnLength('TESTNUMBER'),22)
 checkSuccess(cur.getColumnLength(1),40)
-checkSuccess(cur.getColumnLength('testchar'),40)
+checkSuccess(cur.getColumnLength('TESTCHAR'),40)
 checkSuccess(cur.getColumnLength(2),40)
-checkSuccess(cur.getColumnLength('testvarchar'),40)
+checkSuccess(cur.getColumnLength('TESTVARCHAR'),40)
 checkSuccess(cur.getColumnLength(3),7)
-checkSuccess(cur.getColumnLength('testdate'),7)
+checkSuccess(cur.getColumnLength('TESTDATE'),7)
 checkSuccess(cur.getColumnLength(4),0)
-checkSuccess(cur.getColumnLength('testlong'),0)
+checkSuccess(cur.getColumnLength('TESTLONG'),0)
 print "\n"
 
 print "LONGEST COLUMN: \n"
 checkSuccess(cur.getLongest(0),1)
-checkSuccess(cur.getLongest('testnumber'),1)
+checkSuccess(cur.getLongest('TESTNUMBER'),1)
 checkSuccess(cur.getLongest(1),40)
-checkSuccess(cur.getLongest('testchar'),40)
+checkSuccess(cur.getLongest('TESTCHAR'),40)
 checkSuccess(cur.getLongest(2),12)
-checkSuccess(cur.getLongest('testvarchar'),12)
+checkSuccess(cur.getLongest('TESTVARCHAR'),12)
 checkSuccess(cur.getLongest(3),9)
-checkSuccess(cur.getLongest('testdate'),9)
+checkSuccess(cur.getLongest('TESTDATE'),9)
 checkSuccess(cur.getLongest(4),9)
-checkSuccess(cur.getLongest('testlong'),9)
+checkSuccess(cur.getLongest('TESTLONG'),9)
 print "\n"
 
 print "ROW COUNT: \n"
@@ -281,39 +285,39 @@ checkSuccess(cur.getFieldLength(7,6),9)
 print "\n"
 
 print "FIELDS BY NAME: \n"
-checkSuccess(cur.getField(0,"testnumber"),"1")
-checkSuccess(cur.getField(0,"testchar"),"testchar1                               ")
-checkSuccess(cur.getField(0,"testvarchar"),"testvarchar1")
-checkSuccess(cur.getField(0,"testdate"),"01-JAN-01")
-checkSuccess(cur.getField(0,"testlong"),"testlong1")
-checkSuccess(cur.getField(0,"testclob"),"testclob1")
-checkSuccess(cur.getField(0,"testblob"),"")
+checkSuccess(cur.getField(0,"TESTNUMBER"),"1")
+checkSuccess(cur.getField(0,"TESTCHAR"),"testchar1                               ")
+checkSuccess(cur.getField(0,"TESTVARCHAR"),"testvarchar1")
+checkSuccess(cur.getField(0,"TESTDATE"),"01-JAN-01")
+checkSuccess(cur.getField(0,"TESTLONG"),"testlong1")
+checkSuccess(cur.getField(0,"TESTCLOB"),"testclob1")
+checkSuccess(cur.getField(0,"TESTBLOB"),"")
 print "\n"
-checkSuccess(cur.getField(7,"testnumber"),"8")
-checkSuccess(cur.getField(7,"testchar"),"testchar8                               ")
-checkSuccess(cur.getField(7,"testvarchar"),"testvarchar8")
-checkSuccess(cur.getField(7,"testdate"),"01-JAN-08")
-checkSuccess(cur.getField(7,"testlong"),"testlong8")
-checkSuccess(cur.getField(7,"testclob"),"testclob8")
-checkSuccess(cur.getField(7,"testblob"),"testblob8")
+checkSuccess(cur.getField(7,"TESTNUMBER"),"8")
+checkSuccess(cur.getField(7,"TESTCHAR"),"testchar8                               ")
+checkSuccess(cur.getField(7,"TESTVARCHAR"),"testvarchar8")
+checkSuccess(cur.getField(7,"TESTDATE"),"01-JAN-08")
+checkSuccess(cur.getField(7,"TESTLONG"),"testlong8")
+checkSuccess(cur.getField(7,"TESTCLOB"),"testclob8")
+checkSuccess(cur.getField(7,"TESTBLOB"),"testblob8")
 print "\n"
 
 print "FIELD LENGTHS BY NAME: \n"
-checkSuccess(cur.getFieldLength(0,"testnumber"),1)
-checkSuccess(cur.getFieldLength(0,"testchar"),40)
-checkSuccess(cur.getFieldLength(0,"testvarchar"),12)
-checkSuccess(cur.getFieldLength(0,"testdate"),9)
-checkSuccess(cur.getFieldLength(0,"testlong"),9)
-checkSuccess(cur.getFieldLength(0,"testclob"),9)
-checkSuccess(cur.getFieldLength(0,"testblob"),0)
+checkSuccess(cur.getFieldLength(0,"TESTNUMBER"),1)
+checkSuccess(cur.getFieldLength(0,"TESTCHAR"),40)
+checkSuccess(cur.getFieldLength(0,"TESTVARCHAR"),12)
+checkSuccess(cur.getFieldLength(0,"TESTDATE"),9)
+checkSuccess(cur.getFieldLength(0,"TESTLONG"),9)
+checkSuccess(cur.getFieldLength(0,"TESTCLOB"),9)
+checkSuccess(cur.getFieldLength(0,"TESTBLOB"),0)
 print "\n"
-checkSuccess(cur.getFieldLength(7,"testnumber"),1)
-checkSuccess(cur.getFieldLength(7,"testchar"),40)
-checkSuccess(cur.getFieldLength(7,"testvarchar"),12)
-checkSuccess(cur.getFieldLength(7,"testdate"),9)
-checkSuccess(cur.getFieldLength(7,"testlong"),9)
-checkSuccess(cur.getFieldLength(7,"testclob"),9)
-checkSuccess(cur.getFieldLength(7,"testblob"),9)
+checkSuccess(cur.getFieldLength(7,"TESTNUMBER"),1)
+checkSuccess(cur.getFieldLength(7,"TESTCHAR"),40)
+checkSuccess(cur.getFieldLength(7,"TESTVARCHAR"),12)
+checkSuccess(cur.getFieldLength(7,"TESTDATE"),9)
+checkSuccess(cur.getFieldLength(7,"TESTLONG"),9)
+checkSuccess(cur.getFieldLength(7,"TESTCLOB"),9)
+checkSuccess(cur.getFieldLength(7,"TESTBLOB"),9)
 print "\n"
 
 print "FIELDS BY ARRAY: \n"
@@ -652,7 +656,7 @@ cur.setResultSetBufferSize(0)
 print "\n"
 
 print "COMMIT AND ROLLBACK: \n"
-secondcon=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket","","",0,1)
+secondcon=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket","","",0,1)
 secondcur=SQLRCursor.new(secondcon)
 secondcon.enableKerberos("","","")
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
@@ -734,7 +738,7 @@ end
 cur.inputBindClob("clobval",clobval,8*1024)
 checkSuccess(cur.executeQuery(),1)
 cur.sendQuery("select testclob from testtable2")
-checkSuccess(clobval,cur.getField(0,"testclob"))
+checkSuccess(clobval,cur.getField(0,"TESTCLOB"))
 cur.prepareQuery("begin select testclob into :clobbindval from testtable2; end;")
 cur.defineOutputBindClob("clobbindval")
 checkSuccess(cur.executeQuery(),1)
@@ -814,5 +818,4 @@ checkSuccess(cur.sendQuery("create table testtable"),0)
 checkSuccess(cur.sendQuery("create table testtable"),0)
 print "\n"
 
-
-
+exit(0)
