@@ -1,10 +1,11 @@
 #! /usr/bin/env ruby
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
 
+require 'rbconfig'
 require 'sqlrelay'
 
 def checkSuccess(value,success)
@@ -22,7 +23,7 @@ end
 
 
 # instantiation
-con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+con=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket",
 						"test","test",0,1)
 cur=SQLRCursor.new(con)
 
@@ -101,7 +102,6 @@ cur.inputBind("5","testchar8")
 cur.inputBind("6","testvarchar8")
 cur.inputBind("7","01/01/2008")
 cur.inputBind("8","08:00:00")
-cur.inputBind("9","junkvalue")
 cur.validateBinds()
 checkSuccess(cur.executeQuery(),1)
 print "\n"
@@ -201,9 +201,9 @@ print "ROW COUNT: \n"
 checkSuccess(cur.rowCount(),8)
 print "\n"
 
-print "TOTAL ROWS: \n"
-checkSuccess(cur.totalRows(),8)
-print "\n"
+#print "TOTAL ROWS: \n"
+#checkSuccess(cur.totalRows(),8)
+#print "\n"
 
 print "FIRST ROW INDEX: \n"
 checkSuccess(cur.firstRowIndex(),0)
@@ -632,7 +632,7 @@ cur.setResultSetBufferSize(0)
 print "\n"
 
 print "COMMIT AND ROLLBACK: \n"
-secondcon=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+secondcon=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket",
 						"test","test",0,1)
 secondcur=SQLRCursor.new(secondcon)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
@@ -709,5 +709,4 @@ checkSuccess(cur.sendQuery("create table testtable"),0)
 checkSuccess(cur.sendQuery("create table testtable"),0)
 print "\n"
 
-
-
+exit(0)
